%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% import_data.m 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Imports DATA and DATAHH from Stata exports (variable_outsheet_20160523.do)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% OUTPUTS:
%
% DATA{}.listzipsWTP                   List of unique zipcodes
% DATA{}.listhospsWTP                  List of unique osphdids by insurer (for observed network)
% DATA{}.zip{}.KaiserDist           [7x1] [KisAvail KDist04 KDriveDist04 KDriveTime04 KDist95 KDriveDist95 KDriveTime95]% 
% DATA{}.zip{}.WTP                  [10x2] [gamma_WTP_ij]
% DATA{}.hospdrop{}.zip{}.WTP              [10x2] [gamma_WTP_kjm_drop for each insruer]
% DATA{}.hospdropsys{}.zip{}.WTP           [adm10x2]
%
% DATA{}.listzips
% DATA{}.listhosps                  List of hospitals in HSA
% DATA{}.ison
% DATA{}.avgamtdrg
% DATA{}.hosp{}.sysid               [1x1]
% DATA{}.hosp{}.avgdrgwt            [1x1]
% DATA{}.hosp{}.avgamtdrg           [1x1]
% DATA{}.hosp{}.nadmits             [2x1]
% DATA{}.hosp{}.avgdrgwtins         [2x1]
% DATA{}.hosp{}.costs               [1x1]
% DATA{}.hosp{}.ison                [2x1] ison BS / BC in data
% DATA{}.hosp{}.isfp                [1x1]

% DATA{}.zip{}.sigmaH                [nHospsInHsa x 10 x 2]    agesex x ins
% DATA{}.zip{}.hosputils             [nHospsInHsa x 10 x 6 x 2]  agesex x diag x insurer (u_ijhl numerator)
% DATA{}.zip{}.hospdrop{}.sigmaH     [nHospsInHsa x 10 x 2]    
% DATA{}.zip{}.hospdropsys{}.sigmaH  [nHospsInHsa x 10 x 2]    
%
% DATAHH{}.listzips
% DATAHH{}.zip{}.hhtype{}.members      [nFam x 10] each row is count of # members in each agesexcat
% DATAHH{}.zip{}.hhtype{}.planchoice   [nFam x 1]
% DATAHH{}.zip{}.nhhtype               [3 x 1] number of each household type in zip
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear

FLAG.import_WTP = 1;
FLAG.import_hospitalchars = 1;
FLAG.import_sigmaH = 1;
FLAG.import_households = 1;

%% Import and Structure WTP Data files
    if FLAG.import_WTP
        %******************************************************************
        %Import WTP_and_Kaiser.csv: 
        %[hsa zipcode03 agecat_Ho sex insurer gamma_WTP_ij KaiserisAvailable Kaiservars(6) ]
        %******************************************************************
        fprintf('Importing WTP and Kaiser Distances: ');
        import.WTP = importdata('../d03.Intermediate.Output/WTP_and_KaiserDistance_20160523.csv');
        for idxhsa=1:14
            fprintf('%d ', idxhsa);
            ishsa = (import.WTP(:,1)==idxhsa);
            temp.WTP = import.WTP(ishsa==1,:);
            DATA{idxhsa}.listzipsWTP = unique(temp.WTP(:,2));
            
            for idxzip = 1:length(DATA{idxhsa}.listzipsWTP)
               iszip = ( temp.WTP(:,2)== DATA{idxhsa}.listzipsWTP(idxzip));
               temp.WTPzip = temp.WTP(iszip==1,:);
               
               DATA{idxhsa}.zip{idxzip}.KaiserDist = temp.WTPzip(1,[7:end]);               
               
               DATA{idxhsa}.zip{idxzip}.WTP = zeros(10,2);
               for idxins = 1:2
                  isins = (temp.WTPzip(:,5)==idxins);
                  temp.WTPzipins = temp.WTPzip(isins==1,:);
                  if ~isempty(temp.WTPzipins)
                     for idxagesex=1:10    
                        idxsex = 1 + (idxagesex>5);
                        idxage = idxagesex - (idxsex-1)*5;
                        isage = (temp.WTPzipins(:,3)==idxage);
                        issex = (temp.WTPzipins(:,4)==idxsex);
                        isagesex = isage.*issex;
                        DATA{idxhsa}.zip{idxzip}.WTP(idxagesex,idxins) = temp.WTPzipins(isagesex==1,6);
                     end;
                  end;
               end;
            end;            
        end;
        fprintf('Done.\n');

        %******************************************************************
        %Import WTP_kjm_drop.csv: 
        %[hsa zipcode03 agecat_Ho sex insurer oshpdid_drop gamma_WTP_kjm_drop]
        %******************************************************************
        fprintf('Importing WTPDrop: ');
        import.WTPdrop = importdata('../d03.Intermediate.Output/wtp_kjm_drop_20160523.csv');
        import.WTPdropsys = importdata('../d03.Intermediate.Output/wtp_kjm_drop_sys_20160523.csv');        
        
        for idxhsa=1:14
            fprintf('%d ', idxhsa);
            ishsa = (import.WTPdrop(:,1)==idxhsa);
            temp.WTPdrop = import.WTPdrop(ishsa==1,:);
            DATA{idxhsa}.listhospsWTP = unique(temp.WTPdrop(:,6));
            for idxDhosp=1:length(DATA{idxhsa}.listhospsWTP)
               isdrophosp = ( temp.WTPdrop(:,6)== DATA{idxhsa}.listhospsWTP(idxDhosp));
               temp.WTPdrophosp = temp.WTPdrop(isdrophosp==1,:);                              
               for idxzip = 1:length(DATA{idxhsa}.listzipsWTP)
                  iszip = ( temp.WTPdrophosp(:,2) == DATA{idxhsa}.listzipsWTP(idxzip));
                  temp.WTPdrophospzip = temp.WTPdrophosp(iszip==1,:);
                  DATA{idxhsa}.hospdrop{idxDhosp}.zip{idxzip}.WTP = DATA{idxhsa}.zip{idxzip}.WTP; %<==INITIALIZE DROP WTP
                  for idxins = 1:2
                     isins = (temp.WTPdrophospzip(:,5)==idxins);
                     temp.WTPdrophospzipins = temp.WTPdrophospzip(isins==1,:);
                     if ~isempty(temp.WTPdrophospzipins)   
                        for idxagesex=1:10    
                            idxsex = 1 + (idxagesex>5);
                            idxage = idxagesex - (idxsex-1)*5;
                            isage = (temp.WTPdrophospzipins(:,3)==idxage);
                            issex = (temp.WTPdrophospzipins(:,4)==idxsex);
                            isagesex = isage.*issex;
                            DATA{idxhsa}.hospdrop{idxDhosp}.zip{idxzip}.WTP(idxagesex,idxins) = temp.WTPdrophospzipins(isagesex==1,7);
                        end;                  
                     end;
                  end;
               end;
            end;
            
            %SYSTEMS
            ishsa = (import.WTPdropsys(:,1)==idxhsa);
            temp.WTPdrop = import.WTPdropsys(ishsa==1,:);
            for idxDhosp=1:length(DATA{idxhsa}.listhospsWTP)
               isdrophosp = ( temp.WTPdrop(:,6)== DATA{idxhsa}.listhospsWTP(idxDhosp));
               temp.WTPdrophosp = temp.WTPdrop(isdrophosp==1,:);                              
               for idxzip = 1:length(DATA{idxhsa}.listzipsWTP)
                  iszip = ( temp.WTPdrophosp(:,2) == DATA{idxhsa}.listzipsWTP(idxzip));
                  temp.WTPdrophospzip = temp.WTPdrophosp(iszip==1,:);
                  DATA{idxhsa}.hospdropsys{idxDhosp}.zip{idxzip}.WTP = DATA{idxhsa}.zip{idxzip}.WTP;  %<==INITIALIZE DROP WTP
                  for idxins = 1:2
                     isins = (temp.WTPdrophospzip(:,5)==idxins);
                     temp.WTPdrophospzipins = temp.WTPdrophospzip(isins==1,:);
                     if ~isempty(temp.WTPdrophospzipins)   
                        for idxagesex=1:10    
                            idxsex = 1 + (idxagesex>5);
                            idxage = idxagesex - (idxsex-1)*5;
                            isage = (temp.WTPdrophospzipins(:,3)==idxage);
                            issex = (temp.WTPdrophospzipins(:,4)==idxsex);
                            isagesex = isage.*issex;
                            DATA{idxhsa}.hospdropsys{idxDhosp}.zip{idxzip}.WTP(idxagesex,idxins) = temp.WTPdrophospzipins(isagesex==1,7);
                        end;
                     end;
                  end;
               end;               
            end;
        end;
        fprintf('Done.\n');
   end; %if FLAG.import_WTP


%% Import and Structure Hospital Characteristics Data
    if FLAG.import_hospitalchars
        PARAM.NumBootstrap = 80;

        %****************************************************************** 
        %Import hospchars.csv
        %[1hsa 2oshpdid 3sysid 4avg_drgwt 5avg_amt_drgadj_BS 6avg_amt_drgadj_BC 7nAdmits_BS 8nAdmits_BC 9avg_drgwt_BS 10avg_drgwt_BC 11exp_peradm 12pay_peradm 13isBS 14isBC 15FP 16med_amt_drgadj_BS 17med_amt_drgadj_BC 18exp_dly_pa]
        %[18-97 BS Bootstrapped Prices; 98-177 BC Bootstrapped Prices]
        %******************************************************************
        fprintf('Importing Hospital Chars: ');
        import.hospchars = importdata('../d03.Intermediate.Output/hospchars_20160523.csv');
        
        for idxhsa=1:14
            fprintf('%d ', idxhsa);
            ishsa = (import.hospchars(:,1)==idxhsa);
            temp.hospchars = import.hospchars(ishsa==1,:);
            DATA{idxhsa}.listhosps = unique(temp.hospchars(:,2));
            
            DATA{idxhsa}.avgamtdrg = [];
            for idxboot=1:PARAM.NumBootstrap
                DATA{idxhsa}.avgamtdrg_boot{idxboot} = [];
            end;

            DATA{idxhsa}.ison = [];            
            DATA{idxhsa}.nadmits = [];
            DATA{idxhsa}.listsysid = [];
            DATA{idxhsa}.isonsys = [];   
            DATA{idxhsa}.costdrg = [];
            
            for idxhosp=1:length(DATA{idxhsa}.listhosps)
                ishosp = temp.hospchars(:,2)==DATA{idxhsa}.listhosps(idxhosp);
                hospchars = temp.hospchars(ishosp==1,:);
                DATA{idxhsa}.hosp{idxhosp}.oshpdid = hospchars(:,2);
                DATA{idxhsa}.hosp{idxhosp}.sysid = hospchars(:,3);
                DATA{idxhsa}.hosp{idxhosp}.avgdrgwt = hospchars(:,4);
                DATA{idxhsa}.hosp{idxhosp}.avgamtdrg = hospchars(:,5:6);
                DATA{idxhsa}.hosp{idxhosp}.nadmits = hospchars(:,7:8);
                DATA{idxhsa}.hosp{idxhosp}.avgdrgwtins = hospchars(:,9:10);
                DATA{idxhsa}.hosp{idxhosp}.costs = hospchars(:,11:13);
                DATA{idxhsa}.hosp{idxhosp}.ison = hospchars(:,14:15);
                DATA{idxhsa}.hosp{idxhosp}.isfp = hospchars(:,16);

                %Construct for all hospitals in HSA
                DATA{idxhsa}.avgamtdrg = [DATA{idxhsa}.avgamtdrg; DATA{idxhsa}.hosp{idxhosp}.avgamtdrg];
                
                DATA{idxhsa}.hosp{idxhosp}.avgamtdrg_boot = [DATA{idxhsa}.hosp{idxhosp}.avgamtdrg; hospchars(1,19:19+PARAM.NumBootstrap-1)' hospchars(1,19+PARAM.NumBootstrap:19+2*PARAM.NumBootstrap-1)'];    %41x2 idxboot x idxins (BS/BC)
                for idxboot=1:PARAM.NumBootstrap  
                    DATA{idxhsa}.avgamtdrg_boot{idxboot} = [DATA{idxhsa}.avgamtdrg_boot{idxboot}; DATA{idxhsa}.hosp{idxhosp}.avgamtdrg_boot(idxboot,:)];
                end;
                
                DATA{idxhsa}.costdrg = [ DATA{idxhsa}.costdrg;  DATA{idxhsa}.hosp{idxhosp}.costs(1,:)/DATA{idxhsa}.hosp{idxhosp}.avgdrgwt];
                DATA{idxhsa}.ison = [DATA{idxhsa}.ison; DATA{idxhsa}.hosp{idxhosp}.ison];
                DATA{idxhsa}.nadmits = [DATA{idxhsa}.nadmits; DATA{idxhsa}.hosp{idxhosp}.nadmits];
                
                %Use OSPHDID if hospital is not on a system
                if ~isnan(DATA{idxhsa}.hosp{idxhosp}.sysid)
                    DATA{idxhsa}.listsysid = [DATA{idxhsa}.listsysid; DATA{idxhsa}.hosp{idxhosp}.sysid];
                    DATA{idxhsa}.isonsys = [DATA{idxhsa}.isonsys; 1];
                else
                    DATA{idxhsa}.listsysid = [DATA{idxhsa}.listsysid; DATA{idxhsa}.hosp{idxhosp}.oshpdid];
                    DATA{idxhsa}.isonsys = [DATA{idxhsa}.isonsys; 0];
                end;
            end;
            DATA{idxhsa}.avgamtdrg(isnan(DATA{idxhsa}.avgamtdrg)==1) = 0;
            for idxboot=1:PARAM.NumBootstrap
                DATA{idxhsa}.avgamtdrg_boot{idxboot}(isnan(DATA{idxhsa}.avgamtdrg_boot{idxboot})==1) = 0;
            end;
            
            DATA{idxhsa}.uniquesysids = unique(DATA{idxhsa}.listsysid);
            DATA{idxhsa}.uniquesysids = [DATA{idxhsa}.uniquesysids zeros(length(DATA{idxhsa}.uniquesysids),3)];
            for idxsys = 1:length(DATA{idxhsa}.uniquesysids)
                DATA{idxhsa}.uniquesysids(idxsys,2) = sum( DATA{idxhsa}.listsysid == DATA{idxhsa}.uniquesysids(idxsys,1) );
                DATA{idxhsa}.uniquesysids(idxsys,3) = sum( (DATA{idxhsa}.listsysid == DATA{idxhsa}.uniquesysids(idxsys,1)).*DATA{idxhsa}.ison(:,1) )/DATA{idxhsa}.uniquesysids(idxsys,2);
                DATA{idxhsa}.uniquesysids(idxsys,4) = sum( (DATA{idxhsa}.listsysid == DATA{idxhsa}.uniquesysids(idxsys,1)).*DATA{idxhsa}.ison(:,2) )/DATA{idxhsa}.uniquesysids(idxsys,2);                
            end;
        end;
        fprintf('Done.\n');
    end; %if FLAG.import_hospitalchars

    
%% Import and Structure SigmaH Data files
    if FLAG.import_sigmaH
        %****************************************************************** 
        %Import SigmaH_kijm: 
        %[hsa zipcode03 agecat_Ho sex oshpdid insurer sigmaH_kijm]
        %
        %Import hosputils:
        %hsa oshpdid agecat_Ho sex zipcode03 6u_ihl_cancerBS u_ihl_cardiacBS u_ihl_digestiveBS u_ihl_laborBS u_ihl_neuroBS u_ihl_othercodeBS u_ihl_cancerBC u_ihl_cardiacBC u_ihl_digestiveBC u_ihl_laborBC u_ihl_neuroBC u_ihl_othercodeBC
        %****************************************************************** 
        fprintf('Importing SigmaH and Hosp Utilities: ');
        import.sigmaH = importdata('../d03.Intermediate.Output/sigmaH_kijm_20160523.csv');
        import.hosputils = importdata('../d03.Intermediate.Output/hosputils_20160523.csv');
        
        for idxhsa=1:14
            fprintf('%d ', idxhsa);            

            %Narrow to only hsa==idxhsa entries
            ishsa = (import.sigmaH(:,1)==idxhsa);
            temp.sigmaH = import.sigmaH(ishsa==1,:);            
            DATA{idxhsa}.listzips = unique(temp.sigmaH(:,2));
            ishsa = (import.hosputils(:,1)==idxhsa);
            temp.hosputils = import.hosputils(ishsa==1,:);              
            temp.nhospsinhsa = length(DATA{idxhsa}.listhosps);

            
            for idxzip = 1:length(DATA{idxhsa}.listzips)                
                 %******************************************************
                 %Populate sigmaH for age-sex-zip
                 %******************************************************
                 DATA{idxhsa}.zip{idxzip}.sigmaH = zeros(temp.nhospsinhsa,10,2);   %<== Defined here
                 
                 iszipSigmaH = (temp.sigmaH(:,2) == DATA{idxhsa}.listzips(idxzip));
                 temp.sigmaHzip = temp.sigmaH(iszipSigmaH==1,:);
                 for idxhosp = 1:length(DATA{idxhsa}.listhosps)
                    ishosp = (temp.sigmaHzip(:,5) == DATA{idxhsa}.listhosps(idxhosp));
                    temp.sigmaHzip_hosp = temp.sigmaHzip(ishosp==1,:);                      
                    if ~isempty(temp.sigmaHzip_hosp)
                        for idxagesex=1:10    
                            idxsex = 1 + (idxagesex>5);
                            idxage = idxagesex - (idxsex-1)*5;
                            isage = (temp.sigmaHzip_hosp(:,3)==idxage);
                            issex = (temp.sigmaHzip_hosp(:,4)==idxsex);
                            isagesex = isage.*issex;                            
                            for idxins=1:2
                                isins = (temp.sigmaHzip_hosp(:,6)==idxins);
                                isagesexins = isagesex.*isins;
                                if sum(isagesexins)==1
                                    DATA{idxhsa}.zip{idxzip}.sigmaH(idxhosp,idxagesex,idxins) = temp.sigmaHzip_hosp(isagesexins==1,7);
                                end;
                            end;
                        end;
                    end;
                 end;                 

                  %******************************************************
                  %Populate u_{ihl} for age-sex-diag-insurer w/in zipcode 
                  %******************************************************            
                  DATA{idxhsa}.zip{idxzip}.hosputils = -inf*ones(temp.nhospsinhsa,10,6,2);
                  iszipHospUtils = (temp.hosputils(:,5) == DATA{idxhsa}.listzips(idxzip));
                  temp.hosputilszip = temp.hosputils(iszipHospUtils==1,:);
                  
                  for idxhosp = 1:length(DATA{idxhsa}.listhosps)
                        ishosp = (temp.hosputilszip(:,2) == DATA{idxhsa}.listhosps(idxhosp));
                        temp.hosputilszip_hosp = temp.hosputilszip(ishosp==1,:);          
                        if ~isempty(temp.hosputilszip_hosp)
                          for idxagesex=1:10                           
                               idxsex = 1 + (idxagesex>5);
                               idxage = idxagesex - (idxsex-1)*5;
                               isage = (temp.hosputilszip_hosp(:,3)==idxage);
                               issex = (temp.hosputilszip_hosp(:,4)==idxsex);
                               isagesex = isage.*issex;
                               temp.utils = temp.hosputilszip_hosp(isagesex==1,6:17);

                               DATA{idxhsa}.zip{idxzip}.hosputils(idxhosp,idxagesex,1,:) = [temp.utils(1,1) temp.utils(1,7)];  %[u_ihl_cancerBS u_ihl_cancerBC]
                               DATA{idxhsa}.zip{idxzip}.hosputils(idxhosp,idxagesex,2,:) = [temp.utils(1,2) temp.utils(1,8)];  %[u_ihl_cardiacBS u_ihl_cardiacBC]
                               DATA{idxhsa}.zip{idxzip}.hosputils(idxhosp,idxagesex,3,:) = [temp.utils(1,3) temp.utils(1,9)];  %[u_ihl_digestiveBS u_ihl_digestiveBC]
                               DATA{idxhsa}.zip{idxzip}.hosputils(idxhosp,idxagesex,4,:) = [temp.utils(1,4) temp.utils(1,10)];  %[u_ihl_laborBS u_ihl_laborBC]
                               DATA{idxhsa}.zip{idxzip}.hosputils(idxhosp,idxagesex,5,:) = [temp.utils(1,5) temp.utils(1,11)];  %[u_ihl_neurologicalBS u_ihl_neurologicalBC]
                               DATA{idxhsa}.zip{idxzip}.hosputils(idxhosp,idxagesex,6,:) = [temp.utils(1,6) temp.utils(1,12)];  %[u_ihl_otherBS u_ihl_otherBC]
                          end;     
                       end;    
                  end;                  
            end; %for idxzip
                 
        end;
        fprintf('Done.\n');

        %****************************************************************** 
        %Import sigmaH_kijm_drop and sigmaH_kijm_dropsys: 
        %hsa zipcode03 agecat_Ho sex oshpdid insurer oshpdid_drop sigmaH_kijm_drop
        %****************************************************************** 
        fprintf('Importing SigmaHDrop and SigmaHDropsys: ');
        import.sigmaHD = importdata('../d03.Intermediate.Output/sigmaH_kijm_drop_20160523.csv');
        import.sigmaHDsys = importdata('../d03.Intermediate.Output/sigmaH_kijm_drop_sys_20160523.csv');
        for idxhsa=1:14
            fprintf('%d ', idxhsa);
            %Narrow to only hsa==idxhsa entries
            ishsa = (import.sigmaHD(:,1)==idxhsa);
            temp.sigmaHD = import.sigmaHD(ishsa==1,:);            
            ishsa = (import.sigmaHDsys(:,1)==idxhsa);
            temp.sigmaHDsys = import.sigmaHDsys(ishsa==1,:); 

            temp.nhospsinhsa = length(DATA{idxhsa}.listhosps);
            
            %cycle over all hospitals that can be dropped
            for idxDhosp = 1:length(DATA{idxhsa}.listhosps)
                isDhosp = (temp.sigmaHD(:,7) == DATA{idxhsa}.listhosps(idxDhosp));
                temp.sigmaHDhosp = temp.sigmaHD(isDhosp==1,:);                    
                isDhosp = (temp.sigmaHDsys(:,7) == DATA{idxhsa}.listhosps(idxDhosp));
                temp.sigmaHDhospsys = temp.sigmaHDsys(isDhosp==1,:);                                   
                
                for idxzip = 1:length(DATA{idxhsa}.listzips)
                    DATA{idxhsa}.hospdrop{idxDhosp}.zip{idxzip}.sigmaH = zeros(temp.nhospsinhsa,10,2);     %<=== DATA{idxhsa}.hospdrop{idxDhosp}.zip{idxzip}.sigmaH
                    isDhosp_zip = (temp.sigmaHDhosp(:,2) == DATA{idxhsa}.listzips(idxzip));
                    temp.sigmaHDhosp_zip = temp.sigmaHDhosp(isDhosp_zip==1,:);    

                    DATA{idxhsa}.hospdropsys{idxDhosp}.zip{idxzip}.sigmaH = zeros(temp.nhospsinhsa,10,2);  %<=== DATA{idxhsa}.hospdropsys{idxDhosp}.zip{idxzip}.sigmaH
                    isDhospsys_zip = (temp.sigmaHDhospsys(:,2) == DATA{idxhsa}.listzips(idxzip));
                    temp.sigmaHDhospsys_zip = temp.sigmaHDhospsys(isDhosp_zip==1,:);
                    
                    for idxhosp = 1:length(DATA{idxhsa}.listhosps)
                        %keep only entires that correspond to dropped hospital-hosp pair:
                        isDhosp_zip_hosp = (temp.sigmaHDhosp_zip(:,5) == DATA{idxhsa}.listhosps(idxhosp));
                        temp.sigmaHDhosp_zip_hosp = temp.sigmaHDhosp_zip(isDhosp_zip_hosp==1,:);   
                        isDhospsys_zip_hosp = (temp.sigmaHDhospsys_zip(:,5) == DATA{idxhsa}.listhosps(idxhosp));
                        temp.sigmaHDhospsys_zip_hosp = temp.sigmaHDhospsys_zip(isDhospsys_zip_hosp==1,:);   
                        
                        if ~isempty(temp.sigmaHDhosp_zip_hosp)
                            for idxagesex=1:10    
                                idxsex = 1 + (idxagesex>5);
                                idxage = idxagesex - (idxsex-1)*5;
                                isage = (temp.sigmaHDhosp_zip_hosp(:,3)==idxage);
                                issex = (temp.sigmaHDhosp_zip_hosp(:,4)==idxsex);
                                isagesex = isage.*issex;
                                for idxins=1:2
                                    isins = (temp.sigmaHDhosp_zip_hosp(:,6)==idxins);
                                    isagesexins = isagesex.*isins;
                                    if sum(isagesexins)==1
                                        DATA{idxhsa}.hospdrop{idxDhosp}.zip{idxzip}.sigmaH(idxhosp,idxagesex,idxins) = temp.sigmaHDhosp_zip_hosp(isagesexins==1,8);
                                    end;
                                end;
                            end;                        
                        end;
                        if ~isempty(temp.sigmaHDhospsys_zip_hosp)
                            for idxagesex=1:10         
                                idxsex = 1 + (idxagesex>5);
                                idxage = idxagesex - (idxsex-1)*5;
                                isage = (temp.sigmaHDhospsys_zip_hosp(:,3)==idxage);
                                issex = (temp.sigmaHDhospsys_zip_hosp(:,4)==idxsex);
                                isagesex = isage.*issex;
                                for idxins=1:2                                    
                                    isins = (temp.sigmaHDhospsys_zip_hosp(:,6)==idxins);
                                    isagesexins = isagesex.*isins;
                                    if sum(isagesexins)==1
                                        DATA{idxhsa}.hospdropsys{idxDhosp}.zip{idxzip}.sigmaH(idxhosp,idxagesex,idxins) = temp.sigmaHDhospsys_zip_hosp(isagesexins==1,8);
                                    end;
                                end;
                            end;
                        end;
                    end;
                end;
            end; %for idxDhosp
        end;
        fprintf('Done.\n');        
        save('M_DATA_20160523.mat','DATA');
        clear import temp;
    end; %if FLAG.import_sigmaH


%% Import and Structure Enrollment data (age,sex,zip,household composition)
    if FLAG.import_households  
        %****************************************************************** 
        %Import Households 
        %[hsa zipcode03 party_rollup agecat_Ho sex relationship planchoice familyid personid pay_amount]
        % only keep if has income data
        %****************************************************************** 
        fprintf('Importing Households: ');
        import.hhs = importdata('../d03.Intermediate.Output/households_20160523.csv');
        for idxhsa=1:14
            fprintf('%d ', idxhsa);
            ishsa = (import.hhs(:,1)==idxhsa);
            temp.hhs = import.hhs(ishsa==1,:);
            DATAHH{idxhsa}.listzips = unique(temp.hhs(:,2));
            for idxzip = 1:length(DATAHH{idxhsa}.listzips)
                iszip = ( temp.hhs(:,2)== DATAHH{idxhsa}.listzips(idxzip));
                temp.hhszip = temp.hhs(iszip==1,:);
                DATAHH{idxhsa}.zip{idxzip}.nhhtype = zeros(3,1);
                for idxhhtype=1:3
                    ishhtype = temp.hhszip(:,3)==idxhhtype;
                    hasincome = ~isnan(temp.hhszip(:,10));
                    temp.listfam = unique(temp.hhszip(ishhtype.*hasincome==1,8));
                    DATAHH{idxhsa}.zip{idxzip}.nhhtype(idxhhtype) = length(temp.listfam);
                    DATAHH{idxhsa}.zip{idxzip}.hhtype{idxhhtype}.members = [];
                    DATAHH{idxhsa}.zip{idxzip}.hhtype{idxhhtype}.planchoice = [];
                    DATAHH{idxhsa}.zip{idxzip}.hhtype{idxhhtype}.logincome = [];
                    for idxfam=1:length(temp.listfam)
                        isfam = temp.hhszip(:,8)==temp.listfam(idxfam);
                        temp.family = temp.hhszip(ishhtype.*isfam==1, [4 5 6 7 10]);  %agecat_Ho sex relationship planchoice pay_amount
                        if ~isnan(temp.family(1,5)) %only import families with non-missing income data
                            DATAHH{idxhsa}.zip{idxzip}.hhtype{idxhhtype}.members=[DATAHH{idxhsa}.zip{idxzip}.hhtype{idxhhtype}.members; zeros(1,10)];
                            DATAHH{idxhsa}.zip{idxzip}.hhtype{idxhhtype}.planchoice=[DATAHH{idxhsa}.zip{idxzip}.hhtype{idxhhtype}.planchoice; temp.family(1,4)];
                            for idxperson=1:size(temp.family,1)
                                agesexcat = temp.family(idxperson,1) + (temp.family(idxperson,2)-1)*5;
                                DATAHH{idxhsa}.zip{idxzip}.hhtype{idxhhtype}.members(idxfam,agesexcat) = DATAHH{idxhsa}.zip{idxzip}.hhtype{idxhhtype}.members(idxfam,agesexcat)+1;
                            end;
                            if size(temp.family,1) > 0
                                DATAHH{idxhsa}.zip{idxzip}.hhtype{idxhhtype}.avgmembers(idxfam,:) = DATAHH{idxhsa}.zip{idxzip}.hhtype{idxhhtype}.members(idxfam,:) / size(temp.family,1);
                            end;
                            if ~isnan(temp.family(1,5))
                                DATAHH{idxhsa}.zip{idxzip}.hhtype{idxhhtype}.logincome = [DATAHH{idxhsa}.zip{idxzip}.hhtype{idxhhtype}.logincome; log( temp.family(1,5) * 10000) ];  
                            else
                                DATAHH{idxhsa}.zip{idxzip}.hhtype{idxhhtype}.logincome = [DATAHH{idxhsa}.zip{idxzip}.hhtype{idxhhtype}.logincome; NaN];                         
                            end;
                        end;
                    end;
                end;
            end;
        end;    
        fprintf('Done.\n');
        save('M_DATAHH_20160523.mat','DATAHH');
        clear import temp;
    end;
    
