%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% estimate_bargainingeq.m 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% INPUTS: (Created from import_data.m)
% DATAHH    from datahhimport.mat (import_data.m) 
% DATA      from dataimport.mat (import_data.m)
% Estimated insurer demand from Stata estimate_2_insurerdemand.do (w/ income)
% '../d03.Intermediate.Output/insurer_demand_coeffs.csv')
% '../d03.Intermediate.Output/insurer_demand_deltas.csv')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear;
PARAM.Date=20160621;
FLAG.PremSetting_MatchMargins = 1;          %Match margins to get MCs, then use \tau^\phi factor to match prem setting via bargaining

    %Robustness Flags
    FLAG.BC10PercentMargin = 0;
    FLAG.UseSwitchingCosts = 0;
    FLAG.AdjustWTPCoeff = 0;

    %FLAGS changed only for CFs
    FLAG.isRemoveBS_CF = 0;
    FLAG.isRemoveBC_CF = 0;
    FLAG.isRemoveK_CF = 0;

%Parameters to use
PARAM.NumBootstrap = 80;
PARAM.FixedPremMLR = .80;
PARAM.SwitchingCosts = .90;
PARAM.AdjustWTPCoeff = .75;
PARAM.KaiserDistUse = 4;   
PARAM.HospCostUse = 3;     
PARAM.MinAdmits = 10;      %Only include hospital-insurer pairs w/ this many admits
PARAM.PremiumScale = 1;    
PARAM.ExcludedHSAs = [];
PARAM.IndivPremContribution = .2;

%Construct Kaiser Availability Vector (=1 everywhere except HSA 1+8)
PARAM.isKaiserAvail = ones(14,1);
PARAM.isKaiserAvail(1) = 0;
PARAM.isKaiserAvail(8) = 0;
%%%%%%%%%%%%%%%%%%%%%%
PARAM.FileSuffix=f_filesuffix(FLAG,PARAM);

disp(['Pricing & Bargaining Estimation for M_EST',PARAM.FileSuffix]);

%%%%%%%%%%%%%%%%%%%%%%
load M_DATA_20160523.mat;
load M_DATAHH_20160523.mat; 

%% IMPORT INSURER DEMAND ESTIMATES FROM STATA estimate2a_insurerdemand.do 
    % DATAEST.insdemandcoeffs.insFE                [14x2] Insurer Fixed Effects, BSBC
    % DATAEST.insdemandcoeffs.useWTP               [3x1] Coefficient on WTP (by hhtype)
    % DATAEST.insdemandcoeffs.prem                 [1x1] Coefficient on premium
    % DATAEST.insdemandcoeffs.Kaiser               [3x2x14] Coefficient on Kaiser Drive Time
    % DATAEST.premiums                             [3x3] premiums for insurer x ftype 
    
    DATAEST.premiums = 12* [315.22 630.44 819.57; ...  %BlueShield of CA
                            349.41 698.82 908.47; ...  %Anthem BlueCross
                            305.42 610.84 794.09; ];   %Kaiser
                        
    DATAEST.margins = [17.72 20.93 9.18]'./100; %Estimated percent margins from financial info
    if FLAG.BC10PercentMargin == 1
        DATAEST.margins(2) = .10;
    end;
    
    % Avg DRG weights by agebin and sex
    % Estimated from estimate_1_hospitaldemand.do, only from 35K admissions used to estimate hosp demand
    DATAEST.drgwts = [1.611648  1.780266 1.882043 2.037602 2.186788 ...
                      1.3399486  .862598 1.370604 1.845075 2.016986]; 
    
    DATAEST.admwts = [.0205 .0207 .0311 .0558 .1049 ...
                      .0228 .11194 .0791 .0687 .0974];
                  
    PARAM.drgXadmwts = repmat(DATAEST.drgwts.*DATAEST.admwts,3,1);
    
    import.coeffs = importdata('../d03.Intermediate.Output/insurer_demand_coeffs.csv');   %[hsa party_rollup sex agecat_Ho WTPcoeff PriceCoeff logincprem KCoeff KCoeff2]
    import.insFE = importdata('../d03.Intermediate.Output/insurer_demand_deltas.csv');    %[hsa id_insurer insFE]
   
    DATAEST.insdemandcoeffs.insFE = zeros(14,2);
    for idxhsa=1:14
        for idxins = 1:2
            DATAEST.insdemandcoeffs.insFE(idxhsa,idxins) = import.insFE(find((import.insFE(:,1)==idxhsa) .* (import.insFE(:,2)==idxins)),3);           
        end;
    end;    
    
    DATAEST.insdemandcoeffs.Kaiser= zeros(14,2); 
    DATAEST.insdemandcoeffs.useWTP = zeros(10,1);
    DATAEST.insdemandcoeffs.prem = import.coeffs(1,6);
    DATAEST.insdemandcoeffs.logincprem = import.coeffs(1,7);
    
    for idxhsa=1:14
        temp.coeffs = import.coeffs(find(import.coeffs(:,1)==idxhsa), 8:9);
        DATAEST.insdemandcoeffs.Kaiser(idxhsa,:) = temp.coeffs(1,:);
    end;    
    for idxage = 1:5
        for idxsex = 1:2
            idxagesex = idxage + (idxsex-1)*5;
            DATAEST.insdemandcoeffs.useWTP(idxagesex,1) = import.coeffs(find((import.coeffs(:,1)==2) .* (import.coeffs(:,2)==1) .* (import.coeffs(:,3)==idxsex).* (import.coeffs(:,4)==idxage)),5);
        end;
    end;
    clear import;
    
   %Precompute and Construct Kaiser Distance Utilities for each zip (not in 1,8,9)
    for idxhsa=1:14
        for idxzip = 1:length(DATA{idxhsa}.listzipsWTP)
            if (idxhsa ~= 1) && (idxhsa ~=8) && (idxhsa~=9)
                DATA{idxhsa}.zip{idxzip}.KaiserDistUtil = DATAEST.insdemandcoeffs.Kaiser(idxhsa,1) * DATA{idxhsa}.zip{idxzip}.KaiserDist(PARAM.KaiserDistUse) ...
                    + DATAEST.insdemandcoeffs.Kaiser(idxhsa,2) * DATA{idxhsa}.zip{idxzip}.KaiserDist(PARAM.KaiserDistUse)^2;
            else
                DATA{idxhsa}.zip{idxzip}.KaiserDistUtil = 0;
            end;    
        end;
    end;    
    save('M_DATA_20160523.mat','DATA');   %Only for Kaiser Distances
    
%% Estimate Baseline and CF Insurance & Hospital Demand        
%if FLAG.InitDemand == 1
    %Initialize Baseline INSDEMAND and HOSPDEMAND
    [INSDEMAND, HOSPDEMAND, INSDEMANDALL] = f_initialize_inshospdemand(DATA,DATAHH,DATAEST.premiums, DATAEST.insdemandcoeffs, DATAEST.drgwts, FLAG, PARAM, 1);
    save(['M_InitDemand',PARAM.FileSuffix], 'INSDEMAND', 'HOSPDEMAND', 'INSDEMANDALL');
    
    %Generate predicted dWTP for each ins-hospital pair using predicted insurer demand w/o premiums (FOR IV)
    [DATAEST.dWTP DATAEST.dWTPsys] = f_compute_dWTP(DATA, DATAHH, INSDEMAND);    

%% Estimate Bargaining Equation
    options = optimset('MaxFunEvals', 5000, 'MaxIter', 5000, 'tolX', 10^-3, 'tolFun',10^-5);

    %Scaling of 3 sets of moments (to normalize)
    PARAM.MomentScaling = [10^0; 10^4; 10^-6];
    
    if isfield(FLAG,'AlternatePremiumSettingError')==1
        if FLAG.AlternatePremiumSettingError==1
            PARAM.MomentScaling = [10^0; 10^4; 10^-6];
        end;
    end;    

    for idxboot = 1:PARAM.NumBootstrap
        fprintf('BOOTSTRAP RUN: %f ================= \n', idxboot);

        %SET BOOTSTRAP PRICES HERE
        for idxhsa=1:14
            PRICES{idxhsa}.avgamtdrg = DATA{idxhsa}.avgamtdrg_boot{idxboot};
        end;    

        [LHS, RHS] = f_construct_LHSRHS(DATA,DATAEST, PRICES, INSDEMAND, HOSPDEMAND,  DATAEST.premiums, FLAG, PARAM);
                
        theta_0 = [.2 .2 .85 1500 2500];  %tau_BS tau_BC tau_phi MC_BS MC_BC 
        LBUSE = [.01,.01, 0, 0, 0];
        UBUSE = [1,1,1,10^4,10^4];

        %2-Step GMM
        for isHospSysRegression = 0:1
            
            FLAG.HospitalSystemRegression = isHospSysRegression;

            [theta1 fval_fminc] = fmincon(@(theta) f_GMM_Obj_2016(theta, DATA, DATAEST, PRICES, INSDEMAND, HOSPDEMAND, FLAG, PARAM, LHS, RHS),theta_0,[],[],[],[],LBUSE,UBUSE,[],options);
            [obj, Y, X, Z, ImpliedMC, temp.residXdemand, temp.resid_prem, OMEGA, VarMomentsTheta2, Moments] = f_GMM_Obj_2016(theta1, DATA, DATAEST, PRICES, INSDEMAND, HOSPDEMAND, FLAG, PARAM, LHS, RHS);

            [theta2 fval2_fminc] = fmincon(@(theta) f_GMM_Obj_2016(theta, DATA, DATAEST, PRICES, INSDEMAND, HOSPDEMAND, FLAG, PARAM, LHS, RHS,VarMomentsTheta2),theta_0,[],[],[],[],LBUSE,UBUSE,[],options);            
            [obj, Y, X, Z, ImpliedMC, temp.residXdemand, temp.resid_prem, OMEGA, VarMomentsTheta3, Moments] = f_GMM_Obj_2016(theta2, DATA, DATAEST, PRICES, INSDEMAND, HOSPDEMAND, FLAG, PARAM, LHS, RHS);            
            
            thetafinal=[theta2 ImpliedMC(3)];  
            
            if FLAG.HospitalSystemRegression == 0
                ESTIMATES{idxboot}.residXdemand = temp.residXdemand;
                ESTIMATES{idxboot}.resid_prem = temp.resid_prem;
                fprintf('No Systems: \n');
                ESTIMATES{idxboot}.resid = ESTIMATES{idxboot}.residXdemand ./ LHS.HospDemand;
                ESTIMATES{idxboot}.resid_index = LHS.Index;
                ESTIMATES{idxboot}.tau = thetafinal(1:2);
                ESTIMATES{idxboot}.MC = thetafinal(4:6)';
                if FLAG.PremSetting_MatchMargins==1 
                    ESTIMATES{idxboot}.rho = thetafinal(3);
                else
                    ESTIMATES{idxboot}.rho = 1;
                end;
            else
                ESTIMATES{idxboot}.residXdemand_sys = temp.residXdemand;
                ESTIMATES{idxboot}.resid_sys_prem = temp.resid_prem;
                fprintf('Systems: \n');
                ESTIMATES{idxboot}.resid_sys = ESTIMATES{idxboot}.residXdemand_sys ./ LHS.HospDemand_sys;
                ESTIMATES{idxboot}.resid_sys_index = LHS.Index_sys;
                ESTIMATES{idxboot}.tau_sys = thetafinal(1:2);
                ESTIMATES{idxboot}.MC_sys = thetafinal(4:6)';
                if FLAG.PremSetting_MatchMargins==1 
                    ESTIMATES{idxboot}.rho_sys = thetafinal(3);
                else
                    ESTIMATES{idxboot}.rho_sys = 1;
                end;
            end;
            fprintf('tauM_BS, tauM_BC, rho: %f %f %f', [thetafinal(1:2) thetafinal(3)] );
            fprintf(', MCs %f %f %f', thetafinal(4:6)); 
            fprintf(', fval %f \n', fval2_fminc); 
        end;    
        
        if idxboot==1
            ESTIMATES_ALL.nosys = [ESTIMATES{idxboot}.MC;ESTIMATES{idxboot}.tau'; ESTIMATES{idxboot}.rho];  
            ESTIMATES_ALL.sys = [ESTIMATES{idxboot}.MC_sys;ESTIMATES{idxboot}.tau_sys'; ESTIMATES{idxboot}.rho_sys];  
        else
            ESTIMATES_ALL.nosys = [ESTIMATES_ALL.nosys [ESTIMATES{idxboot}.MC;ESTIMATES{idxboot}.tau'; ESTIMATES{idxboot}.rho]];  
            ESTIMATES_ALL.sys = [ESTIMATES_ALL.sys [ESTIMATES{idxboot}.MC_sys;ESTIMATES{idxboot}.tau_sys'; ESTIMATES{idxboot}.rho_sys]];  
        end;
    end; %for idxboot
    
    temp.nosys = sort(ESTIMATES_ALL.nosys,2);
    temp.sys = sort(ESTIMATES_ALL.sys,2);
    
    ESTIMATES_ALL.CI = [ [ ESTIMATES{1}.MC' ESTIMATES{1}.tau ESTIMATES{1}.rho length(LHS.Index)]' [temp.nosys(:,1+.025*PARAM.NumBootstrap);0] [temp.nosys(:,.975*PARAM.NumBootstrap);0]...
             [ ESTIMATES{1}.MC_sys' ESTIMATES{1}.tau_sys ESTIMATES{1}.rho_sys length(LHS.Index_sys)]' [temp.sys(:,1+.025*PARAM.NumBootstrap);0] [temp.sys(:,.975*PARAM.NumBootstrap);0]];
    ESTIMATES_ALL.se_nosys =  (sum((temp.nosys-repmat(mean(temp.nosys,2),1,PARAM.NumBootstrap)).^2,2)/(PARAM.NumBootstrap)).^.5;
    ESTIMATES_ALL.se_sys =  (sum((temp.sys-repmat(mean(temp.sys,2),1,PARAM.NumBootstrap)).^2,2)/(PARAM.NumBootstrap)).^.5;
    
    ESTIMATES_ALL.Final = [ [ ESTIMATES{1}.MC' ESTIMATES{1}.tau ESTIMATES{1}.rho length(LHS.Index)]' [ESTIMATES_ALL.se_nosys;0]  ...
                            [ ESTIMATES{1}.MC_sys' ESTIMATES{1}.tau_sys ESTIMATES{1}.rho_sys length(LHS.Index_sys)]' [ESTIMATES_ALL.se_sys;0]];
    
    save(['M_EST',PARAM.FileSuffix], 'DATAEST', 'PRICES', 'ESTIMATES', 'ESTIMATES_ALL', 'FLAG', 'PARAM')
    

%% RESET TO BOOTSTRAP 1    
    idxboot = 1;
    ESTIMATESUSE = ESTIMATES{idxboot};
    for idxhsa=1:14
        PRICES{idxhsa}.avgamtdrg = DATA{idxhsa}.avgamtdrg_boot{idxboot};
    end;    
    [LHS, RHS] = f_construct_LHSRHS(DATA, DATAEST, PRICES, INSDEMAND, HOSPDEMAND,  DATAEST.premiums, FLAG, PARAM);    
        
    
%% TEST PRICE AND PREMIUM RECOVERY
    temp.OldPrices = LHS.PriceXDemand ./ LHS.HospDemand;
    FLAG.HospitalSystemRegression=1;
    temp.OldPrices_sys = LHS.PriceXDemand_sys ./ LHS.HospDemand_sys;
    temp.NewRHS_sys = (1-ESTIMATESUSE.tau_sys(LHS.Index_sys(:,2)))' .* (RHS.InsPremRev_sys - ESTIMATESUSE.MC_sys(LHS.Index_sys(:,2)) .* RHS.InsChangeIndivs_sys - RHS.InsOtherHospPmts_sys )...
                    + (ESTIMATESUSE.tau_sys(LHS.Index_sys(:,2)))'.*(RHS.HospCostsXDemand_sys - (RHS.HospOtherInsPriceXDemand_sys - RHS.HospOtherInsCostXDemand_sys)) + ESTIMATESUSE.residXdemand_sys;         
    temp.NewPrices_sys = temp.NewRHS_sys ./ LHS.HospDemand_sys;
    temp.NewRHS_sys2 = (1-ESTIMATESUSE.tau_sys(LHS.Index_sys(:,2)))' .* (RHS.InsPremRev_sys - ESTIMATESUSE.MC_sys(LHS.Index_sys(:,2)) .* RHS.InsChangeIndivs_sys)...
                    + (ESTIMATESUSE.tau_sys(LHS.Index_sys(:,2)))'.*(RHS.HospCostsXDemand_sys + RHS.HospOtherInsCostXDemand_sys) + ESTIMATESUSE.residXdemand_sys; 
    disp(max(abs(temp.NewPrices_sys-temp.OldPrices_sys)));
    [temp.PricesCF temp.UpdatedIdx temp.NewPrices_sys] =  f_cf_updateprices(DATA,DATAEST, INSDEMAND, HOSPDEMAND, ESTIMATESUSE, DATAEST.premiums, FLAG, PARAM); 
    disp(max(abs(temp.NewPrices_sys-temp.OldPrices)));
    temp.newpremiums = f_cf_updatepremiums_barg(PRICES, INSDEMAND, HOSPDEMAND, ESTIMATESUSE.MC_sys, ESTIMATESUSE.rho_sys, ESTIMATESUSE.resid_sys_prem, FLAG, PARAM, DATAEST.premiums);
    disp(max(abs(temp.newpremiums(:,1)-DATAEST.premiums(:,1))));
    
%% :: BASELINE SUMMARY STATISTICS::
    [LHS, RHS] = f_construct_LHSRHS(DATA, DATAEST, PRICES, INSDEMAND, HOSPDEMAND,  DATAEST.premiums, FLAG, PARAM);    
    %Number of hospitals/systems on each insurer
    BASELINE.NumHospsAndSys = [sum(LHS.Index(:,2)==1) sum(LHS.Index(:,2)==2); 0  0];
    BASELINE.NumTotalHospSysByHSA = zeros(14,2);   %All hospitals
    BASELINE.NumHospSysByHSA = zeros(14,2);        %only hospitals in sample (>10 adm, nonzero hosp demand)
    for idxhsa=1:14
        for idxins=1:2
            for idxsys = 1:length(DATA{idxhsa}.uniquesysids)
               temp.sysid = DATA{idxhsa}.uniquesysids(idxsys);
                BASELINE.NumTotalHospSysByHSA(idxhsa,idxins) =  (sum( (DATA{idxhsa}.listsysid==temp.sysid).*DATA{idxhsa}.ison(:,idxins) ) > 0); 
            end;
            BASELINE.NumHospSysByHSA(idxhsa,idxins) = sum( (LHS.Index_sys(:,1)==idxhsa).* (LHS.Index_sys(:,2)==idxins) );            
            BASELINE.NumHospsAndSys(2,idxins) = BASELINE.NumHospsAndSys(2,idxins) + BASELINE.NumHospSysByHSA(idxhsa,idxins);            
        end;
    end;
    %Hospital Prices and Costs on each insurer
    BASELINE.HospPricesAndCosts = [mean(LHS.Price((LHS.Index(:,2)==1))) mean(LHS.Price((LHS.Index(:,2)==2))); ...
                                mean(RHS.HospCosts((LHS.Index(:,2)==1))) mean(RHS.HospCosts((LHS.Index(:,2)==2)))];
    %Hospital Systems on each insurer by HSA
    for idxhsa=1:14
        for idxins=1:2
            BASELINE.HospSysAdmits{idxhsa}{idxins} = [];
        end;
    end;        
    %Admissions By System
    temp.alladmits{1} = [];
    temp.alladmits{2} = [];
    for idxentry = 1:length(LHS.Index_sys)
        idxhsa = LHS.Index_sys(idxentry,1);
        idxins = LHS.Index_sys(idxentry,2);
        idxsys = LHS.Index_sys(idxentry,3);
        temp.nadmits = DATA{idxhsa}.nadmits(:,idxins);
        temp.nadmits(isnan(temp.nadmits)) = 0;
        temp.nadmitssys = sum( ( DATA{idxhsa}.listsysid == idxsys ) .* temp.nadmits );
        temp.nadmitssys_ison = sum( ( DATA{idxhsa}.listsysid == idxsys ) .* temp.nadmits .* DATA{idxhsa}.ison(:,idxins) );
        BASELINE.HospSysAdmits{idxhsa}{idxins} = [ BASELINE.HospSysAdmits{idxhsa}{idxins}; idxsys temp.nadmitssys ];
        temp.alladmits{idxins} = [temp.alladmits{idxins}; idxhsa idxsys temp.nadmitssys]; 
    end;
    %HHI Admission Calc
    BASELINE.HospSysHHIByHSA = zeros(15,2);
    for idxins=1:2
        temp.totalnadmits = 0;
        for idxhsa=1:14
            temp.mktshare = BASELINE.HospSysAdmits{idxhsa}{idxins}(:,2) ./ sum(BASELINE.HospSysAdmits{idxhsa}{idxins}(:,2));
            BASELINE.HospSysHHIByHSA(idxhsa,idxins) = sum( (temp.mktshare*100).^2);            
        end;
        BASELINE.HospSysHHIByHSA(15,idxins) = 0;
            %If account for cross-HSA system membership
            temp.uniquesysidsCA = unique(temp.alladmits{idxins}(:,2));
            temp.allCAadmits = sum(temp.alladmits{idxins}(:,3));
            for idxsys = 1:length(temp.uniquesysidsCA)
                sysid = temp.uniquesysidsCA(idxsys);
                temp.sysCAadmits = sum( ( temp.alladmits{idxins}(:,2) == sysid ).* temp.alladmits{idxins}(:,3) ) ;
                BASELINE.HospSysHHIByHSA(15,idxins) = BASELINE.HospSysHHIByHSA(15,idxins) + ((temp.sysCAadmits / temp.allCAadmits)*100)^2;
            end;
    end;  
    
    
%% PRICE DECOMPOSITION                            
    % NO SYSTEM BARGAINING ======================
        for idxentry=1:length(LHS.Index)
            idxhsa=LHS.Index(idxentry,1);
            idxins=LHS.Index(idxentry,2);
            idxhosp=LHS.Index(idxentry,3);
            tau_M = ESTIMATESUSE.tau;
            tau_H = 1-tau_M;
            MCUSE = ESTIMATESUSE.MC;
            
            BASELINE.TermIa_PremEffect(idxentry,:) = tau_H(idxins) * [ 0 ];
            BASELINE.TermIb_HHEnrollEffect(idxentry,:) = tau_H(idxins) *  [  DATAEST.premiums(idxins,:) * (RHS.InsDemandChange(idxentry,:)/LHS.HospDemand(idxentry))' ];
            BASELINE.TermIc_IndEnrollEffect(idxentry,:) = - tau_H(idxins)  * MCUSE(idxins) *  [ RHS.InsChangeIndivs(idxentry)/LHS.HospDemand(idxentry)  ];
            BASELINE.TermII_PriceReinforcementEffect(idxentry,:) = - tau_H(idxins)  *  [ RHS.InsOtherHospPmts(idxentry)/LHS.HospDemand(idxentry)];
            BASELINE.TermIII_HospCostEffect(idxentry,:) = tau_M(idxins)  *  [ RHS.HospCostsXDemand(idxentry)/LHS.HospDemand(idxentry)];
            BASELINE.TermIV_RecaptureEffect(idxentry,:) = - tau_M(idxins) *  [ RHS.HospOtherInsMarginXDemand(idxentry)/LHS.HospDemand(idxentry)];
            BASELINE.hospprices(idxentry,:) = [LHS.Price(idxentry)];
            BASELINE.Resid(idxentry,:) = [ESTIMATESUSE.resid(idxentry)];
            BASELINE.HospDemand(idxentry,:) = [LHS.HospDemand(idxentry)];          
        end;
        for idxins=1:2 %Decomposition by Insurer
            %Baseline only for All HSAs    
            temp.weights = LHS.HospDemand;
            temp.weights(LHS.Index(:,2)~=idxins,:) = 0;   %zero out entries for other insurer
            temp.weights = temp.weights ./ (repmat(sum(temp.weights,1),length(temp.weights),1));
            idxweight = 1;
            temp.price1 = sum(temp.weights(:,idxweight).*BASELINE.hospprices(:,1)); 
            temp.effect1a = sum((BASELINE.TermIa_PremEffect(:,1)).*temp.weights(:,idxweight)./temp.price1);
            temp.effect1b = sum( (BASELINE.TermIb_HHEnrollEffect(:,1)).*temp.weights(:,idxweight)./temp.price1);
            temp.effect1c = sum( (BASELINE.TermIc_IndEnrollEffect(:,1)).*temp.weights(:,idxweight)./temp.price1);
            temp.effect2 = sum( (BASELINE.TermII_PriceReinforcementEffect(:,1)).*temp.weights(:,idxweight)./temp.price1);
            temp.effect3 = sum( (BASELINE.TermIII_HospCostEffect(:,1)).*temp.weights(:,idxweight)./temp.price1);
            temp.effect4 = sum( (BASELINE.TermIV_RecaptureEffect(:,1)).*temp.weights(:,idxweight)./temp.price1);   
            temp.effect5 = sum( (BASELINE.Resid(:,1)).*temp.weights(:,idxweight)./temp.price1);   
            BASELINE.Decomp_Summary{idxins} = [temp.price1 ...
                                                          temp.effect1a+temp.effect1b+temp.effect1c, temp.effect2, temp.effect3, temp.effect4, temp.effect5]; 
        end;
        BASELINE.Decomp_All = [LHS.Index, BASELINE.HospDemand, BASELINE.hospprices, BASELINE.TermIb_HHEnrollEffect, BASELINE.TermIc_IndEnrollEffect, BASELINE.TermII_PriceReinforcementEffect, BASELINE.TermIII_HospCostEffect, BASELINE.TermIV_RecaptureEffect, BASELINE.Resid,  BASELINE.Resid./BASELINE.hospprices];    

    % SYSTEM BARGAINING STATS ======================
    for idxboot = 1:PARAM.NumBootstrap
        
        ESTIMATESUSE = ESTIMATES{idxboot};
        for idxhsa=1:14
            PRICES{idxhsa}.avgamtdrg = DATA{idxhsa}.avgamtdrg_boot{idxboot};
        end;    
        [LHS, RHS] = f_construct_LHSRHS(DATA, DATAEST, PRICES, INSDEMAND, HOSPDEMAND, DATAEST.premiums, FLAG, PARAM);    
     
            for idxentry=1:length(LHS.Index_sys)
                idxhsa=LHS.Index_sys(idxentry,1);
                idxins=LHS.Index_sys(idxentry,2);
                idxhosp=LHS.Index_sys(idxentry,3);
                tau_M = ESTIMATESUSE.tau_sys;
                tau_H = 1-tau_M;
                MCUSE = ESTIMATESUSE.MC_sys;
                BASELINE_sys.TermIa_PremEffect(idxentry,:) = tau_H(idxins) * [ 0 ];
                BASELINE_sys.TermIb_HHEnrollEffect(idxentry,:) = tau_H(idxins) *  [  DATAEST.premiums(idxins,:) * (RHS.InsDemandChange_sys(idxentry,:)/LHS.HospDemand_sys(idxentry))' ];
                BASELINE_sys.TermIc_IndEnrollEffect(idxentry,:) = - tau_H(idxins)  * MCUSE(idxins) *  [ RHS.InsChangeIndivs_sys(idxentry)/LHS.HospDemand_sys(idxentry)  ];
                BASELINE_sys.TermII_PriceReinforcementEffect(idxentry,:) = - tau_H(idxins)  *  [ RHS.InsOtherHospPmts_sys(idxentry)/LHS.HospDemand_sys(idxentry)];
                BASELINE_sys.TermIII_HospCostEffect(idxentry,:) = tau_M(idxins)  *  [ RHS.HospCostsXDemand_sys(idxentry)/LHS.HospDemand_sys(idxentry)];
                BASELINE_sys.TermIV_RecaptureEffect(idxentry,:) = - tau_M(idxins) *  [ RHS.HospOtherInsMarginXDemand_sys(idxentry)/LHS.HospDemand_sys(idxentry)];
                BASELINE_sys.hospprices(idxentry,:) = [LHS.PriceXDemand_sys(idxentry)/LHS.HospDemand_sys(idxentry)];   %AVERAGE HOSPITAL PRICES WITHIN SYSTEMS
                BASELINE_sys.Resid(idxentry,:) = [ESTIMATESUSE.resid_sys(idxentry)];
                BASELINE_sys.HospDemand(idxentry,:) = [LHS.HospDemand_sys(idxentry)];          
            end;
            for idxins=1:2 %Decomposition by Insurer
                %Baseline only for All HSAs    
                temp.weights = LHS.HospDemand_sys;
                temp.weights(LHS.Index_sys(:,2)~=idxins,:) = 0;   %zero out entries for other insurer
                temp.weights = temp.weights ./ (repmat(sum(temp.weights,1),length(temp.weights),1));
                idxweight = 1;
                temp.price1 = sum(temp.weights(:,idxweight).*BASELINE_sys.hospprices(:,1)); 
                temp.price1_noresid = sum(temp.weights(:,idxweight).*(BASELINE_sys.hospprices(:,1) - BASELINE_sys.Resid(:,1))); 
                temp.effect1a = sum((BASELINE_sys.TermIa_PremEffect(:,1)).*temp.weights(:,idxweight)./temp.price1_noresid);
                temp.effect1b = sum( (BASELINE_sys.TermIb_HHEnrollEffect(:,1)).*temp.weights(:,idxweight)./temp.price1_noresid);
                temp.effect1c = sum( (BASELINE_sys.TermIc_IndEnrollEffect(:,1)).*temp.weights(:,idxweight)./temp.price1_noresid);
                temp.effect2 = sum( (BASELINE_sys.TermII_PriceReinforcementEffect(:,1)).*temp.weights(:,idxweight)./temp.price1_noresid);
                temp.effect3 = sum( (BASELINE_sys.TermIII_HospCostEffect(:,1)).*temp.weights(:,idxweight)./temp.price1_noresid);
                temp.effect4 = sum( (BASELINE_sys.TermIV_RecaptureEffect(:,1)).*temp.weights(:,idxweight)./temp.price1_noresid);   
                
                %temp.effect5 = sum( (BASELINE_sys.Resid(:,1)).*temp.weights(:,idxweight)./temp.price1);   
                BASELINE_sys.Decomp_Summary{idxins} = [temp.price1 ...
                                                              temp.effect1a+temp.effect1b+temp.effect1c, temp.effect2, temp.effect3, temp.effect4];%, temp.effect5]; 
            end;
            BASELINE_sys.Decomp_All = [LHS.Index_sys, BASELINE_sys.HospDemand, BASELINE_sys.hospprices, BASELINE_sys.TermIb_HHEnrollEffect, BASELINE_sys.TermIc_IndEnrollEffect, BASELINE_sys.TermII_PriceReinforcementEffect, BASELINE_sys.TermIII_HospCostEffect, BASELINE_sys.TermIV_RecaptureEffect, BASELINE_sys.Resid,  BASELINE_sys.Resid./BASELINE_sys.hospprices];

            %PROFITS
            BASELINE_sys.Profits_Insurer = zeros(1,3);
            BASELINE_sys.TotalEnrollees = zeros(1,3);
            for idxins=1:3
                for idxhsa=1:14
                    temp.hsaprofits = sum(INSDEMAND{idxhsa}.fam(idxins,:,1).*DATAEST.premiums(idxins,:)) - INSDEMAND{idxhsa}.ind(idxins,1) * ESTIMATESUSE.MC_sys(idxins);
                    if idxins<3
                        temp.hsaprofits = temp.hsaprofits -  sum( PRICES{idxhsa}.avgamtdrg(:,idxins) .* HOSPDEMAND{idxhsa}.indXdrg(:,idxins,1));                
                    end;
                    BASELINE_sys.TotalEnrollees(idxins) = BASELINE_sys.TotalEnrollees(idxins) +  INSDEMAND{idxhsa}.ind(idxins,1);
                    BASELINE_sys.Profits_Insurer(idxins) = BASELINE_sys.Profits_Insurer(idxins) +  temp.hsaprofits;
                end;
                BASELINE_sys.Profits_Insurer(idxins) = BASELINE_sys.Profits_Insurer(idxins) / BASELINE_sys.TotalEnrollees(idxins);
            end;
        BASELINE_sysboot{idxboot} = BASELINE_sys;
    end; %for idxboot
    
    for idxins=1:2
        temp.Decomp_Summary{idxins} = [];
        for idxboot=1:PARAM.NumBootstrap
            temp.Decomp_Summary{idxins} = [temp.Decomp_Summary{idxins}; BASELINE_sysboot{idxboot}.Decomp_Summary{idxins}];
        end;
        temp.Decomp_Summary{idxins} = sort(temp.Decomp_Summary{idxins});
        BASELINE.Decomp_Summary{idxins} = [BASELINE_sysboot{1}.Decomp_Summary{idxins}(1,:); temp.Decomp_Summary{idxins}(1+PARAM.NumBootstrap*.025,:); temp.Decomp_Summary{idxins}(PARAM.NumBootstrap*.975,:)];
    end;
    
    save(['M_EST',PARAM.FileSuffix], 'BASELINE', 'BASELINE_sysboot', '-append');