%% Construct Summary Statistics

clear;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%SET THESE PARAMETERS
PARAM.Date=20160621;
FLAG.PremSetting_MatchMargins = 0;
    
    %ROBUSTNESS
    FLAG.PremSetting_MatchMarginsProbDrop = 0;
    FLAG.PremSetting_FixedPremMarkup = 0;
    FLAG.BC10PercentMargin = 0;
    FLAG.AlternatePremiumSettingError = 0;
    FLAG.UseSwitchingCosts = 0;
    FLAG.AdjustWTPCoeff = 0;
    
PARAM.FixedPremMLR = .80;
PARAM.SwitchingCosts = .9;
PARAM.AdjustWTPCoeff = 1.25;
PARAM.FileSuffix=f_filesuffix(FLAG,PARAM);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

load M_DATA_20160523.mat;
load M_DATAHH_20160523.mat;     
load (['M_InitDemand',PARAM.FileSuffix]);
load(['M_EST',PARAM.FileSuffix]);

PARAM.NumBootstrap=80;

disp(['Computing CF Summary Stats for M_CF',PARAM.FileSuffix]);

%% :: CF SUMMARY STATISTICS :: HOSPITAL SYSTEMS
    load(['M_CFsys',PARAM.FileSuffix]);
    FLAG.HospitalSystemRegression=1; 
        
    %% BOOTSTRAP   
    for idxboot=1:PARAM.NumBootstrap
        fprintf('BOOT #%f ================================ \n', idxboot);  
        CF_sys = CFBOOTsys{idxboot};
        
        %INITIALIZE BOOTSTRAP PRICES AND ESTIMATES
        ESTIMATESUSE = ESTIMATES{idxboot};
        
        idxBaseline = 7;
        LHS = CF_sys{idxBaseline}.LHS;
        RHS = CF_sys{idxBaseline}.RHS;
        PRICES = CF_sys{idxBaseline}.PRICES;
        INSDEMAND = CF_sys{idxBaseline}.INSDEMAND;
        HOSPDEMAND = CF_sys{idxBaseline}.HOSPDEMAND;
        PREMIUMS = CF_sys{idxBaseline}.premiums;
               
        for idxInsRemoved = 1:3
            %1: CF1-3, remove BC  
            %2: CF4-6, remove K

            if idxInsRemoved<3
                temp.Index = CF_sys{idxInsRemoved*3}.LHS.Index_sys;
                idxCF_1 = (idxInsRemoved-1)*3 +1;    %Adjust Prices, Fix premiums
                idxCF_2 = (idxInsRemoved-1)*3 +2;    %Fix Prices, Adjust Premiums
                idxCF_3 = (idxInsRemoved-1)*3 +3;    %Adjust Prices, Adjust Premiums
            else
                temp.Index = CF_sys{7}.LHS.Index_sys;
                idxCF_1 = 7;
                idxCF_2 = 7;
                idxCF_3 = 7;
            end;

            STATS_sys{idxInsRemoved}.hospdemand = zeros(length(temp.Index), 3);       %For each hospital with updated prices, report Baseline, CF1/4, CF3/6
            STATS_sys{idxInsRemoved}.hospdemandXdrg = zeros(length(temp.Index), 3);      
            STATS_sys{idxInsRemoved}.hospprices = zeros(length(temp.Index), 3);      
            STATS_sys{idxInsRemoved}.hosppmts = zeros(length(temp.Index), 3);      
            STATS_sys{idxInsRemoved}.dWTP = zeros(length(temp.Index),1);
            for idxentry=1:length(temp.Index)
                idxhsa=temp.Index(idxentry,1);
                idxins=temp.Index(idxentry,2);
                idxsys=temp.Index(idxentry,3);
                tau_M = ESTIMATESUSE.tau_sys(idxins);
                tau_H = 1-tau_M;
                MCUSE = ESTIMATESUSE.MC_sys;            

                idxOldEntry = strmatch([idxhsa idxins idxsys], LHS.Index_sys);

                STATS_sys{idxInsRemoved}.hospprices(idxentry,:) = [LHS.PriceXDemand_sys(idxOldEntry) / LHS.HospDemand_sys(idxOldEntry), ...
                                                                   CF_sys{idxCF_1}.LHS.PriceXDemand_sys(idxentry) / CF_sys{idxCF_1}.LHS.HospDemand_sys(idxentry), ...
                                                                   CF_sys{idxCF_3}.LHS.PriceXDemand_sys(idxentry) / CF_sys{idxCF_3}.LHS.HospDemand_sys(idxentry)];
                STATS_sys{idxInsRemoved}.hospdemandXdrg(idxentry,:) = [LHS.HospDemand_sys(idxOldEntry), ...
                                                                   CF_sys{idxCF_1}.LHS.HospDemand_sys(idxentry), ...
                                                                   CF_sys{idxCF_3}.LHS.HospDemand_sys(idxentry)];
                STATS_sys{idxInsRemoved}.hospdemand(idxentry,:) = STATS_sys{idxInsRemoved}.hospdemandXdrg(idxentry,:);

                STATS_sys{idxInsRemoved}.hosppmts(idxentry,:) = STATS_sys{idxInsRemoved}.hospdemandXdrg(idxentry,:) .* STATS_sys{idxInsRemoved}.hospprices(idxentry,:);

                STATS_sys{idxInsRemoved}.dWTP(idxentry) = 0; %DATAEST.dWTP{idxhsa}(idxsys,idxins);

                STATS_sys{idxInsRemoved}.TermI_PremHHEffect(idxentry,:) = tau_H * [ ( CF_sys{idxCF_1}.RHS.InsPremRev_sys(idxentry,:) / CF_sys{idxCF_1}.LHS.HospDemand_sys(idxentry))' - (RHS.InsPremRev_sys(idxOldEntry,:)/LHS.HospDemand_sys(idxOldEntry))' , ...                       
                                                                                           ( CF_sys{idxCF_3}.RHS.InsPremRev_sys(idxentry,:) / CF_sys{idxCF_3}.LHS.HospDemand_sys(idxentry))' - (RHS.InsPremRev_sys(idxOldEntry,:)/LHS.HospDemand_sys(idxOldEntry))'];
                STATS_sys{idxInsRemoved}.TermIa_PremEffect(idxentry,:) = tau_H * [ ( CF_sys{idxCF_1}.premiums(idxins,:) - PREMIUMS(idxins,:) ) * (RHS.InsDemandChange_sys(idxOldEntry,:) / LHS.HospDemand_sys(idxOldEntry))' , ...
                                                                                          ( CF_sys{idxCF_3}.premiums(idxins,:) - PREMIUMS(idxins,:) ) * (RHS.InsDemandChange_sys(idxOldEntry,:) / LHS.HospDemand_sys(idxOldEntry))' ];                                                             
                STATS_sys{idxInsRemoved}.TermIb_HHEnrollEffect(idxentry,:) = tau_H *  [ CF_sys{idxCF_1}.premiums(idxins,:) * ( CF_sys{idxCF_1}.RHS.InsDemandChange_sys(idxentry,:) / CF_sys{idxCF_1}.LHS.HospDemand_sys(idxentry) - (RHS.InsDemandChange_sys(idxOldEntry,:)/LHS.HospDemand_sys(idxOldEntry)) )' , ...
                                                                                               CF_sys{idxCF_3}.premiums(idxins,:) * ( CF_sys{idxCF_3}.RHS.InsDemandChange_sys(idxentry,:) / CF_sys{idxCF_3}.LHS.HospDemand_sys(idxentry) - (RHS.InsDemandChange_sys(idxOldEntry,:)/LHS.HospDemand_sys(idxOldEntry)) )' ];
                STATS_sys{idxInsRemoved}.TermIc_IndEnrollEffect(idxentry,:) = - tau_H* MCUSE(idxins) *  [ CF_sys{idxCF_1}.RHS.InsChangeIndivs_sys(idxentry)/ CF_sys{idxCF_1}.LHS.HospDemand_sys(idxentry) - RHS.InsChangeIndivs_sys(idxOldEntry)/LHS.HospDemand_sys(idxOldEntry)  , ...
                                                                                                                             CF_sys{idxCF_3}.RHS.InsChangeIndivs_sys(idxentry)/ CF_sys{idxCF_3}.LHS.HospDemand_sys(idxentry) - RHS.InsChangeIndivs_sys(idxOldEntry)/LHS.HospDemand_sys(idxOldEntry)  ];
                STATS_sys{idxInsRemoved}.TermII_PriceReinforcementEffect(idxentry,:) = -tau_H *  [ CF_sys{idxCF_1}.RHS.InsOtherHospPmts_sys(idxentry)/CF_sys{idxCF_1}.LHS.HospDemand_sys(idxentry) - RHS.InsOtherHospPmts_sys(idxOldEntry)/LHS.HospDemand_sys(idxOldEntry),...
                                                                                                           CF_sys{idxCF_3}.RHS.InsOtherHospPmts_sys(idxentry)/CF_sys{idxCF_3}.LHS.HospDemand_sys(idxentry) - RHS.InsOtherHospPmts_sys(idxOldEntry)/LHS.HospDemand_sys(idxOldEntry)];
                STATS_sys{idxInsRemoved}.TermIII_HospCostEffect(idxentry,:) = tau_M *  [ CF_sys{idxCF_1}.RHS.HospCostsXDemand_sys(idxentry)/CF_sys{idxCF_1}.LHS.HospDemand_sys(idxentry) - RHS.HospCostsXDemand_sys(idxOldEntry)/LHS.HospDemand_sys(idxOldEntry),...
                                                                                                CF_sys{idxCF_3}.RHS.HospCostsXDemand_sys(idxentry)/CF_sys{idxCF_3}.LHS.HospDemand_sys(idxentry) - RHS.HospCostsXDemand_sys(idxOldEntry)/LHS.HospDemand_sys(idxOldEntry)];
                STATS_sys{idxInsRemoved}.TermIV_RecaptureEffect(idxentry,:) = - tau_M *  [ CF_sys{idxCF_1}.RHS.HospOtherInsMarginXDemand_sys(idxentry)/CF_sys{idxCF_1}.LHS.HospDemand_sys(idxentry) - RHS.HospOtherInsMarginXDemand_sys(idxOldEntry)/LHS.HospDemand_sys(idxOldEntry),...
                                                                                                CF_sys{idxCF_3}.RHS.HospOtherInsMarginXDemand_sys(idxentry)/CF_sys{idxCF_3}.LHS.HospDemand_sys(idxentry) - RHS.HospOtherInsMarginXDemand_sys(idxOldEntry)/LHS.HospDemand_sys(idxOldEntry)];
            end;

            STATS_sys{idxInsRemoved}.premiums = [PREMIUMS; CF_sys{idxCF_2}.premiums;  CF_sys{idxCF_3}.premiums];
            STATS_sys{idxInsRemoved}.insenrollment = zeros(9, 3);
            for idxhsa=1:14
                STATS_sys{idxInsRemoved}.insenrollment = STATS_sys{idxInsRemoved}.insenrollment + [INSDEMAND{idxhsa}.fam(:,:,1); CF_sys{idxCF_2}.INSDEMAND{idxhsa}.fam(:,:,1); CF_sys{idxCF_3}.INSDEMAND{idxhsa}.fam(:,:,1)];
            end;
            STATS_sys{idxInsRemoved}.prems_and_insenroll= [STATS_sys{idxInsRemoved}.premiums; STATS_sys{idxInsRemoved}.insenrollment];

            %**************************************************************
            %SUMMARY RESULTS FOR ALL HOSPITALS ****************************
            %**************************************************************            
            STATS_sys{idxInsRemoved}.HospFull = [temp.Index(:,1:3), STATS_sys{idxInsRemoved}.hospprices, (STATS_sys{idxInsRemoved}.hospprices(:,3)-STATS_sys{idxInsRemoved}.hospprices(:,1))./STATS_sys{idxInsRemoved}.hospprices(:,1), ...
                                             STATS_sys{idxInsRemoved}.hospdemand, STATS_sys{idxInsRemoved}.hosppmts, STATS_sys{idxInsRemoved}.dWTP];
            STATS_sys{idxInsRemoved}.HospFull_Decomp = [ STATS_sys{idxInsRemoved}.TermIa_PremEffect, STATS_sys{idxInsRemoved}.TermIb_HHEnrollEffect + STATS_sys{idxInsRemoved}.TermIc_IndEnrollEffect, ...
                                                    STATS_sys{idxInsRemoved}.TermII_PriceReinforcementEffect, STATS_sys{idxInsRemoved}.TermIII_HospCostEffect, STATS_sys{idxInsRemoved}.TermIV_RecaptureEffect];
            STATS_sys{idxInsRemoved}.HospFull = [STATS_sys{idxInsRemoved}.HospFull STATS_sys{idxInsRemoved}.HospFull_Decomp];

           % Breakdown Results by All and HSA, holding FIXED admission weights under baseline.
            for idxins=1:2
                STATS_sys{idxInsRemoved}.PriceComparisons_FixPremiums{idxins} = [];
                STATS_sys{idxInsRemoved}.PriceComparisons_AdjustPremiums{idxins} = [];    
                for idxhsa=0:14    
                    %weight by share of hospital admissions UNDER BASELINE
                    temp.weights = STATS_sys{idxInsRemoved}.hospdemand;
                    temp.weights(temp.Index(:,2)~=idxins,:) = 0;   %zero out entries for other insurer
                    if idxhsa>0   %zero out non-HSA entries
                        temp.weights(temp.Index(:,1)~=idxhsa,:) = 0;
                    end;
                    temp.weights = temp.weights ./ (repmat(sum(temp.weights,1),length(temp.weights),1));
                    idxweight = 1;

                    %Summary Table: Price changes and decomposition, adjusting
                    %premiums
                    temp.price1 = sum(temp.weights(:,idxweight).*STATS_sys{idxInsRemoved}.hospprices(:,1));
                    temp.price2 = sum(temp.weights(:,idxweight).*STATS_sys{idxInsRemoved}.hospprices(:,3));
                    temp.pricechange = STATS_sys{idxInsRemoved}.hospprices(:,3) - STATS_sys{idxInsRemoved}.hospprices(:,1);
                    temp.pricechange = 1;  %Report levels of effects, not percent of effect
                    temp.effect1a = sum((STATS_sys{idxInsRemoved}.TermIa_PremEffect(:,2)./ temp.pricechange).*temp.weights(:,idxweight));
                    temp.effect1b = sum( (STATS_sys{idxInsRemoved}.TermIb_HHEnrollEffect(:,2)./ temp.pricechange).*temp.weights(:,idxweight));
                    temp.effect1c = sum( (STATS_sys{idxInsRemoved}.TermIc_IndEnrollEffect(:,2)./ temp.pricechange).*temp.weights(:,idxweight));
                    temp.effect2 = sum( (STATS_sys{idxInsRemoved}.TermII_PriceReinforcementEffect(:,2)./ temp.pricechange).*temp.weights(:,idxweight));
                    temp.effect3 = sum( (STATS_sys{idxInsRemoved}.TermIII_HospCostEffect(:,2)./ temp.pricechange).*temp.weights(:,idxweight));
                    temp.effect4 = sum( (STATS_sys{idxInsRemoved}.TermIV_RecaptureEffect(:,2)./ temp.pricechange).*temp.weights(:,idxweight));
                    %temp.effect5 = sum( (STATS{idxInsRemoved}.TermV_ResidualEffect(:,2)./ temp.pricechange).*temp.weights(:,idxweight));
                    STATS_sys{idxInsRemoved}.PriceComparisons_AdjustPremiums{idxins} = [STATS_sys{idxInsRemoved}.PriceComparisons_AdjustPremiums{idxins}; idxhsa temp.price1 temp.price2 (temp.price2-temp.price1)/temp.price1...
                                                                            temp.effect1a temp.effect1b+temp.effect1c temp.effect2  temp.effect3   temp.effect4]; 

                    %Summary Table: Price changes and decomposition, fixing premiums                                                    
                    temp.price1 = sum(temp.weights(:,idxweight).*STATS_sys{idxInsRemoved}.hospprices(:,1));
                    temp.price2 = sum(temp.weights(:,idxweight).*STATS_sys{idxInsRemoved}.hospprices(:,2));
                    temp.pricechange = STATS_sys{idxInsRemoved}.hospprices(:,2) - STATS_sys{idxInsRemoved}.hospprices(:,1);
                    temp.pricechange(temp.pricechange==0) = .01;
                    temp.pricechange = 1;  %Report levels of effects, not percent of net effect
                    temp.effect1a = sum((STATS_sys{idxInsRemoved}.TermIa_PremEffect(:,1)./ temp.pricechange).*temp.weights(:,idxweight));
                    temp.effect1b = sum( (STATS_sys{idxInsRemoved}.TermIb_HHEnrollEffect(:,1)./ temp.pricechange).*temp.weights(:,idxweight));
                    temp.effect1c = sum( (STATS_sys{idxInsRemoved}.TermIc_IndEnrollEffect(:,1)./ temp.pricechange).*temp.weights(:,idxweight));
                    temp.effect2 = sum( (STATS_sys{idxInsRemoved}.TermII_PriceReinforcementEffect(:,1)./ temp.pricechange).*temp.weights(:,idxweight));
                    temp.effect3 = sum( (STATS_sys{idxInsRemoved}.TermIII_HospCostEffect(:,1)./ temp.pricechange).*temp.weights(:,idxweight));
                    temp.effect4 = sum( (STATS_sys{idxInsRemoved}.TermIV_RecaptureEffect(:,1)./ temp.pricechange).*temp.weights(:,idxweight));
                    %temp.effect5 = sum( (STATS{idxInsRemoved}.TermV_ResidualEffect(:,1)./ temp.pricechange).*temp.weights(:,idxweight));
                    STATS_sys{idxInsRemoved}.PriceComparisons_FixPremiums{idxins} = [STATS_sys{idxInsRemoved}.PriceComparisons_FixPremiums{idxins}; idxhsa temp.price1 temp.price2 (temp.price2-temp.price1)/temp.price1...
                                                                            temp.effect1a, temp.effect1b+temp.effect1c, temp.effect2,temp.effect3, temp.effect4]; 
                end;
            end;
            STATS_sys{idxInsRemoved}.PriceComparisonsAll = [STATS_sys{idxInsRemoved}.PriceComparisons_AdjustPremiums{1}; STATS_sys{idxInsRemoved}.PriceComparisons_FixPremiums{1};...
                                                            STATS_sys{idxInsRemoved}.PriceComparisons_AdjustPremiums{2}; STATS_sys{idxInsRemoved}.PriceComparisons_FixPremiums{2}];
                                                        
            %Breakdown results by ALL and HSA, allowing admission weights to VARY across baseline.
            for idxins=1:2
                STATS_sys{idxInsRemoved}.PriceComparisons_AdjustWeights{idxins} = [];
                for idxhsa=0:14
                    temp.weights = STATS_sys{idxInsRemoved}.hospdemand;
                    temp.weights(temp.Index(:,2)~=idxins,:) = 0;   %zero out entries for other insurer
                    if idxhsa>0   %zero out non-HSA entries
                        temp.weights(temp.Index(:,1)~=idxhsa,:) = 0;
                    end;
                    for idxcol=1:3
                        temp.weights(:,idxcol) = temp.weights(:,idxcol) / (sum(temp.weights(:,idxcol)));
                    end;                    
                    %Summary Table: Price changes and decomposition, fixing and adjusting premiums                                                    
                    temp.price1 = sum(temp.weights(:,1).*STATS_sys{idxInsRemoved}.hospprices(:,1));
                    temp.price2_fixprem = sum(temp.weights(:,2).*STATS_sys{idxInsRemoved}.hospprices(:,2));
                    temp.price2_adjprem = sum(temp.weights(:,3).*STATS_sys{idxInsRemoved}.hospprices(:,3));
                    STATS_sys{idxInsRemoved}.PriceComparisons_AdjustWeights{idxins} = [STATS_sys{idxInsRemoved}.PriceComparisons_AdjustWeights{idxins}; idxhsa temp.price1 temp.price2_fixprem (temp.price2_fixprem-temp.price1)/temp.price1 temp.price2_adjprem (temp.price2_adjprem-temp.price1)/temp.price1]; 
                end;
            end;                                            
            STATS_sys{idxInsRemoved}.PriceComparisonsAll_AdjustWeights = [STATS_sys{idxInsRemoved}.PriceComparisons_AdjustWeights{1}; STATS_sys{idxInsRemoved}.PriceComparisons_AdjustWeights{2}];
            
            %**************************************************************
            %WELFARE AND PROFIT CALCULATIONS ******************************
            %**************************************************************            
            STATS_sys{idxInsRemoved}.InsRevByHSA = zeros(14,3,3);
            STATS_sys{idxInsRemoved}.InsPremRevenuesByHSA = zeros(14,3,3);
            STATS_sys{idxInsRemoved}.InsHospCostsByHSA = zeros(14,2,3);
            STATS_sys{idxInsRemoved}.HospProfitsByHSA = zeros(14,2,3);
            STATS_sys{idxInsRemoved}.HospRevByHSA = zeros(14,2,3);       
            STATS_sys{idxInsRemoved}.InsTotalIndivsByHSA = zeros(14,3,3);
            STATS_sys{idxInsRemoved}.InsHospCostsPerIndivByHSA = zeros(14,3,3);
            STATS_sys{idxInsRemoved}.InsProfitsByHSA = zeros(14,3,3);
            STATS_sys{idxInsRemoved}.ConsumerWelfare = zeros(1,3);
            for idxhsa=1:14
                HospCostUse = DATA{idxhsa}.costdrg(:,PARAM.HospCostUse);
                HospCostUse(isnan(HospCostUse)==1) = 0;
                for idxins=1:3 
                    STATS_sys{idxInsRemoved}.InsRevByHSA(idxhsa,idxins,1) = sum( PREMIUMS(idxins,:) .* INSDEMAND{idxhsa}.fam(idxins,:,1) );
                    STATS_sys{idxInsRemoved}.InsRevByHSA(idxhsa,idxins,2) = sum(CF_sys{idxCF_2}.premiums(idxins,:) .* CF_sys{idxCF_2}.INSDEMAND{idxhsa}.fam(idxins,:,1) );
                    STATS_sys{idxInsRemoved}.InsRevByHSA(idxhsa,idxins,3) = sum(CF_sys{idxCF_3}.premiums(idxins,:) .* CF_sys{idxCF_3}.INSDEMAND{idxhsa}.fam(idxins,:,1) );
                    STATS_sys{idxInsRemoved}.InsPremRevenuesByHSA(idxhsa,idxins,1) = sum( PREMIUMS(idxins,:) .* INSDEMAND{idxhsa}.fam(idxins,:,1) ) - ESTIMATESUSE.MC_sys(idxins)*INSDEMAND{idxhsa}.ind(idxins,1);
                    STATS_sys{idxInsRemoved}.InsPremRevenuesByHSA(idxhsa,idxins,2) = sum(CF_sys{idxCF_2}.premiums(idxins,:) .* CF_sys{idxCF_2}.INSDEMAND{idxhsa}.fam(idxins,:,1) )  - ESTIMATESUSE.MC_sys(idxins)*CF_sys{idxCF_2}.INSDEMAND{idxhsa}.ind(idxins,1);
                    STATS_sys{idxInsRemoved}.InsPremRevenuesByHSA(idxhsa,idxins,3) = sum(CF_sys{idxCF_3}.premiums(idxins,:) .* CF_sys{idxCF_3}.INSDEMAND{idxhsa}.fam(idxins,:,1) )  - ESTIMATESUSE.MC_sys(idxins)*CF_sys{idxCF_3}.INSDEMAND{idxhsa}.ind(idxins,1);
                    if idxins < 3 
                        STATS_sys{idxInsRemoved}.InsHospCostsByHSA(idxhsa,idxins,1) = sum( PRICES{idxhsa}.avgamtdrg(:,idxins) .* HOSPDEMAND{idxhsa}.indXdrg(:,idxins,1));
                        STATS_sys{idxInsRemoved}.InsHospCostsByHSA(idxhsa,idxins,2) = sum( CF_sys{idxCF_2}.PRICES{idxhsa}.avgamtdrg(:,idxins) .* CF_sys{idxCF_2}.HOSPDEMAND{idxhsa}.indXdrg(:,idxins,1));
                        STATS_sys{idxInsRemoved}.InsHospCostsByHSA(idxhsa,idxins,3) = sum( CF_sys{idxCF_3}.PRICES{idxhsa}.avgamtdrg(:,idxins) .* CF_sys{idxCF_3}.HOSPDEMAND{idxhsa}.indXdrg(:,idxins,1));
                        STATS_sys{idxInsRemoved}.HospProfitsByHSA(idxhsa,idxins,1) = sum( ( PRICES{idxhsa}.avgamtdrg(:,idxins) - HospCostUse ).* HOSPDEMAND{idxhsa}.indXdrg(:,idxins,1));
                        STATS_sys{idxInsRemoved}.HospProfitsByHSA(idxhsa,idxins,2) = sum( ( CF_sys{idxCF_2}.PRICES{idxhsa}.avgamtdrg(:,idxins) - HospCostUse ).* CF_sys{idxCF_2}.HOSPDEMAND{idxhsa}.indXdrg(:,idxins,1));
                        STATS_sys{idxInsRemoved}.HospProfitsByHSA(idxhsa,idxins,3) = sum( ( CF_sys{idxCF_3}.PRICES{idxhsa}.avgamtdrg(:,idxins) - HospCostUse).* CF_sys{idxCF_3}.HOSPDEMAND{idxhsa}.indXdrg(:,idxins,1));                    
                        STATS_sys{idxInsRemoved}.HospRevByHSA(idxhsa,idxins,1) = sum( ( PRICES{idxhsa}.avgamtdrg(:,idxins)  ).* HOSPDEMAND{idxhsa}.indXdrg(:,idxins,1));
                        STATS_sys{idxInsRemoved}.HospRevByHSA(idxhsa,idxins,2) = sum( ( CF_sys{idxCF_2}.PRICES{idxhsa}.avgamtdrg(:,idxins) ).* CF_sys{idxCF_2}.HOSPDEMAND{idxhsa}.indXdrg(:,idxins,1));
                        STATS_sys{idxInsRemoved}.HospRevByHSA(idxhsa,idxins,3) = sum( ( CF_sys{idxCF_3}.PRICES{idxhsa}.avgamtdrg(:,idxins) ).* CF_sys{idxCF_3}.HOSPDEMAND{idxhsa}.indXdrg(:,idxins,1));                    
                    end;
                    STATS_sys{idxInsRemoved}.InsTotalIndivsByHSA(idxhsa,idxins,1) = INSDEMAND{idxhsa}.ind(idxins,1);
                    STATS_sys{idxInsRemoved}.InsTotalIndivsByHSA(idxhsa,idxins,2) = CF_sys{idxCF_2}.INSDEMAND{idxhsa}.ind(idxins,1);
                    STATS_sys{idxInsRemoved}.InsTotalIndivsByHSA(idxhsa,idxins,3) = CF_sys{idxCF_3}.INSDEMAND{idxhsa}.ind(idxins,1);

                    for idxCF=1:3
                        STATS_sys{idxInsRemoved}.InsProfitsByHSA(idxhsa,idxins,idxCF) = STATS_sys{idxInsRemoved}.InsPremRevenuesByHSA(idxhsa,idxins,idxCF);
                        if idxins<3
                            STATS_sys{idxInsRemoved}.InsProfitsByHSA(idxhsa,idxins,idxCF) = STATS_sys{idxInsRemoved}.InsProfitsByHSA(idxhsa,idxins,idxCF) - STATS_sys{idxInsRemoved}.InsHospCostsByHSA(idxhsa,idxins,idxCF);
                            if STATS_sys{idxInsRemoved}.InsTotalIndivsByHSA(idxhsa,idxins,idxCF ) > 0
                               STATS_sys{idxInsRemoved}.InsHospCostsPerIndivByHSA(idxhsa,idxins,idxCF) = STATS_sys{idxInsRemoved}.InsHospCostsByHSA(idxhsa,idxins,idxCF ) / STATS_sys{idxInsRemoved}.InsTotalIndivsByHSA(idxhsa,idxins,idxCF );
                            end;
                        end;
                    end;
                end;             
                STATS_sys{idxInsRemoved}.ConsumerWelfare = STATS_sys{idxInsRemoved}.ConsumerWelfare + [INSDEMAND{idxhsa}.totalEU CF_sys{idxCF_2}.INSDEMAND{idxhsa}.totalEU CF_sys{idxCF_3}.INSDEMAND{idxhsa}.totalEU];
            end;
            STATS_sys{idxInsRemoved}.InsRev = reshape( sum( STATS_sys{idxInsRemoved}.InsRevByHSA,1) , 3 , 3);    
            STATS_sys{idxInsRemoved}.InsPremRevenues = reshape( sum( STATS_sys{idxInsRemoved}.InsPremRevenuesByHSA,1) , 3 , 3);
            STATS_sys{idxInsRemoved}.InsHospCosts = reshape( sum( STATS_sys{idxInsRemoved}.InsHospCostsByHSA,1) , 2 , 3);  
            STATS_sys{idxInsRemoved}.HospProfits = reshape( sum( STATS_sys{idxInsRemoved}.HospProfitsByHSA,1) , 2 , 3);  
            STATS_sys{idxInsRemoved}.HospRev = reshape( sum( STATS_sys{idxInsRemoved}.HospRevByHSA,1) , 2 , 3);  
            STATS_sys{idxInsRemoved}.InsTotalIndivs = reshape( sum( STATS_sys{idxInsRemoved}.InsTotalIndivsByHSA,1) , 3 , 3);    
            STATS_sys{idxInsRemoved}.InsProfits = reshape( sum( STATS_sys{idxInsRemoved}.InsProfitsByHSA,1) , 3 , 3);    

            STATS_sys{idxInsRemoved}.InsHospCostsPerIndiv = STATS_sys{idxInsRemoved}.InsHospCosts ./ STATS_sys{idxInsRemoved}.InsTotalIndivs(1:2,:);    
            STATS_sys{idxInsRemoved}.InsProfitsPerCapitaByIns = STATS_sys{idxInsRemoved}.InsProfits ./ sum(STATS_sys{idxInsRemoved}.InsTotalIndivs(:,1));
            STATS_sys{idxInsRemoved}.InsProfitsPerCapita = sum(STATS_sys{idxInsRemoved}.InsProfitsPerCapitaByIns);
            STATS_sys{idxInsRemoved}.InsRevPerCapitaByIns = STATS_sys{idxInsRemoved}.InsRev ./ sum(STATS_sys{idxInsRemoved}.InsTotalIndivs(:,1));
            STATS_sys{idxInsRemoved}.InsRevPerCapita = sum(STATS_sys{idxInsRemoved}.InsRevPerCapitaByIns);        
            STATS_sys{idxInsRemoved}.HospProfitsPerCapita = sum(STATS_sys{idxInsRemoved}.HospProfits) ./ sum(STATS_sys{idxInsRemoved}.InsTotalIndivs(:,1));
            STATS_sys{idxInsRemoved}.HospRevPerCapita = sum(STATS_sys{idxInsRemoved}.HospRev) ./ sum(STATS_sys{idxInsRemoved}.InsTotalIndivs(:,1));       
            STATS_sys{idxInsRemoved}.ConsumerWelfarePerCapita = STATS_sys{idxInsRemoved}.ConsumerWelfare ./ sum(STATS_sys{idxInsRemoved}.InsTotalIndivs(:,1));

            STATS_sys{idxInsRemoved}.SummaryWelfare = [STATS_sys{idxInsRemoved}.InsHospCostsPerIndiv;  STATS_sys{idxInsRemoved}.InsProfitsPerCapita; STATS_sys{idxInsRemoved}.InsProfitsPerCapitaByIns;...
                                                         STATS_sys{idxInsRemoved}.HospProfitsPerCapita; STATS_sys{idxInsRemoved}.ConsumerWelfarePerCapita];
            STATS_sys{idxInsRemoved}.Margins = [  STATS_sys{idxInsRemoved}.InsProfitsPerCapita(1), STATS_sys{idxInsRemoved}.HospProfitsPerCapita(1);...
                                                  STATS_sys{idxInsRemoved}.InsRevPerCapita(1), STATS_sys{idxInsRemoved}.HospRevPerCapita(1);...
                                                  STATS_sys{idxInsRemoved}.InsProfitsPerCapita(1)/STATS_sys{idxInsRemoved}.InsRevPerCapita(1), STATS_sys{idxInsRemoved}.HospProfitsPerCapita(1) / STATS_sys{idxInsRemoved}.HospRevPerCapita(1)  ];
        end; %for idxinsremoved

        %ENROLLMENT FOR KAISER CF
        for idxCF=1:2
            BSBC_Enrollment{idxCF}=zeros(14,6);
            for idxhsa=1:14
                BSBC_Enrollment{idxCF}(idxhsa,1) = sum(INSDEMAND{idxhsa}.ind(1,:,1));
                BSBC_Enrollment{idxCF}(idxhsa,2) = sum(CF_sys{1,idxCF*3}.INSDEMAND{idxhsa}.ind(1,:,1));
                BSBC_Enrollment{idxCF}(idxhsa,3) = (BSBC_Enrollment{idxCF}(idxhsa,2)-BSBC_Enrollment{idxCF}(idxhsa,1))/BSBC_Enrollment{idxCF}(idxhsa,1);
                BSBC_Enrollment{idxCF}(idxhsa,4) = sum(INSDEMAND{idxhsa}.ind(2,:,1));
                BSBC_Enrollment{idxCF}(idxhsa,5) = sum(CF_sys{1,idxCF*3}.INSDEMAND{idxhsa}.ind(2,:,1));
                BSBC_Enrollment{idxCF}(idxhsa,6) = (BSBC_Enrollment{idxCF}(idxhsa,2)-BSBC_Enrollment{idxCF}(idxhsa,1))/BSBC_Enrollment{idxCF}(idxhsa,1);
            end;
        end;
        for idxInsRemoved=1:2
            STATS_sys{idxInsRemoved}.BSBC_EnrollmentChange=zeros(14,6);
            for idxhsa=1:14
                STATS_sys{idxInsRemoved}.BSBC_EnrollmentChange(idxhsa,1) = sum(INSDEMAND{idxhsa}.ind(1,:,1));
                STATS_sys{idxInsRemoved}.BSBC_EnrollmentChange(idxhsa,2) = sum(INSDEMAND{idxhsa}.ind(2,:,1));
                STATS_sys{idxInsRemoved}.BSBC_EnrollmentChange(idxhsa,3) = sum(INSDEMAND{idxhsa}.ind(3,:,1));
                STATS_sys{idxInsRemoved}.BSBC_EnrollmentChange(idxhsa,4) = sum(CF_sys{1,idxCF*3}.INSDEMAND{idxhsa}.ind(1,:,1));
                STATS_sys{idxInsRemoved}.BSBC_EnrollmentChange(idxhsa,5) = (STATS_sys{idxInsRemoved}.BSBC_EnrollmentChange(idxhsa,4)-STATS_sys{idxInsRemoved}.BSBC_EnrollmentChange(idxhsa,1))/STATS_sys{idxInsRemoved}.BSBC_EnrollmentChange(idxhsa,1);
                STATS_sys{idxInsRemoved}.BSBC_EnrollmentChange(idxhsa,6) = sum(CF_sys{1,idxCF*3}.INSDEMAND{idxhsa}.ind(2,:,1));
                STATS_sys{idxInsRemoved}.BSBC_EnrollmentChange(idxhsa,7) = (STATS_sys{idxInsRemoved}.BSBC_EnrollmentChange(idxhsa,6)-STATS_sys{idxInsRemoved}.BSBC_EnrollmentChange(idxhsa,2))/STATS_sys{idxInsRemoved}.BSBC_EnrollmentChange(idxhsa,2);
            end;
        end;
        
        STATSBOOTsys{idxboot} = STATS_sys;
    end; %for idxboot
        
        
    %%BOOTSTRAP NUMBERS    
    for idxinsremoved=1:2        
        temp.basepremiums{idxinsremoved} = [];        
        temp.baseenrollment{idxinsremoved} = [];
        temp.basehosppmts{idxinsremoved} = [];
        temp.basehospprices{idxinsremoved} =[];
        temp.basesurplus{idxinsremoved} =[];
        temp.cfpremiums{idxinsremoved} = [];        
        temp.cfenrollment{idxinsremoved} = [];
        temp.cfhosppmts{idxinsremoved} = [];
        temp.cfhospprices{idxinsremoved} =[];
        temp.cfsurplus{idxinsremoved} =[];
        temp.cfpremiums_pc{idxinsremoved} = [];        
        temp.cfenrollment_pc{idxinsremoved} = [];
        temp.cfhosppmts_pc{idxinsremoved} = [];
        temp.cfhospprices_pc{idxinsremoved} =[];
        temp.cfsurplus_pc{idxinsremoved} =[];
        for idxboot=1:PARAM.NumBootstrap
            temp.basepremiums{idxinsremoved} = [temp.basepremiums{idxinsremoved} STATSBOOTsys{idxboot}{idxinsremoved}.premiums(1:3,1)];
            temp.baseenrollment{idxinsremoved} = [temp.baseenrollment{idxinsremoved} sum(STATSBOOTsys{idxboot}{idxinsremoved}.insenrollment(1:3,:),2)];                        
            temp.basehosppmts{idxinsremoved} = [temp.basehosppmts{idxinsremoved} STATSBOOTsys{idxboot}{idxinsremoved}.SummaryWelfare(1:2,1)];   
            temp.basehospprices{idxinsremoved} = [temp.basehospprices{idxinsremoved} ...
                  [STATSBOOTsys{idxboot}{idxinsremoved}.PriceComparisonsAll_AdjustWeights(1,2); STATSBOOTsys{idxboot}{idxinsremoved}.PriceComparisonsAll_AdjustWeights(1+15,2)] ];            
            temp.basesurplus{idxinsremoved} = [temp.basesurplus{idxinsremoved} ...
                    [STATSBOOTsys{idxboot}{idxinsremoved}.SummaryWelfare(3,1); STATSBOOTsys{idxboot}{idxinsremoved}.SummaryWelfare(7,1); STATSBOOTsys{idxboot}{idxinsremoved}.SummaryWelfare(8,1)-STATSBOOTsys{idxboot}{idxinsremoved}.SummaryWelfare(8,1)]  ];
            temp.cfpremiums{idxinsremoved} = [temp.cfpremiums{idxinsremoved} STATSBOOTsys{idxboot}{idxinsremoved}.premiums(7:9,1)];
            temp.cfpremiums_pc{idxinsremoved} = [temp.cfpremiums_pc{idxinsremoved} (STATSBOOTsys{idxboot}{idxinsremoved}.premiums(7:9,1)-STATSBOOTsys{idxboot}{idxinsremoved}.premiums(1:3,1))./STATSBOOTsys{idxboot}{idxinsremoved}.premiums(1:3,1)];
            temp.cfenrollment{idxinsremoved} = [temp.cfenrollment{idxinsremoved} sum(STATSBOOTsys{idxboot}{idxinsremoved}.insenrollment(7:9,:),2)];                        
            temp.cfenrollment_pc{idxinsremoved} = [temp.cfenrollment_pc{idxinsremoved} (sum(STATSBOOTsys{idxboot}{idxinsremoved}.insenrollment(7:9,:),2)-sum(STATSBOOTsys{idxboot}{idxinsremoved}.insenrollment(1:3,:),2))./sum(STATSBOOTsys{idxboot}{idxinsremoved}.insenrollment(1:3,:),2)];
            temp.cfhosppmts{idxinsremoved} = [temp.cfhosppmts{idxinsremoved} STATSBOOTsys{idxboot}{idxinsremoved}.SummaryWelfare(1:2,3)];   
            temp.cfhosppmts_pc{idxinsremoved} = [temp.cfhosppmts_pc{idxinsremoved} (STATSBOOTsys{idxboot}{idxinsremoved}.SummaryWelfare(1:2,3)-STATSBOOTsys{idxboot}{idxinsremoved}.SummaryWelfare(1:2,1))./STATSBOOTsys{idxboot}{idxinsremoved}.SummaryWelfare(1:2,1)];   
            temp.cfhospprices{idxinsremoved} = [temp.cfhospprices{idxinsremoved} ...
                  [STATSBOOTsys{idxboot}{idxinsremoved}.PriceComparisonsAll_AdjustWeights(1,5); STATSBOOTsys{idxboot}{idxinsremoved}.PriceComparisonsAll_AdjustWeights(1+15,5)] ];
            temp.cfhospprices_pc{idxinsremoved} = [temp.cfhospprices_pc{idxinsremoved} ...
                  [(STATSBOOTsys{idxboot}{idxinsremoved}.PriceComparisonsAll_AdjustWeights(1,5)-STATSBOOTsys{idxboot}{idxinsremoved}.PriceComparisonsAll_AdjustWeights(1,2))./STATSBOOTsys{idxboot}{idxinsremoved}.PriceComparisonsAll_AdjustWeights(1,2); ...
                   (STATSBOOTsys{idxboot}{idxinsremoved}.PriceComparisonsAll_AdjustWeights(1+15,5)-STATSBOOTsys{idxboot}{idxinsremoved}.PriceComparisonsAll_AdjustWeights(1+15,2))./STATSBOOTsys{idxboot}{idxinsremoved}.PriceComparisonsAll_AdjustWeights(1+15,2)] ];
            temp.cfsurplus{idxinsremoved} = [temp.cfsurplus{idxinsremoved} ...
                    [STATSBOOTsys{idxboot}{idxinsremoved}.SummaryWelfare(3,3); STATSBOOTsys{idxboot}{idxinsremoved}.SummaryWelfare(7,3); STATSBOOTsys{idxboot}{idxinsremoved}.SummaryWelfare(8,3)-STATSBOOTsys{idxboot}{idxinsremoved}.SummaryWelfare(8,1)]  ];
            temp.cfsurplus_pc{idxinsremoved} = [temp.cfsurplus_pc{idxinsremoved} ...
                    [(STATSBOOTsys{idxboot}{idxinsremoved}.SummaryWelfare(3,3)-STATSBOOTsys{idxboot}{idxinsremoved}.SummaryWelfare(3,1))./STATSBOOTsys{idxboot}{idxinsremoved}.SummaryWelfare(3,1); ...
                     (STATSBOOTsys{idxboot}{idxinsremoved}.SummaryWelfare(7,3)-STATSBOOTsys{idxboot}{idxinsremoved}.SummaryWelfare(7,1))./STATSBOOTsys{idxboot}{idxinsremoved}.SummaryWelfare(7,1); ...
                     0]  ];
        end;
        temp.baseall{idxinsremoved} = [temp.basepremiums{idxinsremoved};temp.baseenrollment{idxinsremoved};temp.basehosppmts{idxinsremoved};temp.basehospprices{idxinsremoved};temp.basesurplus{idxinsremoved}];
        temp.cfall{idxinsremoved} = [temp.cfpremiums{idxinsremoved};temp.cfenrollment{idxinsremoved};temp.cfhosppmts{idxinsremoved};temp.cfhospprices{idxinsremoved};temp.cfsurplus{idxinsremoved}];
        temp.cfall_pc{idxinsremoved} = [temp.cfpremiums_pc{idxinsremoved};temp.cfenrollment_pc{idxinsremoved};temp.cfhosppmts_pc{idxinsremoved};temp.cfhospprices_pc{idxinsremoved};temp.cfsurplus_pc{idxinsremoved}];
        temp.baseall{idxinsremoved} = sort(temp.baseall{idxinsremoved},2);
        temp.cfall{idxinsremoved} = sort(temp.cfall{idxinsremoved},2);
        temp.cfall_pc{idxinsremoved} = sort(temp.cfall_pc{idxinsremoved},2);
        STATSALL{idxinsremoved}.CI = [temp.baseall{idxinsremoved}(:,PARAM.NumBootstrap*.025+1), temp.baseall{idxinsremoved}(:,PARAM.NumBootstrap*.975), ...
                                      temp.cfall{idxinsremoved}(:,PARAM.NumBootstrap*.025+1), temp.cfall_pc{idxinsremoved}(:,PARAM.NumBootstrap*.025+1), ...
                                      temp.cfall{idxinsremoved}(:,PARAM.NumBootstrap*.975), temp.cfall_pc{idxinsremoved}(:,PARAM.NumBootstrap*.975) ] ;  %5 and 95% CI for statistics
    end;
    
    save(['M_CFsys',PARAM.FileSuffix], 'STATSBOOTsys', '-append');    
    save(['M_CFsys',PARAM.FileSuffix], 'STATSALL', '-append');
