function [obj, Y, X, ZZ, ImpliedMC, omega_3, omega_1, OMEGA, VarMoments, Moments] = f_GMM_Obj_2016(theta, DATA, DATAEST, PRICES, INSDEMAND, HOSPDEMAND, FLAG, PARAM, LHS, RHS, WUSE)

    if nargin < 11
        GMM2Stage = 0;
    else
        GMM2Stage = 1;
    end;

    %theta(1:2) : tau_M estimate for BS, BC
    tau_M = [theta(1); theta(2)];
    tau_H = 1-tau_M;
     
    if FLAG.PremSetting_MatchMargins==1
        tau_phi = theta(3);
    else
        tau_phi = 1;   %if not matching margins, assume Nash Bertrand and insurers maximize their own profits (full bargaining power)
    end;
    
    %MC estimates for BS,BC; K comes from margin moments
    MCUse = [theta(4:5) 2500]';
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %Premium Setting Moments (\omega_1)    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        [omega_1 ImpliedMC] = f_premiumsetting_error(DATAEST.premiums(:,1), INSDEMAND, HOSPDEMAND, PRICES, MCUse, FLAG, PARAM, tau_phi);
        
        %Kaiser MC is implied from premium-bargaining moment (no omega_{1,K})...
        MCUse(3) = ImpliedMC(3);
        [omega_1 ImpliedMC] = f_premiumsetting_error(DATAEST.premiums(:,1), INSDEMAND, HOSPDEMAND, PRICES, MCUse, FLAG, PARAM, tau_phi);
        
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %MLR Moments (\omega_2)
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        PredictedMLR = zeros(3,1);        
        for idxins=1:3            
            PredictedMLR_numerator = 0;
            PredictedMLR_denominator = 0;
            for idxhsa=1:14                
                if idxins~=3 || (idxins==3 && PARAM.isKaiserAvail(idxhsa)==1)
                    PredictedMLR_numerator = PredictedMLR_numerator + INSDEMAND{idxhsa}.ind(idxins,1) * MCUse(idxins);
                    if idxins ~= 3   %subtract change in hospital costs for non-Kaiser
                        PredictedMLR_numerator = PredictedMLR_numerator + HOSPDEMAND{idxhsa}.indXdrg(:,idxins,1)' * PRICES{idxhsa}.avgamtdrg(:,idxins);
                    end;
                    PredictedMLR_denominator = PredictedMLR_denominator + INSDEMAND{idxhsa}.fam(idxins,:,1) * DATAEST.premiums(idxins,:)';
                end;
            end;
            PredictedMLR(idxins) = PredictedMLR_numerator / PredictedMLR_denominator;
        end;
        omega_2 = ( (1-DATAEST.margins) - PredictedMLR ); 
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Bargaining Parameter Moments (\omega_3)
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        if FLAG.HospitalSystemRegression == 1
            Y = LHS.PriceXDemand_sys;
            X = tau_H(LHS.Index_sys(:,2)) .* (RHS.InsPremRev_sys - MCUse(LHS.Index_sys(:,2)) .* RHS.InsChangeIndivs_sys - RHS.InsOtherHospPmts_sys )...
                + tau_M(LHS.Index_sys(:,2)).*(RHS.HospCostsXDemand_sys - (RHS.HospOtherInsPriceXDemand_sys - RHS.HospOtherInsCostXDemand_sys));
            Z{2} = [repmat(RHS.InsPremRev_sys,1,2) - RHS.InsOtherHospPmts_IV_sys, RHS.InsChangeIndivs_sys, repmat(RHS.HospCostsXDemand_sys,1,2) - RHS.HospOtherInsMarginXDemand_IV_sys];
            %DUPLICATE MOMENTS BY INSURER
            Z{2}(:,3) = Z{2}(:,3)*10^3;
            Z{2} = [Z{2} .* repmat(LHS.Index_sys(:,2)==1, 1, size(Z{2},2)),  Z{2} .* repmat(LHS.Index_sys(:,2)==2, 1, size(Z{2},2))];

            OMEGA_Index = [LHS.Index_sys];
        else
            Y = LHS.PriceXDemand;
            X = tau_H(LHS.Index(:,2)) .* (RHS.InsPremRev - MCUse(LHS.Index(:,2)) .* RHS.InsChangeIndivs - RHS.InsOtherHospPmts ) ...
                + tau_M(LHS.Index(:,2)).*(RHS.HospCostsXDemand - RHS.HospOtherInsMarginXDemand);
            
            Z{2} = [repmat(RHS.InsPremRev,1,2) - RHS.InsOtherHospPmts_IV, RHS.InsChangeIndivs, repmat( RHS.HospCostsXDemand,1,2) - RHS.HospOtherInsMarginXDemand_IV];

            %DUPLICATE MOMENTS BY INSURER
            Z{2}(:,3) = Z{2}(:,3)*10^3;
            Z{2} = [Z{2} .* repmat(LHS.Index(:,2)==1, 1, size(Z{2},2)),  Z{2} .* repmat(LHS.Index(:,2)==2, 1, size(Z{2},2))];

            OMEGA_Index = [LHS.Index];
        end;
        omega_3 = (Y-X); 
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Compute GMM Objective
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        if FLAG.PremSetting_MatchMargins==1
            OMEGA{1} = [ omega_1*PARAM.MomentScaling(1); omega_2*PARAM.MomentScaling(2)];
            Ztemp1 = [  [119;147;1]/100, ones(3,1)]; 
            Ztemp2 = [  [187;220;27]/100, [119;147;1]/100, ones(3,1)]; 
            
            temp.numinst1 = size(Ztemp1,2);
            temp.numinst2 = size(Ztemp2,2);
            Z{1} =  [ Ztemp1 zeros(3,temp.numinst2); zeros(3, temp.numinst1) Ztemp2];
        else
            OMEGA{1} = [ omega_1*PARAM.MomentScaling(1) ];
            Z{1} = [[119;147;27]/100, ones(3,1) ];
        end;
        OMEGA{2} = omega_3*PARAM.MomentScaling(3);   

        %Instruments
        Z{1} = Z{1};
        Z{2} = Z{2}/10^6;
        
        %Start constructing objects for computing GMM objective    
        NOBS{1} = length(Z{1});
        NOBS{2} = length(Z{2});
        ZZ = [Z{1} zeros(size(Z{1},1),size(Z{2},2)); zeros(size(Z{2},1),size(Z{1},2)) Z{2}];
        if GMM2Stage==0
            WUSE = (ZZ'*ZZ);
        end;

        %STACK OMEGA{1}, OMEGA{2} (#sys x 2) vector;
        OMEGA_ALL = [OMEGA{1}/NOBS{1}; OMEGA{2}/NOBS{2}];

        obj = (OMEGA_ALL' * ZZ) * (WUSE \ (OMEGA_ALL'* ZZ)');% * 10^6;

        %Compute Variance of Moments    
        Moments{1}=[];
        Moments{2}=[];

        VarMomentsOmega1 = zeros(size(Z{1},2),size(Z{1},2));
        for idxObs=1:size(OMEGA{1},1)
             Moments{1} = [Moments{1}; OMEGA{1}(idxObs) * Z{1}(idxObs,:)];
             VarMomentsOmega1 = VarMomentsOmega1 + Moments{1}(idxObs,:)'*Moments{1}(idxObs,:);
        end;  
        VarMomentsOmega1 =  VarMomentsOmega1 / ( NOBS{1} ); 

        VarMomentsOmega2 = zeros(size(Z{2},2),size(Z{2},2));
        for idxObs = 1:length(OMEGA{2})
             Moments{2} = [Moments{2}; OMEGA{2}(idxObs) * Z{2}(idxObs,:)];
        end;
        NumClusters = 0;        
        for idxhsa=1:14
            ObsUse =  ( OMEGA_Index(:,1)==idxhsa );
            if sum(ObsUse)>0
                NumClusters = NumClusters+1;
                MomentsUse = Moments{2}(ObsUse==1,:);
                VarMomentsOmega2 = VarMomentsOmega2 + MomentsUse'*MomentsUse;
            end;
        end;
        VarMomentsOmega2 = VarMomentsOmega2/NOBS{2};
        VarMoments=[VarMomentsOmega1 zeros(size(VarMomentsOmega1,1), size(VarMomentsOmega2,2));
                    zeros(size(VarMomentsOmega2,1), size(VarMomentsOmega1,2)) VarMomentsOmega2 ]; 