function [LHS, RHS] = f_construct_LHSRHS(DATA,DATAEST, PRICES, INSDEMAND, HOSPDEMAND, PremiumsUse, FLAG, PARAM)


    %Count # of hospitals in each hsa on each insurer to solve prices for
    LHS.Index = [];             %hsa idxins idxhosp
    LHS.NumHosps = zeros(14,2);
    for idxhsa=1:14
        for idxins=1:2
            temp.include = (DATA{idxhsa}.ison(:,idxins)==1).*(DATA{idxhsa}.nadmits(:,idxins)>=PARAM.MinAdmits).*(HOSPDEMAND{idxhsa}.ind(:,idxins)>0);
            LHS.NumHosps(idxhsa,idxins) = sum ( temp.include );
            for idxhosp=1:length(DATA{idxhsa}.listhosps)
                if (temp.include(idxhosp)==1)
                    LHS.Index = [LHS.Index; idxhsa idxins idxhosp];
                end;
            end;
        end;
    end;
    LHS.Matrix = zeros( sum(sum(LHS.NumHosps(:,:) )) ,  sum(sum(LHS.NumHosps(:,:) )) );    %Used for Inversion to determine new prices.  Contains all hosps x ins pairs...

    %Initialize Structures
    LHS.Price = [];             %p_{ij}
    LHS.PriceXDemand = [];      %p_{ij} x D^H_{ij}
    LHS.HospDemand = [];        %D^H_{ij}
    
    RHS.InsPremRev = [];            %\phi_j x (D_{j} - D_{j\ij})
    RHS.InsDemandChange = [];       %(D_{j} - D_{j\ij})
    RHS.InsOtherHospPmts=[];        
    RHS.InsOtherHospPmts_IV=[];
    RHS.InsChangeIndivs=[];
    RHS.HospCosts=[];
    RHS.HospCostsXDemand=[];
    RHS.HospCostsXDemand_IV=[];
    RHS.HospOtherInsMarginXDemand=[];
    RHS.HospOtherInsMarginXDemand_IV=[];
    RHS.HospOtherInsPriceXDemand=[];        
    RHS.HospOtherInsCostsXDemand = [];
    RHS.HospOtherInsDemandChange = [];
    RHS.isSys = [];
    
    idxIVDemand = 1;   %1 to use premiums to predict demand in IVs; 2 to not use premiums

    fprintf('Constructing LHS/RHS of Bargaining Eq: ');

    for idxhsa=1:14

        fprintf('%d ', idxhsa);
        temp.nHospsinHSA = length(DATA{idxhsa}.listhosps);

        for idxins=1:2
            idxotherins = 2;
            if idxins==2
                idxotherins = 1;
            end;
            for idxhosp=1:temp.nHospsinHSA
                if (DATA{idxhsa}.hosp{idxhosp}.ison(idxins)==1)&&(DATA{idxhsa}.hosp{idxhosp}.nadmits(idxins)>=PARAM.MinAdmits)&&(HOSPDEMAND{idxhsa}.ind(idxhosp,idxins)>0)
                    HospCostUse = DATA{idxhsa}.hosp{idxhosp}.costs(PARAM.HospCostUse) / DATA{idxhsa}.hosp{idxhosp}.avgdrgwt;
                    LHS.Price = [LHS.Price; PRICES{idxhsa}.avgamtdrg(idxhosp,idxins) ];                            
                    LHS.PriceXDemand = [LHS.PriceXDemand; PRICES{idxhsa}.avgamtdrg(idxhosp,idxins) * HOSPDEMAND{idxhsa}.indXdrg(idxhosp,idxins,1)];                            
                    LHS.HospDemand = [LHS.HospDemand; HOSPDEMAND{idxhsa}.indXdrg(idxhosp,idxins,1)];
                        temp.index = strmatch( [idxhsa idxins idxhosp] , LHS.Index );                       %Index in Matrix for own hospital price                    
                        LHS.Matrix(temp.index,temp.index) = HOSPDEMAND{idxhsa}.indXdrg(idxhosp,idxins,1);   %Diagonal of Matrix
    
                    %******************************************
                    %DEFINE RHS VARS FOR NON-SYSTEM REGRESSIONS
                    %******************************************                    
                    %(M ia) Premium Effect
                    RHS.InsPremRev = [RHS.InsPremRev; ...
                                sum( PremiumsUse(idxins,:) .* (INSDEMAND{idxhsa}.fam(idxins,:,1) - INSDEMAND{idxhsa}.insdrop{idxins}.hospdrop{idxhosp}.fam(idxins,:,1)) )];
                    RHS.InsDemandChange = [RHS.InsDemandChange; ...
                                ((INSDEMAND{idxhsa}.fam(idxins,:,1) - INSDEMAND{idxhsa}.insdrop{idxins}.hospdrop{idxhosp}.fam(idxins,:,1)) )];
                            
                    %(M ib) Enrollment Effect
                    RHS.InsChangeIndivs = [RHS.InsChangeIndivs; (INSDEMAND{idxhsa}.ind(idxins,1) - INSDEMAND{idxhsa}.insdrop{idxins}.hospdrop{idxhosp}.ind(idxins,1))];
                            
                    %(M ii) Price Reinforcement Effect
                    temp.otherhosppmts = 0;
                    temp.otherhosppmts_iv = zeros(1,2);
                    for idxhosp2=1:temp.nHospsinHSA
                        if (DATA{idxhsa}.hosp{idxhosp2}.ison(idxins)==1) && (idxhosp2~=idxhosp) && (DATA{idxhsa}.hosp{idxhosp2}.nadmits(idxins)>=PARAM.MinAdmits)&&(HOSPDEMAND{idxhsa}.ind(idxhosp2,idxins)>0)
                            temp.otherhosppmts = temp.otherhosppmts ...
                                 + PRICES{idxhsa}.avgamtdrg(idxhosp2,idxins) ... 
                                 * (HOSPDEMAND{idxhsa}.indXdrg(idxhosp2,idxins,1) - HOSPDEMAND{idxhsa}.insdrop{idxins}.hospdrop{idxhosp}.indXdrg(idxhosp2,idxins,1));
                            %IVs based on using dWTP and costs of other
                            %hospitals instead of prices
                            temp.otherhosppmts_iv(1) = temp.otherhosppmts_iv(1) ...
                                 + DATAEST.dWTP{idxhsa}(idxhosp2,idxins) ... 
                                 * (HOSPDEMAND{idxhsa}.indXdrg(idxhosp2,idxins,idxIVDemand) - HOSPDEMAND{idxhsa}.insdrop{idxins}.hospdrop{idxhosp}.indXdrg(idxhosp2,idxins,idxIVDemand));
                            OtherHospCostUse = DATA{idxhsa}.hosp{idxhosp2}.costs(PARAM.HospCostUse) / DATA{idxhsa}.hosp{idxhosp2}.avgdrgwt;
                            temp.otherhosppmts_iv(2) = temp.otherhosppmts_iv(2) ...
                                 + OtherHospCostUse ... 
                                 * (HOSPDEMAND{idxhsa}.indXdrg(idxhosp2,idxins,idxIVDemand) - HOSPDEMAND{idxhsa}.insdrop{idxins}.hospdrop{idxhosp}.indXdrg(idxhosp2,idxins,idxIVDemand));

                            temp.index2 = strmatch( [idxhsa idxins idxhosp2] , LHS.Index );       %Index in Matrix for other hospital price
                            LHS.Matrix(temp.index, temp.index2) = (HOSPDEMAND{idxhsa}.indXdrg(idxhosp2,idxins,1) - HOSPDEMAND{idxhsa}.insdrop{idxins}.hospdrop{idxhosp}.indXdrg(idxhosp2,idxins,1));
                        end;
                    end;
                    RHS.InsOtherHospPmts = [RHS.InsOtherHospPmts; temp.otherhosppmts];
                    RHS.InsOtherHospPmts_IV = [RHS.InsOtherHospPmts_IV; [temp.otherhosppmts_iv]];

                    %(H iii) Hospital Costs                        
                    RHS.HospCosts = [RHS.HospCosts; HospCostUse];
                    RHS.HospCostsXDemand = [RHS.HospCostsXDemand; HospCostUse * HOSPDEMAND{idxhsa}.indXdrg(idxhosp,idxins,1)];
                    RHS.HospCostsXDemand_IV = [RHS.HospCostsXDemand_IV; HospCostUse * HOSPDEMAND{idxhsa}.indXdrg(idxhosp,idxins,idxIVDemand)];

                    %(H iv) Recapture Effect 
                    if (DATA{idxhsa}.hosp{idxhosp}.ison(idxotherins)==1)&&(DATA{idxhsa}.hosp{idxhosp}.nadmits(idxotherins)>=PARAM.MinAdmits)&&(HOSPDEMAND{idxhsa}.ind(idxhosp,idxotherins)>0)
                        temp.otherinsdemandchange = (HOSPDEMAND{idxhsa}.indXdrg(idxhosp,idxotherins,1) - HOSPDEMAND{idxhsa}.insdrop{idxins}.hospdrop{idxhosp}.indXdrg(idxhosp,idxotherins,1));
                        temp.otherinsdemandchange_iv = (HOSPDEMAND{idxhsa}.indXdrg(idxhosp,idxotherins,idxIVDemand) - HOSPDEMAND{idxhsa}.insdrop{idxins}.hospdrop{idxhosp}.indXdrg(idxhosp,idxotherins,idxIVDemand));
                        temp.otherinsprice = (PRICES{idxhsa}.avgamtdrg(idxhosp,idxotherins));
                        temp.otherinsmargin = (PRICES{idxhsa}.avgamtdrg(idxhosp,idxotherins) - HospCostUse);
                        temp.otherinsmargin_iv = [DATAEST.dWTP{idxhsa}(idxhosp,idxotherins), HospCostUse];
                        RHS.HospOtherInsDemandChange = [RHS.HospOtherInsDemandChange; temp.otherinsdemandchange];
                        RHS.HospOtherInsMarginXDemand = [RHS.HospOtherInsMarginXDemand; temp.otherinsdemandchange*temp.otherinsmargin];
                        RHS.HospOtherInsMarginXDemand_IV = [RHS.HospOtherInsMarginXDemand_IV; temp.otherinsdemandchange_iv * temp.otherinsmargin_iv];
                        RHS.HospOtherInsPriceXDemand = [RHS.HospOtherInsPriceXDemand; temp.otherinsdemandchange*temp.otherinsprice];
                        RHS.HospOtherInsCostsXDemand = [RHS.HospOtherInsCostsXDemand; temp.otherinsdemandchange*HospCostUse];
                        temp.index2 = strmatch( [idxhsa idxotherins idxhosp] , LHS.Index );     %Index for idxhosp on other insurer; recapture effect
                        LHS.Matrix(temp.index,temp.index2) = temp.otherinsdemandchange;
                    else
                        RHS.HospOtherInsDemandChange = [RHS.HospOtherInsDemandChange; 0];
                        RHS.HospOtherInsMarginXDemand = [RHS.HospOtherInsMarginXDemand; 0];
                        RHS.HospOtherInsMarginXDemand_IV = [RHS.HospOtherInsMarginXDemand_IV; [0 0];];
                        RHS.HospOtherInsCostsXDemand = [RHS.HospOtherInsCostsXDemand; 0];
                        RHS.HospOtherInsPriceXDemand = [RHS.HospOtherInsPriceXDemand;0];
                    end;
                    
                    RHS.isSys = [RHS.isSys; ~isnan(DATA{idxhsa}.hosp{idxhosp}.sysid)];
                end;
            end;
        end;
    end;
               
    %%SYSTEM REGRESSION VARIABLES
    %Count # of systems in each hsa on each insurer to solve prices for
    LHS.NumSys = zeros(14,2);
    for idxhsa=1:14
        temp.nSysinHSA = length(DATA{idxhsa}.uniquesysids(:,1));
        for idxins=1:2
            for idxsys=1:temp.nSysinHSA          
                temp.hospinsys = DATA{idxhsa}.listsysid(:)==DATA{idxhsa}.uniquesysids(idxsys,1);  %0-1 vector indicating which hospitals are on the system in question                
                temp.hosplist = find(temp.hospinsys .* DATA{idxhsa}.ison(:,idxins) .*  ( DATA{idxhsa}.nadmits(:,idxins)>=PARAM.MinAdmits) .* ( HOSPDEMAND{idxhsa}.ind(:,idxins)>0 ) );  %Choose a hospital in the system that is on the insurer in question            
                if ~isempty(temp.hosplist)
                    LHS.NumSys(idxhsa,idxins) = LHS.NumSys(idxhsa,idxins) + 1;
                end;
            end;
        end;
    end;    
    
    LHS.Index_sys = [];
    LHS.PriceXDemand_sys = []; 
    LHS.HospDemand_sys = [];        %D^H_{ij}
    LHS.HospDemandNoDRG_sys = [];        %D^H_{ij}
    RHS.HospCostsXDemand_sys = [];

    RHS.InsPremRev_sys = [];
    RHS.InsDemandChange_sys = [];
    RHS.InsDemandChangePercent_sys = [];
    
    RHS.InsOtherHospPmts_sys=[];
    RHS.InsOtherHospPmts_IV_sys=[];
    RHS.InsChangeIndivs_sys=[];
    RHS.HospOtherInsMarginXDemand_sys=[];
    RHS.HospOtherInsMarginXDemand_IV_sys=[];   
    RHS.HospOtherInsPriceXDemand_sys = [];
    RHS.HospOtherInsCostXDemand_sys = [];
    RHS.HospOtherInsDemandChange_sys = [];
    
    for idxhsa=1:14
        fprintf('%d ', idxhsa);
        temp.nSysinHSA = length(DATA{idxhsa}.uniquesysids(:,1));
        temp.nHospsinHSA = length(DATA{idxhsa}.listhosps);

        for idxins=1:2
            idxotherins = 2;
            if idxins==2
                idxotherins = 1;
            end;
            for idxsys=1:temp.nSysinHSA                
                temp.hospinsys = DATA{idxhsa}.listsysid(:)==DATA{idxhsa}.uniquesysids(idxsys,1);  %0-1 vector indicating which hospitals are on the system in question                
                temp.hosplist = find(temp.hospinsys .* DATA{idxhsa}.ison(:,idxins) .*  ( DATA{idxhsa}.nadmits(:,idxins)>=PARAM.MinAdmits) .* ( HOSPDEMAND{idxhsa}.ind(:,idxins)>0 ) );  %Choose a hospital in the system that is on the insurer in question
                if ~isempty(temp.hosplist)
                    idxhosp = temp.hosplist(1);
                    LHS.Index_sys = [LHS.Index_sys; idxhsa idxins DATA{idxhsa}.uniquesysids(idxsys,1)];
                    %Cost and Demand for all hospitals
                    temp.HospDemand = 0;
                    temp.HospDemandNoDRG = 0;
                    temp.PriceXDemand = 0;
                    temp.HospCostsXDemand = 0;
                    nHospsinSys = length(temp.hosplist);
                    for idxhosp2 = 1:nHospsinSys                        
                        idxhospUse = temp.hosplist(idxhosp2);
                        temp.HospDemand = temp.HospDemand + HOSPDEMAND{idxhsa}.indXdrg(idxhospUse,idxins,1);
                        temp.HospDemandNoDRG = temp.HospDemandNoDRG + HOSPDEMAND{idxhsa}.ind(idxhospUse,idxins,1);
                        temp.HospCostsXDemand = temp.HospCostsXDemand + HOSPDEMAND{idxhsa}.indXdrg(idxhospUse,idxins,1) * DATA{idxhsa}.hosp{idxhospUse}.costs(PARAM.HospCostUse) / DATA{idxhsa}.hosp{idxhospUse}.avgdrgwt;
                        temp.PriceXDemand = temp.PriceXDemand + PRICES{idxhsa}.avgamtdrg(idxhospUse,idxins) * HOSPDEMAND{idxhsa}.indXdrg(idxhospUse,idxins,1);                                                            
                    end;
                    RHS.HospCostsXDemand_sys = [RHS.HospCostsXDemand_sys; temp.HospCostsXDemand];
                    LHS.HospDemand_sys = [LHS.HospDemand_sys; temp.HospDemand];
                    LHS.HospDemandNoDRG_sys = [LHS.HospDemandNoDRG_sys; temp.HospDemandNoDRG];
                    LHS.PriceXDemand_sys = [LHS.PriceXDemand_sys; temp.PriceXDemand];                        
                    
                    %(ia) Premium Recapture
                    RHS.InsPremRev_sys = [RHS.InsPremRev_sys; ...
                                sum(PremiumsUse(idxins,:) .* (INSDEMAND{idxhsa}.fam(idxins,:,1) - INSDEMAND{idxhsa}.insdrop{idxins}.hospdropsys{idxhosp}.fam(idxins,:,1)) )];
                    RHS.InsDemandChange_sys = [RHS.InsDemandChange_sys; ...
                                ((INSDEMAND{idxhsa}.fam(idxins,:,1) - INSDEMAND{idxhsa}.insdrop{idxins}.hospdropsys{idxhosp}.fam(idxins,:,1)) )];
                    RHS.InsDemandChangePercent_sys = [RHS.InsDemandChangePercent_sys; ...
                                sum((INSDEMAND{idxhsa}.fam(idxins,:,1) - INSDEMAND{idxhsa}.insdrop{idxins}.hospdropsys{idxhosp}.fam(idxins,:,1)) ) / sum(INSDEMAND{idxhsa}.fam(idxins,:,1)) ];
                    
                    %(ib) Enrollment Effect
                    RHS.InsChangeIndivs_sys = [RHS.InsChangeIndivs_sys;   (INSDEMAND{idxhsa}.ind(idxins,1) - INSDEMAND{idxhsa}.insdrop{idxins}.hospdropsys{idxhosp}.ind(idxins,1))];
                    
                    %(ii) Price Reinforcement
                    temp.otherhosppmts = 0;
                    temp.otherhosppmts_iv = zeros(1,2);
                    for idxhosp2=1:temp.nHospsinHSA
                        %ONLY GO OVER NON-SYSTEM HOSPITALS
                        if (temp.hospinsys(idxhosp2)==0) && (DATA{idxhsa}.hosp{idxhosp2}.ison(idxins)==1) && (DATA{idxhsa}.hosp{idxhosp2}.nadmits(idxins)>=PARAM.MinAdmits)
                                temp.otherhosppmts = temp.otherhosppmts ...
                                     + PRICES{idxhsa}.avgamtdrg(idxhosp2,idxins) ... 
                                     * (HOSPDEMAND{idxhsa}.indXdrg(idxhosp2,idxins,1) - HOSPDEMAND{idxhsa}.insdrop{idxins}.hospdropsys{idxhosp}.indXdrg(idxhosp2,idxins,1));
                                %IVs based on using dWTP and costs of other
                                %hospitals instead of prices
                                temp.otherhosppmts_iv(1) = temp.otherhosppmts_iv(1) ...
                                     + DATAEST.dWTP{idxhsa}(idxhosp2,idxins) ... 
                                     * (HOSPDEMAND{idxhsa}.indXdrg(idxhosp2,idxins,idxIVDemand) - HOSPDEMAND{idxhsa}.insdrop{idxins}.hospdropsys{idxhosp}.indXdrg(idxhosp2,idxins,idxIVDemand));
                                OtherHospCostUse = DATA{idxhsa}.hosp{idxhosp2}.costs(PARAM.HospCostUse) / DATA{idxhsa}.hosp{idxhosp2}.avgdrgwt;
                                temp.otherhosppmts_iv(2) = temp.otherhosppmts_iv(2) ...
                                     + OtherHospCostUse ... 
                                     * (HOSPDEMAND{idxhsa}.indXdrg(idxhosp2,idxins,idxIVDemand) - HOSPDEMAND{idxhsa}.insdrop{idxins}.hospdropsys{idxhosp}.indXdrg(idxhosp2,idxins,idxIVDemand));
                        end;
                    end;
                    RHS.InsOtherHospPmts_sys = [RHS.InsOtherHospPmts_sys; temp.otherhosppmts];
                    RHS.InsOtherHospPmts_IV_sys = [RHS.InsOtherHospPmts_IV_sys; [temp.otherhosppmts_iv]];
                    
                    
                    %(H iv) Recapture Effect 
                    if sum(DATA{idxhsa}.ison(temp.hospinsys,idxotherins)) > 0
                        temp.otherinscostXdemand = 0;
                        temp.otherinspriceXdemand = 0;
                        temp.otherinsmargin = 0;
                        temp.otherinsmargin_iv = [0 0];
                        for idxhosp2=1:temp.nHospsinHSA
                            if (temp.hospinsys(idxhosp2)==1) && (DATA{idxhsa}.hosp{idxhosp2}.nadmits(idxotherins)>=PARAM.MinAdmits) &&(HOSPDEMAND{idxhsa}.ind(idxhosp2,idxotherins)>0) %if hosp2 is same sys
                                temp.otherinsdemandchange = (HOSPDEMAND{idxhsa}.indXdrg(idxhosp2,idxotherins,1) - HOSPDEMAND{idxhsa}.insdrop{idxins}.hospdropsys{idxhosp}.indXdrg(idxhosp2,idxotherins,1));
                                temp.otherinsdemandchange_iv = (HOSPDEMAND{idxhsa}.indXdrg(idxhosp2,idxotherins,idxIVDemand) - HOSPDEMAND{idxhsa}.insdrop{idxins}.hospdropsys{idxhosp}.indXdrg(idxhosp2,idxotherins,idxIVDemand));
                                OtherHospCostUse = DATA{idxhsa}.hosp{idxhosp2}.costs(PARAM.HospCostUse) / DATA{idxhsa}.hosp{idxhosp2}.avgdrgwt;   
                                temp.otherinspriceXdemand = temp.otherinspriceXdemand + temp.otherinsdemandchange*(PRICES{idxhsa}.avgamtdrg(idxhosp2,idxotherins));
                                temp.otherinscostXdemand = temp.otherinscostXdemand + temp.otherinsdemandchange*(OtherHospCostUse);
                                temp.otherinsmargin = temp.otherinsmargin + temp.otherinsdemandchange*(PRICES{idxhsa}.avgamtdrg(idxhosp2,idxotherins) - OtherHospCostUse);
                                temp.otherinsmargin_iv = temp.otherinsmargin_iv + temp.otherinsdemandchange_iv*[DATAEST.dWTP{idxhsa}(idxhosp2,idxotherins), OtherHospCostUse];                                
                            end;
                        end;
                        RHS.HospOtherInsPriceXDemand_sys = [RHS.HospOtherInsPriceXDemand_sys; temp.otherinspriceXdemand];                        
                        RHS.HospOtherInsCostXDemand_sys = [RHS.HospOtherInsCostXDemand_sys; temp.otherinscostXdemand];                        
                        RHS.HospOtherInsMarginXDemand_sys = [RHS.HospOtherInsMarginXDemand_sys; temp.otherinsmargin];
                        RHS.HospOtherInsMarginXDemand_IV_sys = [RHS.HospOtherInsMarginXDemand_IV_sys; temp.otherinsmargin_iv];                        
                    else
                        RHS.HospOtherInsPriceXDemand_sys = [RHS.HospOtherInsPriceXDemand_sys; 0];                        
                        RHS.HospOtherInsCostXDemand_sys = [RHS.HospOtherInsCostXDemand_sys; 0];                        
                        RHS.HospOtherInsMarginXDemand_sys = [RHS.HospOtherInsMarginXDemand_sys; 0];
                        RHS.HospOtherInsMarginXDemand_IV_sys = [RHS.HospOtherInsMarginXDemand_IV_sys; [0 0];];
                    end;
                end; %if sum(DATA{idxhsa}.ison(temp.hospinsys,idxins)) > 0
            end; %idxhosp
        end; %for idxins
    end; %for idxhsa
    fprintf('Done. \n');
    