function [HOSPDEMAND] = f_hospdemand(DATA, DATAHH, drgwts, INSDEMAND_HSA, idxhsa, idxinsdrop,idxhospdrop, isDropSys)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% INPUTS: 
% DATA structure    (see import_data.m)
% DATAHH structure  (see import_data.m)
% drgwts
% ZIPSUSE structure from either DATA{}.zip or DATA{}.hospdrop(sys){}.zip for right SigmaH variable
% INSDEMAND_HSA     structure from f_insdemand (only 1 HSA)
% idxhsa             scalar b/w 1-14
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% OUTPUTS:   
% HOSPDEMAND.ind     [nHosp x 2 x 2]          idxhosp x idxins isprem
% HOSPDEMAND.indfull [nHosp x 10 x 2 x 2]     idxhosp x agecat x idxins x isprem
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    if nargin > 5
        isDrop = 1;
    else
        isDrop = 0;
    end;
   
    nHospsinHSA = length(DATA{idxhsa}.listhosps);
    
    %Total Number of patients that go to each hosp from each insurer
    HOSPDEMAND.indfull = zeros(nHospsinHSA,10,2,1);

    for idxPrem = 1:1
        for idxzipHH=1:length(DATAHH{idxhsa}.listzips)
            idxzip = find(DATA{idxhsa}.listzips == DATAHH{idxhsa}.listzips(idxzipHH));        %Find index for HH zip in main DATAUSE file            
            for idxins = 1:2            
                if isDrop
                    if (idxins == idxinsdrop)
                        if isDropSys
                            SIGMAHUSE = DATA{idxhsa}.hospdropsys{idxhospdrop}.zip{idxzip}.sigmaH(:,:,idxins);
                        else
                            SIGMAHUSE = DATA{idxhsa}.hospdrop{idxhospdrop}.zip{idxzip}.sigmaH(:,:,idxins);
                        end;
                    else
                        SIGMAHUSE = DATA{idxhsa}.zip{idxzip}.sigmaH(:,:,idxins);
                    end;
                else
                    SIGMAHUSE = DATA{idxhsa}.zip{idxzip}.sigmaH(:,:,idxins);
                end;
                
                HOSPDEMAND.indfull(:,:,idxins,idxPrem) = HOSPDEMAND.indfull(:,:,idxins,idxPrem) + ...
                    SIGMAHUSE .* ...             %<== nHosp x 10 w/ share of each type that go to that hosp on that insplan                
                    (ones(nHospsinHSA,1) * INSDEMAND_HSA.zip{idxzipHH}.indfull(idxins,:,idxPrem));    %<== nHospsp x 10 w/ # of each type of indiv in that insurance plan rep'd    
            end;        
        end;
    end;
    
    HOSPDEMAND.ind = zeros(nHospsinHSA, 2, 2);
    for idxPrem = 1:1
        HOSPDEMAND.ind(:,:,idxPrem) = reshape( sum(HOSPDEMAND.indfull(:,:,:,idxPrem),2), nHospsinHSA, 2);
    end;
    
    HOSPDEMAND.indXdrg = zeros(nHospsinHSA,2,2);
    for idxPrem=1:1
        for idxins=1:2
            HOSPDEMAND.indXdrg(:,idxins,idxPrem) = sum(HOSPDEMAND.indfull(:,:,idxins,idxPrem) .* ( ones(nHospsinHSA,1) * drgwts ), 2); 
       end;        
    end;