function [INSDEMAND, HOSPDEMAND, INSDEMANDALL] = f_initialize_inshospdemand(DATA,DATAHH, PremiumsUse, insdemandcoeffs, drgwts, FLAG, PARAM, isRunTests)
    
    if nargin < 8
        isRunTests = 0;
    end;

    MCONetwork = [1 1 1];
    
    % Estimate Baseline Insurance & Hospital Demand    
    fprintf('Estimating Baseline Insurance and Hospital Demand: ');
    for idxhsa=1:14
        fprintf('%d ', idxhsa);        
        [INSDEMAND{idxhsa}] = f_insdemand(DATA, DATAHH,  PremiumsUse, insdemandcoeffs, idxhsa, FLAG, PARAM, MCONetwork, 1, 0);
        [HOSPDEMAND{idxhsa}] = f_hospdemand(DATA, DATAHH, drgwts, INSDEMAND{idxhsa}, idxhsa);
    end;
    fprintf('Done.\n');
    
    % Estimate CF insurance demand by removing an insurer one-by-one
    for idxins=1:3
        MCONetworkTemp = MCONetwork;
        MCONetworkTemp(idxins) = 0;
        for idxhsa=1:14
            fprintf('%d ', idxhsa);        
            [temp.INSDEMAND_drop] = f_insdemand(DATA, DATAHH,  PremiumsUse, insdemandcoeffs, idxhsa, FLAG, PARAM, MCONetworkTemp, 1, 0);
            [temp.HOSPDEMAND_drop] = f_hospdemand(DATA, DATAHH, drgwts, temp.INSDEMAND_drop, idxhsa);
            INSDEMAND{idxhsa}.insdrop{idxins}.fam = temp.INSDEMAND_drop.fam;
            INSDEMAND{idxhsa}.insdrop{idxins}.ind = temp.INSDEMAND_drop.ind;
            INSDEMAND{idxhsa}.insdrop{idxins}.hospXdrg_demand = temp.INSDEMAND_drop.hospXdrg_demand;
            INSDEMAND{idxhsa}.insdrop{idxins}.indXdrg = temp.HOSPDEMAND_drop.indXdrg;
        end;
    end;
    
    
    % Estimate CF insurance & Hospital Demand upon dropping any hospital-ins pair
    fprintf('Estimating CF Insurance and Hospital Demand: \n');
    for idxhsa=1:14               
        fprintf('HSA %d: ', idxhsa);        
        temp.nHospsinHSA = length(DATA{idxhsa}.listhosps);
        for idxhospdrop = 1:temp.nHospsinHSA
            fprintf('%d', idxhospdrop);
            for idxins = 1:2                
                if (DATA{idxhsa}.hosp{idxhospdrop}.ison(idxins)==1) && (DATA{idxhsa}.hosp{idxhospdrop}.nadmits(idxins)>=PARAM.MinAdmits)&&(HOSPDEMAND{idxhsa}.ind(idxhospdrop,idxins)>0)  %Only if Hosp-Ins are contracted, has minimal admits, or has positive demand
                    temp.INSDEMAND_drop = f_insdemand(DATA, DATAHH, PremiumsUse, insdemandcoeffs, idxhsa, FLAG, PARAM, MCONetwork, 0, 1, idxins, idxhospdrop, 0);
                    temp.INSDEMAND_dropsys = f_insdemand(DATA, DATAHH, PremiumsUse, insdemandcoeffs, idxhsa, FLAG, PARAM, MCONetwork, 0, 1, idxins, idxhospdrop, 1);
                    temp.HOSPDEMAND_drop = f_hospdemand(DATA, DATAHH, drgwts, temp.INSDEMAND_drop, idxhsa, idxins, idxhospdrop, 0);
                    temp.HOSPDEMAND_dropsys = f_hospdemand(DATA, DATAHH, drgwts, temp.INSDEMAND_dropsys, idxhsa, idxins, idxhospdrop, 1);                    
                    
                    INSDEMAND{idxhsa}.insdrop{idxins}.hospdrop{idxhospdrop}.ind = temp.INSDEMAND_drop.ind; 
                    INSDEMAND{idxhsa}.insdrop{idxins}.hospdrop{idxhospdrop}.fam = temp.INSDEMAND_drop.fam;
                    INSDEMAND{idxhsa}.insdrop{idxins}.hospdrop{idxhospdrop}.zip = temp.INSDEMAND_drop.zip; 
                    INSDEMAND{idxhsa}.insdrop{idxins}.hospdropsys{idxhospdrop}.ind = temp.INSDEMAND_dropsys.ind; 
                    INSDEMAND{idxhsa}.insdrop{idxins}.hospdropsys{idxhospdrop}.fam = temp.INSDEMAND_dropsys.fam;
                    INSDEMAND{idxhsa}.insdrop{idxins}.hospdropsys{idxhospdrop}.zip = temp.INSDEMAND_dropsys.zip;
                    HOSPDEMAND{idxhsa}.insdrop{idxins}.hospdrop{idxhospdrop}.ind = temp.HOSPDEMAND_drop.ind;
                    HOSPDEMAND{idxhsa}.insdrop{idxins}.hospdropsys{idxhospdrop}.ind = temp.HOSPDEMAND_dropsys.ind;
                    HOSPDEMAND{idxhsa}.insdrop{idxins}.hospdrop{idxhospdrop}.indXdrg = temp.HOSPDEMAND_drop.indXdrg;
                    HOSPDEMAND{idxhsa}.insdrop{idxins}.hospdropsys{idxhospdrop}.indXdrg = temp.HOSPDEMAND_dropsys.indXdrg;
                else   %If not contracted, CF demand is the same as baseline
                    INSDEMAND{idxhsa}.insdrop{idxins}.hospdrop{idxhospdrop}.ind = INSDEMAND{idxhsa}.ind; 
                    INSDEMAND{idxhsa}.insdrop{idxins}.hospdrop{idxhospdrop}.fam = INSDEMAND{idxhsa}.fam;
                    INSDEMAND{idxhsa}.insdrop{idxins}.hospdrop{idxhospdrop}.zip = INSDEMAND{idxhsa}.zip;
                    INSDEMAND{idxhsa}.insdrop{idxins}.hospdropsys{idxhospdrop}.ind = INSDEMAND{idxhsa}.ind; 
                    INSDEMAND{idxhsa}.insdrop{idxins}.hospdropsys{idxhospdrop}.fam = INSDEMAND{idxhsa}.fam;
                    INSDEMAND{idxhsa}.insdrop{idxins}.hospdropsys{idxhospdrop}.zip = INSDEMAND{idxhsa}.zip;
                    HOSPDEMAND{idxhsa}.insdrop{idxins}.hospdrop{idxhospdrop}.ind = HOSPDEMAND{idxhsa}.ind;
                    HOSPDEMAND{idxhsa}.insdrop{idxins}.hospdropsys{idxhospdrop}.ind = HOSPDEMAND{idxhsa}.ind;
                    HOSPDEMAND{idxhsa}.insdrop{idxins}.hospdrop{idxhospdrop}.indXdrg = HOSPDEMAND{idxhsa}.indXdrg;
                    HOSPDEMAND{idxhsa}.insdrop{idxins}.hospdropsys{idxhospdrop}.indXdrg = HOSPDEMAND{idxhsa}.indXdrg;                    
                end;                
            end;
        end;
        fprintf('\n');
    end;    
    fprintf('Done.\n');

    %Generate predicted elasticities for insurer pricing FOCs
    fprintf('Estimating Demand Derivatives & Elasticities: ');
    DERIVATIVE_STEP = 10^-7;
    for idxhsa=1:14               
        INSDEMAND{idxhsa}.deriv.fam = zeros(3,3);        
        INSDEMAND{idxhsa}.deriv.ind = zeros(3,1);
        INSDEMAND{idxhsa}.elasticity.fam = zeros(3,3);
        INSDEMAND{idxhsa}.elasticity.ind = zeros(3,1);
        HOSPDEMAND{idxhsa}.deriv.indXdrg = zeros(length(DATA{idxhsa}.listhosps),2);
        HOSPDEMAND{idxhsa}.elasticity.indXdrg = zeros(length(DATA{idxhsa}.listhosps),2);
        fprintf('%d ', idxhsa);        
        for idxins=1:3
            INSDEMAND{idxhsa}.deriv.fam_all{idxins} = zeros(3,3);   %Includes cross price elasticities when idxins price changes            
            temp.newpremiums = PremiumsUse;
            temp.newpremiums(idxins,:) = temp.newpremiums(idxins,:)+DERIVATIVE_STEP*[1 2 2.6];
            [temp.INSDEMAND] = f_insdemand(DATA, DATAHH, temp.newpremiums, insdemandcoeffs, idxhsa, FLAG, PARAM, MCONetwork, 0, 1);
            INSDEMAND{idxhsa}.deriv.fam(idxins,:) = (temp.INSDEMAND.fam(idxins,:,1)-INSDEMAND{idxhsa}.fam(idxins,:,1)) / DERIVATIVE_STEP;
            INSDEMAND{idxhsa}.deriv.fam_all{idxins} = (temp.INSDEMAND.fam(:,:,1)-INSDEMAND{idxhsa}.fam(:,:,1)) / DERIVATIVE_STEP;
            INSDEMAND{idxhsa}.deriv.ind(idxins,1) = (temp.INSDEMAND.ind(idxins,1)-INSDEMAND{idxhsa}.ind(idxins,1)) / DERIVATIVE_STEP;     
            INSDEMAND{idxhsa}.deriv.hospXdrg_demand(idxins,1) = (temp.INSDEMAND.hospXdrg_demand(idxins,1)-INSDEMAND{idxhsa}.hospXdrg_demand(idxins,1)) / DERIVATIVE_STEP;     
            INSDEMAND{idxhsa}.elasticity.fam(idxins,:) = PremiumsUse(idxins,:) .* INSDEMAND{idxhsa}.deriv.fam(idxins,:)./INSDEMAND{idxhsa}.fam(idxins,:,1);
            INSDEMAND{idxhsa}.elasticity.ind(idxins,1) = PremiumsUse(idxins,1) * INSDEMAND{idxhsa}.deriv.ind(idxins,1)./INSDEMAND{idxhsa}.ind(idxins,1);
            INSDEMAND{idxhsa}.elasticity.fam(idxins,2) = INSDEMAND{idxhsa}.elasticity.fam(idxins,2)/2;
            INSDEMAND{idxhsa}.elasticity.fam(idxins,3) = INSDEMAND{idxhsa}.elasticity.fam(idxins,3)/2.6;
            if idxins < 3
                [temp.HOSPDEMAND] = f_hospdemand(DATA, DATAHH, drgwts, temp.INSDEMAND, idxhsa);
                HOSPDEMAND{idxhsa}.deriv.indXdrg(:,idxins) = (temp.HOSPDEMAND.indXdrg(:,idxins) - HOSPDEMAND{idxhsa}.indXdrg(:,idxins,1))/DERIVATIVE_STEP;
                HOSPDEMAND{idxhsa}.elasticity.indXdrg(:,idxins) = PremiumsUse(idxins,1)*(temp.HOSPDEMAND.indXdrg(:,idxins) - HOSPDEMAND{idxhsa}.indXdrg(:,idxins,1))./HOSPDEMAND{idxhsa}.indXdrg(:,idxins,1);                
            end;            
        end;
        INSDEMAND{idxhsa}.elasticity.fam(isnan(INSDEMAND{idxhsa}.elasticity.fam)==1) = 0;
        INSDEMAND{idxhsa}.elasticity.ind(isnan(INSDEMAND{idxhsa}.elasticity.ind)==1) = 0;
        HOSPDEMAND{idxhsa}.elasticity.indXdrg(isnan(HOSPDEMAND{idxhsa}.elasticity.indXdrg)==1) = 0;
        INSDEMAND{idxhsa}.deriv.fam(isnan(INSDEMAND{idxhsa}.deriv.fam)==1) = 0;
        INSDEMAND{idxhsa}.deriv.ind(isnan(INSDEMAND{idxhsa}.deriv.ind)==1) = 0;
        INSDEMAND{idxhsa}.deriv.hospXdrg_demand(isnan(INSDEMAND{idxhsa}.deriv.hospXdrg_demand)==1) = 0;        
        HOSPDEMAND{idxhsa}.deriv.indXdrg(isnan(HOSPDEMAND{idxhsa}.deriv.indXdrg)==1) = 0;
    end;
    
    % Testing Predicted vs. Actual Insurance Demand
    if isRunTests==1
        INSDEMANDALL.ActualByHSA = zeros(3,14);
        INSDEMANDALL.ActualIndByHSA = zeros(3,14);
        INSDEMANDALL.ActualByHSAType = zeros(3,3,14);
        for idxhsa=1:14      
           for idxzip=1:length(DATAHH{idxhsa}.listzips)
              for idxhhtype=1:3
                 for idxfam=1:DATAHH{idxhsa}.zip{idxzip}.nhhtype(idxhhtype)
                     if ~isnan(DATAHH{idxhsa}.zip{idxzip}.hhtype{idxhhtype}.logincome(idxfam))
                        INSDEMANDALL.ActualByHSA(DATAHH{idxhsa}.zip{idxzip}.hhtype{idxhhtype}.planchoice(idxfam),idxhsa) = INSDEMANDALL.ActualByHSA(DATAHH{idxhsa}.zip{idxzip}.hhtype{idxhhtype}.planchoice(idxfam),idxhsa) +1;
                        INSDEMANDALL.ActualIndByHSA(DATAHH{idxhsa}.zip{idxzip}.hhtype{idxhhtype}.planchoice(idxfam),idxhsa) = INSDEMANDALL.ActualIndByHSA(DATAHH{idxhsa}.zip{idxzip}.hhtype{idxhhtype}.planchoice(idxfam),idxhsa) + sum(DATAHH{idxhsa}.zip{idxzip}.hhtype{idxhhtype}.members(idxfam,:));
                        INSDEMANDALL.ActualByHSAType(DATAHH{idxhsa}.zip{idxzip}.hhtype{idxhhtype}.planchoice(idxfam),idxhhtype,idxhsa) = INSDEMANDALL.ActualByHSAType(DATAHH{idxhsa}.zip{idxzip}.hhtype{idxhhtype}.planchoice(idxfam),idxhhtype,idxhsa) +1;
                     end;
                 end;
              end;
           end;
        end;
        INSDEMANDALL.ActualAll = sum(INSDEMANDALL.ActualByHSAType,3);
        
        INSDEMANDALL.PredictedByHSA = zeros(3,14);
        INSDEMANDALL.PredictedByHSAType = zeros(3,3,14);       
        INSDEMANDALL.PredictedInd = zeros(3,1);
        for idxhsa=1:14
          INSDEMANDALL.PredictedByHSA(:,idxhsa)=INSDEMANDALL.PredictedByHSA(:,idxhsa)+sum(INSDEMAND{idxhsa}.fam(:,:,1),2);
          for idxhhtype=1:3
             INSDEMANDALL.PredictedByHSAType(:,idxhhtype,idxhsa)=INSDEMANDALL.PredictedByHSAType(:,idxhhtype,idxhsa)+INSDEMAND{idxhsa}.fam(:,idxhhtype,1);
          end
          INSDEMANDALL.PredictedInd = INSDEMANDALL.PredictedInd + INSDEMAND{idxhsa}.ind(:,1);
        end;
        INSDEMANDALL.PredictedAll = sum(INSDEMANDALL.PredictedByHSAType,3);

        INSDEMANDALL.Compare = [INSDEMANDALL.ActualByHSA; INSDEMANDALL.PredictedByHSA];
    end;
    if isRunTests==1
        INSDEMANDALL.elasticity.fam = zeros(3,3);
        INSDEMANDALL.elasticity.ind = zeros(3,1);
        for idxhsa=1:14
            for idxins=1:3
                for idxhhtype = 1:3
                    if INSDEMANDALL.PredictedByHSAType(idxins,idxhhtype,idxhsa) > 0
                        INSDEMANDALL.elasticity.fam(idxins,idxhhtype) = INSDEMANDALL.elasticity.fam(idxins,idxhhtype) + INSDEMAND{idxhsa}.elasticity.fam(idxins,idxhhtype) * INSDEMAND{idxhsa}.fam(idxins,idxhhtype)/INSDEMANDALL.PredictedAll(idxins,idxhhtype);
                    end;
                end;
                INSDEMANDALL.elasticity.ind(idxins) = INSDEMANDALL.elasticity.ind(idxins) + INSDEMAND{idxhsa}.elasticity.ind(idxins) * INSDEMAND{idxhsa}.ind(idxins,1)/INSDEMANDALL.PredictedInd(idxins,1);
            end;
        end;        
    end;
    fprintf('Done.\n');
    
    
    