function [INSDEMAND] = f_insdemand(DATA, DATAHH, premiums, insdemandcoeffs, idxhsa, FLAG, PARAM, MCONetwork, isComputeEU, isSwitch, idxinsdrop, idxhospdrop, isDropSys)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% INPUTS: 
% DATA structure    (see import_data.m)
% DATAHH structure  (see import_data.m)
% ZIPSUSE structure from either DATA{}.zip or DATA{}.hospdrop(sys){}.zip for right WTP variable
% premiums          [3x3] insurer x ftype
% insdemandcoeffs   structure (see estimate_bargainingeq.m)
% idxhsa             scalar b/w 1-14
% dropInsHosp       2x1 w/ ins_id and hosp_id that disagree (empty if no disagreement)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% OUTPUTS:   
% INSDEMAND.fam     [3x3x2]        idxins x idxhhtype x isprem
% INSDEMAND.ind     [3x2]        idxins x isprem
% INSDEMAND.indfull [3x10x2]     idxins x agesexcat x isprem
% INSDEMAND.zip.fam [3x2]        idxins x isprem
% INSDEMAND.zip.ind [3x10x2]     idxins x agecat x isprem
% INSDEMAND.zip{}.famshare{idxhhtype}   [nFams x idxins (no K) x isprem
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    if nargin > 10
        isDrop = 1;
    else
        isDrop = 0;
    end;

    if MCONetwork(3)==1 && FLAG.isRemoveK_CF==0         %if Kaiser is available
        isKaiserAvailinHSA = PARAM.isKaiserAvail(idxhsa);
    else
        isKaiserAvailinHSA = 0;
    end;
            
    AreSwitchingCostsRelevant = (isSwitch==1) * FLAG.UseSwitchingCosts; %only positive switching costs when evaluating drops, premium changes
    
    HHAnnualPremiums = PARAM.IndivPremContribution * premiums;
    
    %ROBUSTNESS: IF USING SWITCHING COSTS TO RE-ESTIMATE MC, BARGAINING PARAMETERS
    if AreSwitchingCostsRelevant==1
        %INITIALIZE SWITCHING COST PREMIUMS FOR EACH HOUSEHOLD TYPE AND INS
        %HHAnnualPremiums_SC{idxhhtype}(idxinsstart,idxins) -- Effective premiums for idxhhtype who was at idxinstart evaluating plan idxins
        for idxhhtype = 1:3        
            HHAnnualPremiums_SC{idxhhtype} = ones(3,1) * HHAnnualPremiums(:,idxhhtype)'; %3x3: premiums for all 3 plans for given hhtype
            for idxins = 1:3
                temp.SC = ones(1,3);
                temp.SC(idxins) = PARAM.SwitchingCosts;
                HHAnnualPremiums_SC{idxhhtype}(idxins,:) = HHAnnualPremiums_SC{idxhhtype}(idxins,:) .* temp.SC;
            end;
        end;
    end;
    
    INSDEMAND.fam = zeros(3,3,1);
    INSDEMAND.indfull = zeros(3,10,1);    
    INSDEMAND.totalEU = 0;
    INSDEMAND.totalEU_dropins = zeros(3,1);  %totalEU if insurer idxins is dropped
    
    for idxzipHH=1:length(DATAHH{idxhsa}.listzips)   %Go through all the zips we have households living in
        isKaiserAvailinHSAandZip = (isKaiserAvailinHSA == 1) && (DATA{idxhsa}.zip{idxzipHH}.KaiserDist(1)==1);
        
        INSDEMAND.zip{idxzipHH}.fam = zeros(3,3,1);
        INSDEMAND.zip{idxzipHH}.indfull = zeros(3,10,1);        
        
        idxzip = find(DATA{idxhsa}.listzips == DATAHH{idxhsa}.listzips(idxzipHH));        %Find index for HH zip in main DATAUSE file    

        %ADJUST WTP IF THERE IS A DROP
        WTPUSE = DATA{idxhsa}.zip{idxzip}.WTP;
        if isDrop
            if isDropSys
                WTPUSE(:,idxinsdrop) = DATA{idxhsa}.hospdropsys{idxhospdrop}.zip{idxzip}.WTP(:,idxinsdrop);
            else
                WTPUSE(:,idxinsdrop) = DATA{idxhsa}.hospdrop{idxhospdrop}.zip{idxzip}.WTP(:,idxinsdrop);
            end;
        end;
                       
        WTPUSExCoeff = (insdemandcoeffs.useWTP(:,1) * ones(1,2)) .* WTPUSE;
        %ROBUSTNESS: IF ADJUSTING WTP COEFF
        if FLAG.AdjustWTPCoeff
            WTPUSExCoeff = WTPUSExCoeff * PARAM.AdjustWTPCoeff;
        end;
        
        INSDEMAND.zip{idxzipHH}.indfull = zeros(3,10,1);   %idxins x idxagesex x idxPrem
        
        for idxhhtype = 1:3   
            nhhtype=DATAHH{idxhsa}.zip{idxzipHH}.nhhtype(idxhhtype);
            if nhhtype>0
                
                if isKaiserAvailinHSA==1
                    HHDelta_NoWTP_NoPrem =  [insdemandcoeffs.insFE(idxhsa,:) DATA{idxhsa}.zip{idxzip}.KaiserDistUtil]';   %3x1, mean utilities for each ins for given hhtype w/o WTP, prem
                else
                    HHDelta_NoWTP_NoPrem =  [insdemandcoeffs.insFE(idxhsa,:) 0]';
                end;         
                
                %SWITCHING COST PREMIUMS FOR HHs IN ZIPCODE
                if AreSwitchingCostsRelevant == 0  %If computing initial demand or not using switching costs at all
                    HHDelta_NoWTP = HHDelta_NoWTP_NoPrem + insdemandcoeffs.prem * ( HHAnnualPremiums(:,idxhhtype) );                
                    HHDelta_NoWTP_AllHH = ones(DATAHH{idxhsa}.zip{idxzipHH}.nhhtype(idxhhtype),1) * HHDelta_NoWTP';
                else
                    HHAnnualPremiums_AllHHinZip = HHAnnualPremiums_SC{idxhhtype}(DATAHH{idxhsa}.zip{idxzipHH}.hhtype{idxhhtype}.planchoice,:);                    
                    HHDelta_NoWTP_AllHH = ones(DATAHH{idxhsa}.zip{idxzipHH}.nhhtype(idxhhtype),1) * HHDelta_NoWTP_NoPrem' ...
                                           + insdemandcoeffs.prem * HHAnnualPremiums_AllHHinZip;
                end
                
                INSDEMAND.zip{idxzipHH}.famshare{idxhhtype} = zeros(DATAHH{idxhsa}.zip{idxzipHH}.nhhtype(idxhhtype),3,1);                            
                
                %TOTAL WTP:
                temp.WTPuse = DATAHH{idxhsa}.zip{idxzipHH}.hhtype{idxhhtype}.members(:,:) * WTPUSExCoeff;

                for usePremiums = 1:1
                    if usePremiums==1
                        idxPrem=1;                        
                        if AreSwitchingCostsRelevant==0
                            temp.delta = HHDelta_NoWTP_AllHH ...
                                         + [temp.WTPuse zeros(nhhtype,1)] ... 
                                         + insdemandcoeffs.logincprem * (DATAHH{idxhsa}.zip{idxzipHH}.hhtype{idxhhtype}.logincome * HHAnnualPremiums(:,idxhhtype)'   );
                        else
                            temp.delta = HHDelta_NoWTP_AllHH ...
                                         + [temp.WTPuse zeros(nhhtype,1)] ... 
                                         + insdemandcoeffs.logincprem * ( (DATAHH{idxhsa}.zip{idxzipHH}.hhtype{idxhhtype}.logincome*ones(1,3)) .* HHAnnualPremiums_AllHHinZip);
                        end;
                    end;
                    
                    
                    
                    %Adjust deltas based on availability of insurers in MCO Network
%     
                    if isKaiserAvailinHSAandZip==1
                        %if Kaiser is present...then either BS or BC can be
                        %removed w/o issue
                        if MCONetwork(1)==0 || (FLAG.isRemoveBS_CF == 1)
                            temp.delta(:,1) = -inf;
                        end;
                        if (MCONetwork(2)==0) || (FLAG.isRemoveBC_CF == 1)
                            temp.delta(:,2) = -inf;
                        end;
                    else %Either No Kaiser CF, or in HSA 1 + 8
                        temp.delta(:,3) = -inf; %Remove Kaiser as an option if not available in HSA
                        if (FLAG.isRemoveBS_CF == 1) 
                            temp.delta(:,1) = -inf;
                        end;                        
                        if MCONetwork(1)==0
                            if ( FLAG.isRemoveBC_CF==1 && (idxhsa==1 || idxhsa==8) ) || FLAG.isRemoveBC_CF==0   %(Only remove BS in remove BC CF if Kaiser is around or in hsa 1+8
                                temp.delta(:,1) = -inf;
                            end;
                        end;                            
                        if (MCONetwork(2)==0) || ((FLAG.isRemoveBC_CF == 1) && (idxhsa~=1) && (idxhsa~=8))
                            temp.delta(:,2) = -inf;
                        end;
                    end;

                    temp.expdelta = exp(temp.delta);
                    
                    %EXPECTED UTILITIES OF HOUSEHOLDS
                    if isComputeEU==1 && usePremiums==1
                        %Expected utilities from existing choice set of MCOs                        
                        INSDEMAND.totalEU  = INSDEMAND.totalEU + ...
                            sum( log(sum(temp.expdelta,2)) ./ -(insdemandcoeffs.prem + insdemandcoeffs.logincprem * DATAHH{idxhsa}.zip{idxzipHH}.hhtype{idxhhtype}.logincome)   );
                        
                        idxotherins_all=[2,3;1,3;1,2];
                        for idxins=1:3
                            idxotherins = idxotherins_all(idxins,:);
                            
                            temp.expdelta_drop = temp.expdelta;                            
                            
                            temp.expdelta_drop( ( temp.expdelta_drop(:,idxotherins(1)) +  temp.expdelta_drop(:,idxotherins(2)) ) > 0 ,idxins) = 0;
                            
                            INSDEMAND.totalEU_dropins(idxins)  =  INSDEMAND.totalEU_dropins(idxins) + ...
                                sum( log(sum(temp.expdelta_drop,2)) ./ -(insdemandcoeffs.prem + insdemandcoeffs.logincprem * DATAHH{idxhsa}.zip{idxzipHH}.hhtype{idxhhtype}.logincome)   );
                        end;
                    end;
                    
                    INSDEMAND.zip{idxzipHH}.famshare{idxhhtype}(:,:,idxPrem) =  temp.expdelta ./ (sum(temp.expdelta,2) * ones(1,3) );     %idxfam x idxins
                    INSDEMAND.zip{idxzipHH}.fam(:,idxhhtype,idxPrem)  = sum(INSDEMAND.zip{idxzipHH}.famshare{idxhhtype}(:,:,idxPrem),1)';
                    INSDEMAND.zip{idxzipHH}.indfull(:,:,idxPrem) = INSDEMAND.zip{idxzipHH}.indfull(:,:,idxPrem) + INSDEMAND.zip{idxzipHH}.famshare{idxhhtype}(:,:,idxPrem)' * DATAHH{idxhsa}.zip{idxzipHH}.hhtype{idxhhtype}.members(:,:);   %idxins x idxagesex                    
                end;
            end;
        end;
        
        INSDEMAND.fam = INSDEMAND.fam + INSDEMAND.zip{idxzipHH}.fam;
        INSDEMAND.indfull = INSDEMAND.indfull + INSDEMAND.zip{idxzipHH}.indfull;
    end;
    INSDEMAND.ind = reshape(sum(INSDEMAND.indfull,2),3,1);
    INSDEMAND.hospXdrg_demand = sum(INSDEMAND.indfull .* PARAM.drgXadmwts,2); 
    
    