function [omega1 ImpliedMC dPi_dPrem GFT_M GFT_E dGFTE_dPrem] = f_premiumsetting_error(prem_single, INSDEMAND, HOSPDEMAND, PRICES, MCUse, FLAG, PARAM, tau_phi, resid_sys_prem)
    
    if nargin<9
        resid_sys_prem = zeros(3,1);    %residual from premium setting 
    end;

    PremiumsUse = repmat(prem_single,1,3) .* repmat([1 2 2.6],3,1);    
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %Premium Setting Moments (\omega_1)    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

        OtherInsList = [2 3; 1 3; 1 2];
    
        dPi_dPrem = zeros(3,1);    
        dPi_dPrem_A_NoInsMC = zeros(3,1);
        dPi_dPrem_B_dEnrolldPrem = zeros(3,1);
        
        GFT_M = zeros(3,1);
        GFT_M_A_NoInsMC = zeros(3,1); %Pi^M w/o Insurer MC
        GFT_M_B_Enroll = zeros(3,1);  %Total Enrollment
        
        GFT_E = zeros(3,1);
        dGFTE_dPrem = zeros(3,1); 

        %--------------------
        % Construct dPi_dPrem and dGFTE_dPrem
        % dPi_j/dPhi_j = \sum_hsa( [1 2 2.6] x D_j +  Phi_j x dD_j/dPhi_j - \eta_j * dD^E_j/dPhi_j  - \sum_{h\in j network} dD^H_{hj}/dPhi_j x p_{hj} ) 
        % dGFTE_dPrem = \sum_hsa( [1 2 2.6] x D_j + .8 \sum_k\phi_k [1 2 2.6]' dD_k/dphi_j) : change in revenues (hold fixed demand) when changing premiums
        %--------------------
        % \eta_j = insurer j's MC per enrollee  
        % D^E_j = insurer j's enrollee demand
        % D_j = insurer j's household demand (vector of HH-types)
        % \Phi_j = insurer j's premium
        % D^H_{hj} = hospital h's demand on insurer j
        %--------------------
        for idxins=1:3
            sum_RHS = 0;
            dPi_dPrem_A_NoInsMC(idxins) = 0;
            dPi_dPrem_B_dEnrolldPrem(idxins) = 0;
            for idxhsa=1:14
                if idxins~=3 || (idxins==3 && PARAM.isKaiserAvail(idxhsa)==1)
                    dGFTE_dPrem(idxins) = dGFTE_dPrem(idxins) + [1 2 2.6] * INSDEMAND{idxhsa}.fam(idxins,:,1)' + .8 * PremiumsUse(idxins,:) * INSDEMAND{idxhsa}.deriv.fam(idxins,:)';
                    for idxtemp=1:2
                        idxotherins=OtherInsList(idxins,idxtemp);
                        dGFTE_dPrem(idxins) = dGFTE_dPrem(idxins) + .8 * PremiumsUse(idxotherins,:) * INSDEMAND{idxhsa}.deriv.fam_all{idxins}(idxotherins,:)';
                    end;
                    sum_RHS = sum_RHS + [1 2 2.6] * INSDEMAND{idxhsa}.fam(idxins,:,1)' + PremiumsUse(idxins,:) * INSDEMAND{idxhsa}.deriv.fam(idxins,:)';
                    dPi_dPrem_A_NoInsMC(idxins) = dPi_dPrem_A_NoInsMC(idxins) + [1 2 2.6] * INSDEMAND{idxhsa}.fam(idxins,:,1)' + PremiumsUse(idxins,:) * INSDEMAND{idxhsa}.deriv.fam(idxins,:)';

                    if idxins ~= 3   %subtract change in hospital costs for non-Kaiser
                        sum_RHS = sum_RHS - HOSPDEMAND{idxhsa}.deriv.indXdrg(:,idxins)' * PRICES{idxhsa}.avgamtdrg(:,idxins);
                        dPi_dPrem_A_NoInsMC(idxins) = dPi_dPrem_A_NoInsMC(idxins) - HOSPDEMAND{idxhsa}.deriv.indXdrg(:,idxins)' * PRICES{idxhsa}.avgamtdrg(:,idxins);
                    end;      

                    sum_RHS = sum_RHS - INSDEMAND{idxhsa}.deriv.ind(idxins) * MCUse(idxins); %subtract non-hospital costs
                    dPi_dPrem_B_dEnrolldPrem(idxins) = dPi_dPrem_B_dEnrolldPrem(idxins) + INSDEMAND{idxhsa}.deriv.ind(idxins);                                 
                end;
            end;
            dPi_dPrem(idxins) = sum_RHS;
        end;
    
        %--------------------
        % Construct GFT Terms
        %--------------------
        if tau_phi <= 1
            %Construct GFT_M: gains from trade to MCO from being on employer (MCO profits)        
            for idxins=1:3            
                for idxhsa=1:14
                    if idxins~=3 || (idxins==3 && PARAM.isKaiserAvail(idxhsa)==1)                    
                        GFT_M(idxins) = GFT_M(idxins) + PremiumsUse(idxins,:) * ( INSDEMAND{idxhsa}.fam(idxins,:,1) - INSDEMAND{idxhsa}.insdrop{idxins}.fam(idxins,:,1) )';  %Prem revenues
                        GFT_M_A_NoInsMC(idxins) = GFT_M_A_NoInsMC(idxins) + PremiumsUse(idxins,:) * ( INSDEMAND{idxhsa}.fam(idxins,:,1) - INSDEMAND{idxhsa}.insdrop{idxins}.fam(idxins,:,1) )'; 

                        GFT_M(idxins) = GFT_M(idxins) - ( INSDEMAND{idxhsa}.ind(idxins,1) - INSDEMAND{idxhsa}.insdrop{idxins}.ind(idxins,1) ) * MCUse(idxins); %subtract non-hospital costs
                        GFT_M_B_Enroll(idxins) = GFT_M_B_Enroll(idxins) +  ( INSDEMAND{idxhsa}.ind(idxins,1) - INSDEMAND{idxhsa}.insdrop{idxins}.ind(idxins,1) );
                        if idxins ~= 3   %subtract change in hospital costs for non-Kaiser
                            GFT_M(idxins) = GFT_M(idxins) - (HOSPDEMAND{idxhsa}.indXdrg(:,idxins,1) - INSDEMAND{idxhsa}.insdrop{idxins}.indXdrg(:,idxins,1) )' * PRICES{idxhsa}.avgamtdrg(:,idxins);
                            GFT_M_A_NoInsMC(idxins) = GFT_M_A_NoInsMC(idxins) - (HOSPDEMAND{idxhsa}.indXdrg(:,idxins,1) - INSDEMAND{idxhsa}.insdrop{idxins}.indXdrg(:,idxins,1) )' * PRICES{idxhsa}.avgamtdrg(:,idxins);
                        end;                
                    end;
                end;
            end;        

            %Construct GFT_E: gains from trade to employer from having MCO 
            idxotherins_all=[2,3;1,3;1,2];
            for idxins=1:3
                idxotherins = idxotherins_all(idxins,:);
                for idxhsa=1:14    
                    %Change in premiums paid to other insurers
                    temp.ChangePrems    = PremiumsUse(1,:) * (INSDEMAND{idxhsa}.fam(1,:,1)' - INSDEMAND{idxhsa}.insdrop{idxins}.fam(1,:,1)') ...
                                              +PremiumsUse(2,:) * (INSDEMAND{idxhsa}.fam(2,:,1)' - INSDEMAND{idxhsa}.insdrop{idxins}.fam(2,:,1)')...
                                              +PremiumsUse(3,:) * (INSDEMAND{idxhsa}.fam(3,:,1)' - INSDEMAND{idxhsa}.insdrop{idxins}.fam(3,:,1)');
                    GFT_E(idxins) = GFT_E(idxins) + INSDEMAND{idxhsa}.totalEU - INSDEMAND{idxhsa}.totalEU_dropins(idxins);  %First add change in employees' welfare
                    GFT_E(idxins) = GFT_E(idxins) - .8 * ( temp.ChangePrems ); %Next account for change in premium payments by employer
                end;
            end;
        end;
        
        %--------------------
        %Section 3, Omega 1 Definition
        %--------------------        
        %SCALE ERROR BY TOTAL DEMAND ON INSURER
        TotalHospXDrgDemand = zeros(3,1);
        for idxhsa=1:14
             TotalHospXDrgDemand = TotalHospXDrgDemand + INSDEMAND{idxhsa}.hospXdrg_demand;
        end;     
        
        %If omega_1=0, what would be the implied insurer MC?
        ImpliedMC = zeros(3,1);
        ImpliedMC = dPi_dPrem_A_NoInsMC - ( (1-tau_phi)/(tau_phi) ) * ( GFT_M_A_NoInsMC .* dGFTE_dPrem ) ./ GFT_E;
        ImpliedMC = ImpliedMC ./ ( dPi_dPrem_B_dEnrolldPrem - ( ( (1-tau_phi)/(tau_phi) ) * GFT_M_B_Enroll .* dGFTE_dPrem ./ GFT_E )  );
 
        omega1 = zeros(3,1);
   
        omega1 = tau_phi * dPi_dPrem - ( (1-tau_phi) ) * ( GFT_M .* dGFTE_dPrem ) ./ GFT_E;
        omega1 = omega1 ./ TotalHospXDrgDemand;

        omega1 = omega1-resid_sys_prem;
        omega1(isnan(omega1))=0;
end