function [INSDEMAND, HOSPDEMAND] = f_update_demand_derivelast(INSDEMAND, HOSPDEMAND, DATA, DATAHH, PremiumsUse, insdemandcoeffs, drgwts, FLAG, PARAM, idxins_only)
   
    MCONetwork = [1 1 1];

    %Indicates which insurers to update elasticities for
    if nargin < 10
        idxins_only = 0;
        idxins_start = 1;
        idxins_end = 3;    
    else
        idxins_start = idxins_only;
        idxins_end = idxins_only;    
    end;

    for idxhsa=1:14
        fprintf('%d ', idxhsa);        
        [INSDEMAND{idxhsa}] = f_insdemand(DATA, DATAHH,  PremiumsUse, insdemandcoeffs, idxhsa, FLAG, PARAM, MCONetwork, 1, 0);
        [HOSPDEMAND{idxhsa}] = f_hospdemand(DATA, DATAHH, drgwts, INSDEMAND{idxhsa}, idxhsa);
    end;
    
    % Estimate CF insurance demand by removing an insurer one-by-one
    for idxins=1:3
        MCONetworkTemp = MCONetwork;
        MCONetworkTemp(idxins) = 0;
        for idxhsa=1:14
            %fprintf('%d ', idxhsa);        
            [temp.INSDEMAND_drop] = f_insdemand(DATA, DATAHH,  PremiumsUse, insdemandcoeffs, idxhsa, FLAG, PARAM, MCONetworkTemp, 1, 0);            
            [temp.HOSPDEMAND_drop] = f_hospdemand(DATA, DATAHH, drgwts, temp.INSDEMAND_drop, idxhsa);
            INSDEMAND{idxhsa}.insdrop{idxins}.fam = temp.INSDEMAND_drop.fam;
            INSDEMAND{idxhsa}.insdrop{idxins}.ind = temp.INSDEMAND_drop.ind;
            INSDEMAND{idxhsa}.insdrop{idxins}.hospXdrg_demand = temp.INSDEMAND_drop.hospXdrg_demand;
            INSDEMAND{idxhsa}.insdrop{idxins}.indXdrg = temp.HOSPDEMAND_drop.indXdrg;
            
        end;
    end;    
    
    %Generate predicted elasticities for insurer pricing FOCs
    fprintf('Estimating Demand Dervis & Elasticities: ');
    DERIVATIVE_STEP = 10^-7;
    for idxhsa=1:14               
        INSDEMAND{idxhsa}.deriv.fam = zeros(3,3);
        INSDEMAND{idxhsa}.deriv.ind = zeros(3,1);
        INSDEMAND{idxhsa}.deriv.hospXdrg_demand = zeros(3,1);
        INSDEMAND{idxhsa}.elasticity.fam = zeros(3,3);
        INSDEMAND{idxhsa}.elasticity.ind = zeros(3,1);
        HOSPDEMAND{idxhsa}.deriv.indXdrg = zeros(length(DATA{idxhsa}.listhosps),2);
        HOSPDEMAND{idxhsa}.elasticity.indXdrg = zeros(length(DATA{idxhsa}.listhosps),2);
        fprintf('%d ', idxhsa);        
        for idxins=idxins_start:idxins_end
            INSDEMAND{idxhsa}.deriv.fam_all{idxins} = zeros(3,3);   %Includes cross price elasticities when idxins price changes                        
            temp.newpremiums = PremiumsUse;
            temp.newpremiums(idxins,:) = temp.newpremiums(idxins,:)+DERIVATIVE_STEP*[1 2 2.6];
            [temp.INSDEMAND] = f_insdemand(DATA, DATAHH, temp.newpremiums, insdemandcoeffs, idxhsa, FLAG, PARAM, MCONetwork, 0, 1);
            INSDEMAND{idxhsa}.deriv.fam(idxins,:) = (temp.INSDEMAND.fam(idxins,:,1)-INSDEMAND{idxhsa}.fam(idxins,:,1)) / DERIVATIVE_STEP;
            INSDEMAND{idxhsa}.deriv.fam_all{idxins} = (temp.INSDEMAND.fam(:,:,1)-INSDEMAND{idxhsa}.fam(:,:,1)) / DERIVATIVE_STEP;
            INSDEMAND{idxhsa}.deriv.ind(idxins,1) = (temp.INSDEMAND.ind(idxins,1)-INSDEMAND{idxhsa}.ind(idxins,1)) / DERIVATIVE_STEP;     
            INSDEMAND{idxhsa}.deriv.hospXdrg_demand(idxins,1) = (temp.INSDEMAND.hospXdrg_demand(idxins,1)-INSDEMAND{idxhsa}.hospXdrg_demand(idxins,1)) / DERIVATIVE_STEP;     
            INSDEMAND{idxhsa}.elasticity.fam(idxins,:) = PremiumsUse(idxins,:) .* INSDEMAND{idxhsa}.deriv.fam(idxins,:)./INSDEMAND{idxhsa}.fam(idxins,:,1);
            INSDEMAND{idxhsa}.elasticity.ind(idxins,1) = PremiumsUse(idxins,1) * INSDEMAND{idxhsa}.deriv.ind(idxins,1)./INSDEMAND{idxhsa}.ind(idxins,1);
            if idxins < 3
                [temp.HOSPDEMAND] = f_hospdemand(DATA, DATAHH, drgwts, temp.INSDEMAND, idxhsa);
                HOSPDEMAND{idxhsa}.deriv.indXdrg(:,idxins) = (temp.HOSPDEMAND.indXdrg(:,idxins) - HOSPDEMAND{idxhsa}.indXdrg(:,idxins,1))/DERIVATIVE_STEP;
                HOSPDEMAND{idxhsa}.elasticity.indXdrg(:,idxins) = PremiumsUse(idxins,1)*(temp.HOSPDEMAND.indXdrg(:,idxins) - HOSPDEMAND{idxhsa}.indXdrg(:,idxins,1))./HOSPDEMAND{idxhsa}.indXdrg(:,idxins,1);                
            end;            
        end;
        
        %Set 0 elasticities and derivatives for those w/o any demand
        INSDEMAND{idxhsa}.elasticity.fam(isnan(INSDEMAND{idxhsa}.elasticity.fam)==1) = 0;
        INSDEMAND{idxhsa}.elasticity.ind(isnan(INSDEMAND{idxhsa}.elasticity.ind)==1) = 0;
        HOSPDEMAND{idxhsa}.elasticity.indXdrg(isnan(HOSPDEMAND{idxhsa}.elasticity.indXdrg)==1) = 0;
        INSDEMAND{idxhsa}.deriv.fam(isnan(INSDEMAND{idxhsa}.deriv.fam)==1) = 0;
        INSDEMAND{idxhsa}.deriv.ind(isnan(INSDEMAND{idxhsa}.deriv.ind)==1) = 0;
        INSDEMAND{idxhsa}.deriv.hospXdrg_demand(isnan(INSDEMAND{idxhsa}.deriv.hospXdrg_demand)==1) = 0;        
        HOSPDEMAND{idxhsa}.deriv.indXdrg(isnan(HOSPDEMAND{idxhsa}.deriv.indXdrg)==1) = 0;
    end;
    fprintf('Done.\n');