*create_0_countadmissions.do

* Hospital Systems:
* Count probability of being admitted conditional on age, gender. 
****
* From Admissions data:
* Create list of 2004 admissions to be used for demand estimation

global dir_root     /home/HC
global dir_log		$dir_root/d02.Scripts.and.Logs
global dir_data		$dir_root/d04.Cleaned.Output
global dir_intout	$dir_root/d03.Intermediate.Output
global dir_raw		$dir_root/d01.RawData
global dir_temp		$dir_root/d99.Temp
*********************************************************

clear
set more off
cap log close
log using "$dir_hospsys_scripts/Logs/elig_countadmissions.log", replace


	u $dir_raw/DRG/2008_drg.dta, clear
	drop if strpos(ms_drg,"cases")
	destring ms_drg, gen(drg)
	drop ms_drg
	sa $dir_temp/08drg.dta, replace


*********************************************************
*COUNT ADMISSION PROBABILITIES
*********************************************************
u $dir_data/Eligibility_SCO_All, clear
keep if obs_year< 2008
keep pid fid age gender employee_status relationship_type pay_office zipcode plan_rollup plan_name pay_amount _SCOmerge  obs_year obs_month
duplicates drop pid obs_year, force
gen age_bin=0
replace age_bin = 1 if age <= 19
replace age_bin = 2 if age >= 20 & age <= 34
replace age_bin = 3 if age >= 35 & age <= 44
replace age_bin = 4 if age >= 45 & age <= 54
replace age_bin = 5 if age >= 55 & age <= 64
replace age_bin = 6 if age >= 65
so pid
rename pid id_person
sa $dir_temp/Elig_2004-07.dta, replace


u $dir_data/Admit_all.dta, replace
keep if file_year<2008
rename file_year obs_year

merge m:1 id_person obs_year using $dir_temp/Elig_2004-07.dta
drop if _merge==1

*Drop Neonatal, new births
drop if drg_base>=789 & drg_base<=795

keep if plan_rollup == "PERS Choice" || plan_rollup == "Blue Shield Access+" || plan_rollup == "PERSCare"

bysort id_person obs_year: gen n_admissions = _N
bysort obs_year: replace n_admissions = 0 if _merge==2
bysort obs_year: gen is_admission = (n_admissions>0)

*SummarizeResults

bysort obs_year: tab age_bin is_admission if gender=="F"
bysort obs_year: tab age_bin is_admission if gender=="M"

bysort plan_rollup:  tab age_bin is_admission if gender=="F" & obs_year==2004
bysort plan_rollup:  tab age_bin is_admission if gender=="M" & obs_year==2004

tab n_admissions if obs_year==2004 & gender=="F"
tab n_admissions if obs_year==2004 & gender=="M"



u $dir_data/admit_all_w_ids_20160523.dta, clear
keep if imp_ptype==1
*Drop Neonatal, new births
drop if drg_base>=789 & drg_base<=795
rename file_year obs_year
merge m:1 id_person obs_year using $dir_temp/Elig_2004-07.dta
drop if _merge==1

keep if plan_rollup == "PERS Choice" || plan_rollup == "Blue Shield Access+" 
bysort id_person obs_year: gen n_admissions = _N
bysort obs_year: replace n_admissions = 0 if _merge==2
bysort obs_year: gen is_admission = (n_admissions>0)
keep if obs_year==2004
bysort plan_rollup:  tab age_bin is_admission if gender=="F" & obs_year==2004
bysort plan_rollup:  tab age_bin is_admission if gender=="M" & obs_year==2004




********************************************************
* PULL ADMISSIONS FOR USE IN DISCRETE CHOICE
* (Requires network_hosp_a3_prices.do to be run)
********************************************************

foreach year in "2004" {

	u $dir_data/admit_all_w_ids_20160523.dta, clear
	keep if file_year==`year'

	*ONLY KEEP ACUTE CARE ADMISSIONS
	keep if imp_ptype==1
		
	*Merge in DRG Weights
	rename drg_base drg
	merge m:1 drg using $dir_temp/08drg.dta
	keep if _merge==3
	drop _merge
	
	
	*******************************************************		
	*Merge in Plans for employees
	merge m:1 id_person file_year using $dir_temp/EligPlans.dta
	keep if _merge==3
	drop _merge
		
	gen isBS = strpos(plan_rollup, "Blue Shield")
	gen isBC = strpos(plan_rollup, "PERS")
	keep if (isBS|isBC)	
	
	*Pull in isNetworkProvider from `year' Facility Claims
	merge 1:1 id_admit id_admitfac_tax using $dir_temp/`year'_FacilityClaimsIsNetworkPaid.dta
	drop if _merge==2
	drop _merge
	
	gen age_bin=0
	replace age_bin = 1 if age <= 19
	replace age_bin = 2 if age >= 20 & age <= 34
	replace age_bin = 3 if age >= 35 & age <= 44
	replace age_bin = 4 if age >= 45 & age <= 54
	replace age_bin = 5 if age >= 55 & age <= 64
	replace age_bin = 6 if age >= 65
	drop age
	
	*******************************************************
	*Merge in imputed ICD9 codes from Claims Data
	********************************************************
	merge m:1 id_admit using $dir_temp/`year'_FacilityClaimsAdmitICD9.dta
	drop if _merge==2
	drop _merge
	local diags "cancer cardiac digestive labor neurological othercode"

	* Assign diagnosis based on imputed ICD9 codes and Ho 2006 classification
	icd9 generate admit_cardiac = imp_icd9, range(393/398 401/405 410/417 420/429)
	icd9 generate admit_cancer = imp_icd9, range(140/239)	
	icd9 generate admit_neurological = imp_icd9, range(320/326 330/337 340/359)
	icd9 generate admit_digestive = imp_icd9, range(520/579)
	icd9 generate admit_labor = imp_icd9, range(644 647 648 650/677 V22/V24 V27)
	icd9 generate admit_newborn = imp_icd9, range(V29/V39)
		
	* Assign diagnosis based on MDC code (05 circulatory, 06 digestive, 14/15 delivery/newbown, 19/20 neurological / substance abuse /etc.
	replace admit_cardiac=1 if mdc=="05" & admit_cancer==0 
	replace admit_digestive=0 if admit_cardiac==1
	replace admit_digestive=1 if mdc=="06" & admit_cancer==0 & admit_cardiac==0
	replace admit_labor=1 if mdc=="14"
	replace admit_newborn=1 if mdc=="15"
	replace admit_neurological=1 if (mdc=="19" | mdc=="20") 
	replace admit_cardiac=0 if admit_neurological==1
	replace admit_digestive=0 if admit_neurological==1
	
	replace admit_labor = 1 if admit_newborn==1 & age > 5
	replace admit_newborn = 0 if admit_newborn==1 & age > 5

	egen temp = rowtotal(admit_*)
	generate admit_othercode=0
	replace admit_othercode = 1 if temp==0
	drop temp	

	tab drg if admit_othercode==1	
	tab mdc if admit_othercode==1
	
	egen temp = rowtotal(admit_*)
	sum admit_* if temp>1
	drop temp
		
		

	*Make names consistent
	bysort id_hosp file_year: egen name_mode = mode(name_facility), maxmode
	bysort id_hosp file_year: replace name_facility=name_mode if ~missing(id_hosp)	

	bysort id_hosp name_facility file_year isBS: gen nAdmits_hospyearplan = _N
	bysort id_hosp name_facility file_year isBS: egen isNetworkProviderMax = max(isNetworkProviderImp)
	bysort id_hosp name_facility file_year isBS: egen isNetworkPaidMax = max(isNetworkPaidImp)
	
	gen tempBC = 0
	gen tempBS = 0
	replace tempBC = nAdmits_hospyearplan if isBC
	replace tempBS = nAdmits_hospyearplan if isBS
	bysort id_hosp name_facility file_year: egen nAdmits_BS = max(tempBS)
	bysort id_hosp name_facility file_year: egen nAdmits_BC = max(tempBC)
	drop temp* nAdmits_hospyearplan

	gen tempBC = 0
	gen tempBS = 0
	replace tempBC = isNetworkPaidMax if isBC
	replace tempBS = isNetworkPaidMax if isBS
	bysort id_hosp name_facility file_year: egen isNetPaid_BS = max(tempBS)
	bysort id_hosp name_facility file_year: egen isNetPaid_BC = max(tempBC)
	drop temp* isNetworkPaidMax

	gen tempBC = 0
	gen tempBS = 0
	replace tempBC = isNetworkProviderMax if isBC
	replace tempBS = isNetworkProviderMax if isBS
	bysort id_hosp name_facility file_year: egen isNetProvider_BS = max(tempBS)
	bysort id_hosp name_facility file_year: egen isNetProvider_BC = max(tempBC)
	drop temp* isNetworkProviderMax


	*******************************************************	
	keep if isOutofState==0
	keep if ~missing(id_hosp)

	keep  age_bin sex zipcode_patient admit_* imp_icd9 drg mdc name_facility id_tax id_hosp id_oshpd isBS isBC id_person wt
	order age_bin sex zipcode_patient admit_* imp_icd9 drg mdc name_facility id_tax id_hosp id_oshpd isBS isBC id_person wt
	do "$dir_hospsys_scripts/support_clean_oshpdid.do"
	drop if zipcode_patient=="~    "
	destring zipcode_patient, replace
	la data "`year' CA Admissions (create_0_countadmissions.do) created `c(current_date)'"
	sa "$dir_hospsys_intout/`year'_admissions_20160523.dta", replace
}


bysort age sex: sum wt

log close

