//Use output of create_KaiserVariables.do to create hospital-level variables: what percentage of this hospital's population has access to Kaiser?

global dir_root     /home/HC

global dir_raw 		$dir_root/d01.RawData
global dir_log 		$dir_root/d02.Scripts.and.Logs
global dir_out 		$dir_root/d04.Cleaned.Output
global dir_intout 	$dir_root/d03.Intermediate.Output
global dir_temp 	$dir_root/d99.Temp
set more off
*==============================================
cap log close
log using "$dir_log/create_Kaiser_b_HospVbles_20160523.log", text replace



use "$dir_raw/OSHPD03/oshpd03_hospzipdiag.dta", clear
collapse (sum) numpats, by(oshpdid patzip)    
rename patzip zipcode
save "$dir_intout/OSHPD03_percpats_zip.dta", replace


use "$dir_intout/Kaiser_ZipAvailability_traveltimes.dta", clear
keep zipcode Kaiser_isAvailable Kaiser_Distance_95 Kaiser_Distance_04 Kaiser_time* Kaiser_drive*
merge 1:m zipcode using "$dir_intout/OSHPD03_percpats_zip.dta"
drop if _merge==1   
keep if _merge==3  
drop _merge

bys oshpdid: egen totnumpats = total(numpat)
gen percpat = numpat / totnumpats

local distance_list 1 2 3 4 5 6 7 10 15 20
foreach distance of numlist `distance_list' {
	gen waKaiserHospin`distance'mi_04 = 0
	replace waKaiserHospin`distance'mi_04 = 1 if Kaiser_Distance_04 < `distance'
	label variable waKaiserHospin`distance'mi_04 "wave Kaiser hosp in `distance' miles of pat zip 04"   

	gen waKaiserHospin`distance'mi_95 = 0
	replace waKaiserHospin`distance'mi_95 = 1 if Kaiser_Distance_95 < `distance'  
	label variable waKaiserHospin`distance'mi_04 "wave Kaiser hosp in `distance' miles of pat zip 95"   

	gen waKaiserHospin`distance'DRmi_04 = 0
	replace waKaiserHospin`distance'DRmi_04 = 1 if Kaiser_drivedist_04 < `distance'
	label variable waKaiserHospin`distance'DRmi_04 "wave Kaiser hosp in `distance' miles of pat zip 04" 

	gen waKaiserHospin`distance'DRmi_95 = 0
	replace waKaiserHospin`distance'DRmi_95 = 1 if Kaiser_drivedist_95 < `distance'  
	label variable waKaiserHospin`distance'DRmi_04 "wave Kaiser hosp in `distance' miles of pat zip 95"  

}

local time_list 5 10 15 20 25 30 35
foreach time of numlist `time_list' {
	gen waKaiserHospin`time'mins_04 = 0
	replace waKaiserHospin`time'mins_04 = 1 if Kaiser_time_04 < `time'
	label variable waKaiserHospin`time'mins_04 "wave Kaiser hosp in `time' minutes of pat zip 04"   

	gen waKaiserHospin`time'mins_95 = 0
	replace waKaiserHospin`time'mins_95 = 1 if Kaiser_time_95 < `time'
	label variable waKaiserHospin`time'mins_95 "wave Kaiser hosp in `time' minutes of pat zip 95"  
}

sum

collapse (mean) waKaiser_isAvailable=Kaiser_isAvailable waKaiserHospin* [w=numpat], by(oshpdid)
label variable waKaiser_isAvailable "wave Kaiser selectible in pats zip" 
save "$dir_intout/Kaiser_HospAvailability.dta", replace


use "$dir_intout/WTPcalc/hospital_charas5_20160523.dta"		
keep oshpdid hosp_zipcode
rename hosp_zipcode zipcode
merge m:1 zipcode using "$dir_intout/Kaiser_ZipAvailability_traveltimes.dta"
keep if _merge==3
drop _merge


foreach distance of numlist `distance_list' {
	gen KaiserHospin`distance'mi_04 = 0
	replace KaiserHospin`distance'mi_04 = 1 if Kaiser_Distance_04 < `distance'
	label variable KaiserHospin`distance'mi_04 "Kaiser hosp in `distance' miles of this zip 04" 
	gen KaiserHospin`distance'mi_95 = 0
	replace KaiserHospin`distance'mi_95 = 1 if Kaiser_Distance_95 < `distance'
	label variable KaiserHospin`distance'mi_95 "Kaiser hosp in `distance' miles of this zip 95" 

	gen KaiserHospin`distance'DRmi_04 = 0
	replace KaiserHospin`distance'DRmi_04 = 1 if Kaiser_drivedist_04 < `distance'
	label variable KaiserHospin`distance'DRmi_04 "Kaiser hosp in drive `distance' miles of this zip 04" 
	gen KaiserHospin`distance'DRmi_95 = 0
	replace KaiserHospin`distance'DRmi_95 = 1 if Kaiser_drivedist_95 < `distance'
	label variable KaiserHospin`distance'DRmi_95 "Kaiser hosp in drive `distance' miles of this zip 95" 
}
foreach time of numlist `time_list' {
	gen KaiserHospin`time'mins_04 = 0
	replace KaiserHospin`time'mins_04 = 1 if Kaiser_time_04 < `time'
	label variable KaiserHospin`time'mins_04 "Kaiser hosp in `time' minutes of pat zip 04"  
	gen KaiserHospin`time'mins_95 = 0
	replace KaiserHospin`time'mins_95 = 1 if Kaiser_time_95 < `time'
	label variable KaiserHospin`time'mins_95 "Kaiser hosp in `time' minutes of pat zip 95"  
}


gen Kaiser_Available_myzip = 0
replace Kaiser_Available_myzip = 1 if Kaiser_isAvailable==1
sum KaiserHosp*
keep oshpdid KaiserHosp* Kaiser_Available_myzip
gen oshpdid2 = oshpdid

replace oshpdid = 331152 if oshpdid==331145
replace oshpdid = 440755 if oshpdid==441807
replace oshpdid = 560492 if oshpdid==564018
replace oshpdid = 301097 if oshpdid==301109
replace oshpdid = 551034 if oshpdid==554011

merge m:1 oshpdid using "$dir_intout/Kaiser_HospAvailability.dta"
drop _merge
drop oshpdid
rename oshpdid2 oshpdid

replace waKaiser_isAvailable = Kaiser_Available_myzip if oshpdid==121002 | oshpdid==334001
foreach distance of numlist `distance_list' {
	foreach year in "95" "04" {
		replace waKaiserHospin`distance'mi_`year' = KaiserHospin`distance'mi_`year' if oshpdid==121002 | oshpdid==334001
	}
}
*
foreach time of numlist `time_list' {
	foreach year in "95" "04" {
		replace waKaiserHospin`time'mins_`year' = KaiserHospin`time'mins_`year' if oshpdid==14050 | oshpdid==104008 | oshpdid==120981 | oshpdid==121002 | oshpdid==204023 | oshpdid==334001
	}
}


//
drop if oshpdid==.

save "$dir_intout/Kaiser_HospAvailability_20160523.dta", replace


log close
