//Create characteristics for the hospitals included in BC (PPO) and BS (HMO) networks. 


*=====================================
global dir_root     /home/HC
global dir_raw 		$dir_root/d01.RawData
global dir_log 		$dir_root/d02.Scripts.and.Logs
global dir_intout 	$dir_root/d03.Intermediate.Output
global dir_out 		$dir_root/d04.Cleaned.Output
global dir_temp 	$dir_root/d99.Temp

clear
set more off
cap log close
*=====================================

log using "$dir_log/Logs/create_hospcharas_20160523.log", text replace

	
	use "$dir_intout/hosp_network04_wprices_boot_onlyposadmits_20160523.dta", clear		/* <== 2016.05.23 PUT NEW FILE NAME HERE */
	
	tab file_year

	keep if file_year==2004         

	replace isBS=0 if missing(isBS)
	
	drop if id_oshpd==.
	count                      
	tab isBC isBS              
	drop if isBC==0 & isBS==0  
	*drop nAdmits
		
	*Create oshpdid from id_oshpdid by removing leading 106
	do "$dir_log/support_clean_oshpdid.do"

	so id_hosp oshpdid
	*duplicates drop oshpdid, force	
	duplicates drop id_hosp, force
	rename zipcode hosp_zipcode
	*rename address hospaddress
	rename latitude hosplat
	rename longitude hosplong
	rename id_county hosp_id_county
	
	save "$dir_intout/WTPcalc/hospital_charas_20160523.dta", replace	 

//Get 2004 OSHPD Financial Data  
	clear
	insheet using "$dir_raw/OSHPD03/HAFD2004_Revised906.csv"
	rename fac_no id_oshpd
	duplicates drop id_oshpd, force  //drops 7 observations where financial statement listed in 2 parts. Normalizing expenses by day_tot so this seems fine.
	do "$dir_log/support_clean_oshpdid.do"
	sa "$dir_intout/OSHPD2004_costs.dta", replace
	//Fill in 5 hospitals that are in the final dataset, with nAdmits_BC>10 or nAdmits_BS>10 (and non-missing), but not in the OSHPD 2004 cost data
	//2 are in OSHPD 2003 cost data, so pull them in
	clear
	insheet using "$dir_raw/OSHPD03/HAFD123103.csv" 	
	rename fac_no id_oshpd
	keep if id_oshpd==106510882 | id_oshpd==106301325
	keep if day_per==365 		//drop one observation where financial statement listed in 2 parts - keep a full year, drop a part-year
	tostring id_oshpd, replace
	gen oshpdid = substr(id_oshpd,4,9)
	destring oshpdid, replace
	append using "$dir_intout/OSHPD2004_costs.dta"
	sa "$dir_intout/OSHPD2004_costs.dta", replace
	//2 are in OSHPD 2002 cost data; pull them in
	clear
	insheet using "$dir_raw/OSHPD03/HAFD123102Rev1004.csv" 	
	rename fac_no id_oshpd
	keep if id_oshpd==106334001 | id_oshpd==106301126
	tostring id_oshpd, replace
	gen oshpdid = substr(id_oshpd,4,9)
	destring oshpdid, replace
	append using "$dir_intout/OSHPD2004_costs.dta"
	sa "$dir_intout/OSHPD2004_costs.dta", replace
	//Last one is oshpdid 100822, University Medical Center Fresno. It was closed in 2007, merged into Community Medical Center in downtown Fresno.
	//Match to 100717, Community Regional Medical Center.
	clear
	insheet using "$dir_raw/OSHPD03/HAFD2004_Revised906.csv"
	rename fac_no id_oshpd
	keep if id_oshpd==106100717
	drop id_oshpd
	gen oshpdid=100822     //renumber the oshpdid so that it matches up to 100822.
	append using "$dir_intout/OSHPD2004_costs.dta"
	
	
	//Keep just the variables we want
	destring tot_op_exp, replace ignore(",")
	destring exp*, replace ignore(",")
	destring dis_tot, replace ignore(",")
	keep tot_op_exp exp* dis_tot oshpdid
	drop exp_insur exp_intrst exp_oth
	gen exp_dly_pa = exp_dly / dis_tot
	sa "$dir_intout/OSHPD2004_costs.dta", replace
	
	
	//Merge with hospital_charas.dta
	use "$dir_intout/WTPcalc/hospital_charas_20160523.dta"	 
	merge oshpdid using "$dir_intout/OSHPD2004_costs.dta", sort uniqusing
	tab _merge    
	drop if _merge==2
	list oshpdid name_facility hosp_zipcode if _merge==1
	drop _merge 
	save "$dir_intout/WTPcalc/hospital_charas_20160523.dta", replace	 
	

//Merge with ahaid and therefore aha data
	use "$dir_raw/AHA/ahaid_oshpdid_link2003.dta"
	
	
	merge oshpdid using "$dir_intout/WTPcalc/hospital_charas_20160523.dta", sort uniqusing	 
	tab _merge			
	
	
	//Fill in matches with ahaid's for 10 out of 16 that didn't match; the rest are rehab or nursing care only and we drop them. See match_ahaid_oshpdid.xlsx for details.
	replace ahaidno = 6930031 if oshpdid == 13626
	replace ahaidno = 6930085 if oshpdid == 301109
	replace ahaidno = 6930402 if oshpdid == 204023
	replace ahaidno = 6930045 if oshpdid == 331145
	replace ahaidno = 6930008 if oshpdid == 441807
	replace ahaidno = 6930065 if oshpdid == 105029
	replace ahaidno = 6933672 if oshpdid == 564018
	replace ahaidno = 6931929 if oshpdid == 240924
	replace ahaidno = 6933533 if oshpdid == 554011
	replace ahaidno = 6930106 if oshpdid == 120981
	replace ahaidno = 6930107 if oshpdid == 14050
	replace ahaidno = 6930640 if oshpdid == 334001      
	drop mname mloczip regionmsa                         
	drop if ahaidno==. & _merge==2
	drop if _merge==1
	drop _merge		
	save "$dir_intout/WTPcalc/hospital_charas2_20160523.dta", replace	 


//Now clean up and pull in AHA characteristics
	use "$dir_raw/AHA/aha_extract03.dta"
	keep if stcd=="93"    //California
	keep mname id reg stcd hrrcode hsacode cntrl serv sysid bdtot cclabhos radthhos angiohos ftern ftemd fteres mapp1 mapp2 mapp3 mapp5 mapp8 nichos oncolhos obhos emdephos mammshos brnhos ultsnhos mrihos cichos exptot paytot admtot ipdtot 
	list mname id if substr(id,7,7)=="A"
	//COST DATA
	gen exp_peradm = exptot/(admtot)
	gen pay_peradm = paytot/ (admtot)
	save "$dir_intout/WTPcalc/work.dta", replace

	
	use "$dir_raw/AHA/aha_addnaldata_03.dta"
	keep if stcd=="93"
	keep id reg stcd subs ipahos foundhos ipfeehos osteo ctscnhos pethos specthos alcophos ohsrghos
	merge id reg stcd using "$dir_intout/WTPcalc/work.dta", sort uniqusing
	tab _merge
	drop _merge
	save "$dir_intout/WTPcalc/work.dta", replace
	
	
	use "$dir_raw/AHA/aha_addnaldata_04.dta"
	keep id reg stcd broomhos 
	merge id reg stcd using "$dir_intout/WTPcalc/work.dta", sort uniqusing
	tab _merge
	drop if _merge==1   
	drop _merge
	save "$dir_intout/WTPcalc/work.dta", replace


//Now merge with hospital_charas.dta. 
	rename id ahaidno
	list mname ahaidno if substr(ahaidno,7,7)=="A"   
	replace ahaidno="693139" if ahaidno=="693139A"
	destring ahaidno, replace
	sort ahaidno
	merge ahaidno using "$dir_intout/WTPcalc/hospital_charas2_20160523.dta", sort uniqmaster	 
		
	tab _merge                 
	keep if _merge==3
	drop _merge
	sum

save "$dir_intout/WTPcalc/hospital_charas3_20160523.dta", replace

	keep if cichos==.
	sum                    
	keep ahaidno reg stcd *hos
	drop broomhos         
	sort ahaidno
	rename *hos *hostemp
	save "$dir_intout/WTPcalc/temp.dta", replace
	
	use "$dir_raw/AHA/aha_extract2004.dta", clear
	keep id reg stcd *hos
	keep if stcd=="93" 
	rename id ahaidno
	replace ahaidno="693139" if ahaidno=="693139A"
	destring ahaidno, replace
	merge ahaidno reg stcd using "$dir_intout/WTPcalc/temp.dta", sort uniqusing
	tab _merge
	keep if _merge==3
	drop _merge
	local tempvars "alcop ctscn pet spect ipa found ipfee ob cic nic brn mamms emdep oncol mri ultsn"
	foreach x of local tempvars  {
		replace `x'hostemp = `x'hos  
	} 
	
	keep ahaidno reg stcd *temp
	save "$dir_intout/WTPcalc/temp.dta", replace  
	
	use "$dir_intout/WTPcalc/hospital_charas3_20160523.dta"		
	sort ahaidno reg stcd
	merge ahaidno reg stcd using "$dir_intout/WTPcalc/temp.dta", sort uniqusing
	tab _merge      
	local tempvars "alcop ctscn pet spect ipa found ipfee ob cic nic brn mamms emdep oncol mri ultsn"
	foreach x of local tempvars  {
		replace `x'hos = `x'hostemp if _merge==3  
	} 
	
	drop _merge *temp
	
	
	local vars "broomhos osteo subs alcophos ohsrghos ctscnhos pethos specthos ipahos foundhos ipfeehos obhos cichos nichos brnhos angiohos mammshos cclabhos emdephos oncolhos radthhos mrihos ultsnhos"
	foreach x of local vars  {
		replace `x'=0 if `x'==.
	}

save "$dir_intout/WTPcalc/hospital_charas4_20160523.dta", replace		 

//Now create the variables we'll use to create WTP

	generate qualcardiac = 0
	replace qualcardiac=1 if ohsrghos==1
	replace qualcardiac=0.90 if ohsrghos==0 & angiohos==1
	replace qualcardiac=0.76 if ohsrghos==0 & angiohos==0 & cichos==1
	replace qualcardiac=0.57 if ohsrghos==0 & angiohos==0 & cichos==0 & cclabhos==1
	generate qualimaging=0
	replace qualimaging=1 if pethos==1
	replace qualimaging=0.49 if pethos==0 & specthos==1
	replace qualimaging=0.45 if pethos==0 & specthos==0 & mrihos==1
	replace qualimaging=0.03 if pethos==0 & specthos==0 & mrihos==0 & ctscnhos==1
	replace qualimaging=0.03 if pethos==0 & specthos==0 & mrihos==0 & ultsnhos==1
	generate qualcancer2 = 0
	replace qualcancer2 = 1 if radthhos==1
	replace qualcancer2 = 0.22 if radthhos==1 & oncolhos==1
	generate qualbirths2 = 0
	replace qualbirths2 = 1 if nichos==1
	replace qualbirths2 = 1 if nichos==0 & broomhos==1
	replace qualbirths2 = 0.89 if nichos==0 & broomhos==0 & obhos==1
	
	
	//Following taken from create_extravbles.do and create_hospcharas2.do
	generate JCAHO = 2 - mapp1
	generate CancerProg = 2 - mapp2
	generate Residency = 2 - mapp3
	generate MedSchool = 2 - mapp5
	generate teach2 = 2 - mapp8
	generate FP = 0
	replace FP = 1 if cntrl>30
	generate cntrl_county = 0
	replace cntrl_county = 1 if cntrl==13
	generate cntrl_city = 0
	replace cntrl_city = 1 if cntrl==14
	generate cntrl_hospauth = 0 
	replace cntrl_hospauth = 1 if cntrl==16
	generate cntrl_church = 0
	replace cntrl_church = 1 if cntrl==21
	generate cntrl_othnfp = 0 
	replace cntrl_othnfp = 1 if cntrl==23
	generate cntrl_indfp = 0
	replace cntrl_indfp = 1 if cntrl==31
	generate cntrl_ptnerfp = 0 
	replace cntrl_ptnerfp = 1 if cntrl==32
	generate cntrl_corpfp = 0
	replace cntrl_corpfp = 1 if cntrl==33
	
	generate nurseperbed = ftern / bdtot
	generate nurseperbedsq = nurseperbed * nurseperbed
	generate docsperbed = ftemd/bdtot
	
	keep ahaidno broomhos osteo subs alcophos ctscnhos pethos specthos ipahos foundhos ipfeehos sysid obhos nichos brnhos angiohos mammshos cclabhos emdephos oncolhos bdtot mname oshpdid id_oshpd id_hosp isBS id_tax hosp_zipcode isBC hosp_id_county isClosed avg_drg* avg_amt* med_amt* nAdmits* hosplat hosplong qual* JCAHO CancerProg Residency MedSchool teach2 FP cntrl_county cntrl_church nurseperbed nurseperbedsq docsperbed exptot paytot exp_peradm pay_peradm BS_boot* BC_boot* exp* dis_tot
save "$dir_intout/WTPcalc/hospital_charas5_20160523.dta", replace

	rename hosp_zipcode zipcode03
	merge zipcode03 using "$dir_raw/DartmouthAtlas/ZipHsaHrr03.dta", sort uniqusing
	tab _merge
	drop if _merge==2
	tab hrrnum   
	rename zipcode03 hosp_zipcode
	drop hsanum hsacity hsastate hrrcity hrrstate _merge
	save "$dir_intout/WTPcalc/hospital_charas5_20160523.dta", replace		 

	rename hosp_zipcode patzip
	merge m:1 patzip using "$dir_raw/OSHPD03/oshpd03_patzip_hsa.dta"
	drop if _merge==2
	drop _merge
	tab hsap
	rename hsap hsa
	rename patzip hosp_zipcode
	
	bysort hsa: gen num_hosp_in_hsa = _N
	
	la data "Hospital Characteristics (create_1_hospcharas.do) created `c(current_date)'"
	saveold "$dir_intout/WTPcalc/hospital_charas5_20160523.dta", replace		
	
	
log close
