
global dir_root     /home/HC

global dir_raw 		$dir_root/d01.RawData
global dir_log 		$dir_root/d02.Scripts.and.Logs
global dir_intout 	$dir_root/d03.Intermediate.Output
global dir_out 		$dir_root/d04.Cleaned.Output
global dir_temp 	$dir_root/d99.Temp
set more off

*================================================================================================

log using "$dir_log/create_probadm.log", text replace

//First create population breakdown by age-gender in CA, from Census data.
	cd "$dir_raw"
	use nber_census2000_sf12000871ca2.dta, clear     
	gen pop_1019 = p012003 + p012004 + p012005 + p012006 + p012007
	gen pop_12034 = p012008 + p012009 + p012010 + p012011 + p012012
	gen pop_13544 = p012013 + p012014
	gen pop_14554 = p012015 + p012016
	gen pop_15564 = p012017 + p012018 + p012019
	gen pop_2019 = p012027 + p012028 + p012029 + p012030 + p012031
	gen pop_22034 = p012032 + p012033 + p012034 + p012035 + p012036
	gen pop_23544 = p012037 + p012038
	gen pop_24554 = p012039 + p012040
	gen pop_25564 = p012041 + p012042 + p012043
	drop pop100  
	collapse (sum) pop*    
	egen total=rsum(pop*)

	reshape long pop_, i(total) j(agesex)
	rename pop_ pop
	tostring agesex, replace
	gen sex=substr(agesex,1,1)  
	destring sex, replace
	gen agecat_Ho = 1
	replace agecat_Ho = 2 if substr(agesex,2,5)=="2034"
	replace agecat_Ho = 3 if substr(agesex,2,5)=="3544"
	replace agecat_Ho = 4 if substr(agesex,2,5)=="4554"
	replace agecat_Ho = 5 if substr(agesex,2,5)=="5564"         
	gen p_CApop = pop/total         
	keep sex agecat_Ho p_CApop
	label variable p_CApop "% of CA under-65 pop in this age-sex group, Census 2000 data"
	save "$dir_intout/WTPcalc/agesex_data.dta", replace

	use "$dir_raw/OSHPD03/oshpd03_zipagesexdiag.dta", clear        
	drop if diagnosis=="newborn"            
	collapse (sum) numpats, by(sex agecat_Ho)
	drop if agecat_Ho==6                  
	rename numpats numadm
	label variable numadm "priv insured admissions to hosp in this age-sex excl newborns, OSHPD 2003 data"
	sort sex agecat_Ho
	merge sex agecat_Ho using "$dir_intout/WTPcalc/agesex_data.dta", sort uniqusing
	tab _merge
	drop _merge
	list
	save "$dir_intout/WTPcalc/agesex_data.dta", replace

//Add probability of each diagnosis conditional on admission, age, sex (assumed constant across zips)
	use "$dir_raw/OSHPD03/oshpd03_zipagesexdiag.dta", clear
	drop if diagnosis=="newborn"	 
	collapse (sum) numpats, by(sex agecat_Ho)
	rename numpats pats
	sort sex agecat_Ho
	save "$dir_intout/WTPcalc/prob_diags_agesex.dta", replace
	
	local diags "cancer cardiac digestive labor neurological othercode"
	foreach x of local diags  {
		use "$dir_raw/OSHPD03/oshpd03_zipagesexdiag.dta", clear
		keep if diagnosis=="`x'"
		drop diagnosis
		rename numpats numpat_`x'
		collapse (sum) numpat_`x', by(sex agecat_Ho)
		sort sex agecat_Ho
		merge sex agecat_Ho using "$dir_intout/WTPcalc/prob_diags_agesex.dta", sort uniqmaster
		tab _merge
		drop _merge
		gen p_`x' = numpat_`x' / pats
		drop numpat_`x'
		label variable p_`x' "P(`x'|admitted,age,sex), from OSHPD 2003 data"
		
		save "$dir_intout/WTPcalc/prob_diags_agesex.dta", replace
	}
	
	replace p_labor = 0 if sex==1 | agecat_Ho==6  //these are tiny numbers in any case
	save, replace
	
	drop pats
	drop if agecat_Ho==6
	sort sex agecat_Ho
	merge sex agecat_Ho using "$dir_intout/WTPcalc/agesex_data.dta", sort uniqusing
	tab _merge
	drop _merge
	save "$dir_intout/WTPcalc/agesex_data.dta", replace              


//Second part of this do file creates data to cross-check the population numbers.
	use "$dir_raw/OSHPD03/oshpd03_zipagesexdiag.dta", clear
	drop if diagnosis=="newborn"            
	collapse (sum) numpats, by(patzip sex agecat_Ho)
	//Add information on prob admitted by age-sex from analysis of Calpers data 
	gen p_adm = 0.0228   
	replace p_adm = 0.11194 if sex==2 & agecat_Ho==2
	replace p_adm = 0.0791 if sex==2 & agecat_Ho==3
	replace p_adm = 0.0687 if sex==2 & agecat_Ho==4
	replace p_adm = 0.0974 if sex==2 & agecat_Ho==5
	replace p_adm = 0.2315 if sex==2 & agecat_Ho==6
	replace p_adm = 0.0205 if sex==1 & agecat_Ho==1
	replace p_adm = 0.0207 if sex==1 & agecat_Ho==2
	replace p_adm = 0.0311 if sex==1 & agecat_Ho==3
	replace p_adm = 0.0558 if sex==1 & agecat_Ho==4
	replace p_adm = 0.1049 if sex==1 & agecat_Ho==5
	replace p_adm = 0.2478 if sex==1 & agecat_Ho==6
	
	drop if agecat_Ho==6

//Use this to scale up number of admissions to implied population by age-gender-zip
	generate pop_inf = numpats / p_adm
	replace pop_inf = floor(pop_inf)
	label variable pop_inf "inf popln: priv insured pop (OSHPD 2003) /p_adm for age/sex group (Calpers 04)"
	label variable p_adm "prob of admission by age-sex group from Calpers 2004 data"
	label variable numpats "total priv insured pats by agesexzip, excl newborns, OSHPD 2003"
	rename patzip zipcode03
	rename p_adm p_adm_calpers
	rename numpats numpats_zip_oshpd
	save "$dir_intout/WTPcalc/prob_adms_agesexzipinf.dta", replace


log close
