//Use Census 2000 data from AmericanFactFinder.com to create hospital-level variables: what percent of this hospital's catchment zips are white? Median income of this hospital's catchment zips?


global dir_root     /home/HC

global dir_raw 		$dir_root/d01.RawData
global dir_log 		$dir_root/d02.Scripts.and.Logs
global dir_intout 	$dir_root/d03.Intermediate.Output
global dir_out 		$dir_root/d04.Cleaned.Output
global dir_temp 	$dir_root/d99.Temp
set more off

*=====================================

log using "$dir_root/d02.Scripts.and.Logs/create_demog_hospvles_20160523.log", text replace

use "$dir_root/d01.RawData/Census2000/hhinc1999_by_zcta.dta", clear
	keep zcta2000 total
	rename total medhhinc
	rename zcta2000 zipcode
	label variable zipcode "ZCTA from Census 2000"
	drop if substr(zipcode,4,2)=="HH" | substr(zipcode,4,2)=="XX"
	replace medhhinc = "200000" if medhhinc=="200,000+"  
	destring zipcode medhhinc, replace
	save "$dir_root/d03.Intermediate.Output/Hosp_demographics.dta", replace
	
	 use "$dir_root/d01.RawData/Census2000/popbyrace1999_by_zcta.dta", clear
	rename geoid2 zipcode
	drop geoid geodisplaylabel p*
	drop if substr(zipcode,4,2)=="HH" | substr(zipcode,4,2)=="XX"
	destring zipcode, replace
	gen pwhite = whitepopuln/totalpopulation
	gen pblack = blackpop/totalpopulation
	gen pasian = asianpop/totalpopulation
	gen phispanic = hispanicpop/totalpopulation
	drop if totalpopulation==0
	merge 1:1 zipcode using "$dir_root/d03.Intermediate.Output/Hosp_demographics.dta"
	keep if _merge==3   
	drop _merge
	save "$dir_root/d03.Intermediate.Output/Hosp_demographics.dta", replace
	
	use "$dir_root/d01.RawData/Census2000/popbyagesex1999_by_zcta.dta", clear
	rename geoid2 zipcode
	drop if substr(zipcode,4,2)=="HH" | substr(zipcode,4,2)=="XX"
	destring zipcode, replace
	rename vd01 totalpop
	gen tot_age5564 = vd17 + vd18 + vd19 + vd41 + vd42 + vd43
	gen tot_ageg65 = vd20 + vd21 + vd22 + vd23 + vd24 + vd25 + vd44 + vd45 + vd46 + vd47 + vd48 + vd49
	gen perc_age5564 = tot_age5564 / totalpop
	gen perc_ageg65 = tot_ageg65 / totalpop
	drop if totalpop==0
	keep zipcode perc*
	sum
	merge 1:1 zipcode using "$dir_root/d03.Intermediate.Output/Hosp_demographics.dta"
	keep if _merge==3
	drop _merge
	save "$dir_root/d03.Intermediate.Output/Hosp_demographics.dta", replace


//Use OSHPD03_percpats_zip.dta, created in create_KaiserHospVbles.do, to match these zip charas to hospital catchment areas
	merge 1:m zipcode using "$dir_root/d03.Intermediate.Output/OSHPD03_percpats_zip.dta"
	drop if _merge==1   
	keep if _merge==3   
	drop _merge
	
	bys oshpdid: egen totnumpats = total(numpat)
	gen percpat = numpat / totnumpats
	
	sum
	
	collapse (mean) wa_medhhinc=medhhinc wa_pwhite = pwhite wa_pblack = pblack wa_pasian = pasian wa_phispanic = phispanic wa_p_age5564 = perc_age5564 wa_p_ageg65 = perc_ageg65 [w=numpat], by(oshpdid)
	label variable wa_medhhinc "w ave medhhinc of zcta, 1999, Census 2000, w=num commercial pats to the hosp in 03, OSHPD"
	label variable wa_pwhite "wave pwhite in zcta, 1999, Census 2000, w=num commercial pats to the hosp in 03, OSHPD"  
	label variable wa_p_age5564 "wave p_age5564 in zcta, 1999, Census 2000, w=num commercial pats to the hosp in 03, OSHPD"
	save "$dir_root/d03.Intermediate.Output/Hosp_demographics2_20160523.dta", replace		

	use "$dir_root/d03.Intermediate.Output/WTPcalc/hospital_charas5_20160523.dta"		
	keep oshpdid hosp_zipcode 
	rename hosp_zipcode zipcode
	merge m:1 zipcode using "$dir_root/d03.Intermediate.Output/Hosp_demographics.dta"
	
	keep if _merge==3
	keep oshpdid pwhite pblack phispanic pasian medhhinc perc_age5564 perc_ageg65 zipcode
	
	
	gen oshpdid2 = oshpdid
	replace oshpdid = 331152 if oshpdid==331145
	replace oshpdid = 440755 if oshpdid==441807
	replace oshpdid = 560492 if oshpdid==564018
	replace oshpdid = 301097 if oshpdid==301109
	replace oshpdid = 551034 if oshpdid==554011
	merge m:1 oshpdid using "$dir_root/d03.Intermediate.Output/Hosp_demographics2_20160523.dta"
	
	drop _merge
	replace oshpdid2=oshpdid if oshpdid2==.
	drop oshpdid
	rename oshpdid2 oshpdid
	replace wa_medhhinc = medhhinc if oshpdid==121002 | oshpdid==334001
	replace wa_pwhite = pwhite if oshpdid==121002 | oshpdid==334001
	replace wa_pblack = pblack if oshpdid==121002 | oshpdid==334001
	replace wa_pasian = pasian if oshpdid==121002 | oshpdid==334001
	replace wa_phispanic = phispanic if oshpdid==121002 | oshpdid==334001
	replace wa_p_age5564 = perc_age5564 if oshpdid==121002 | oshpdid==334001
	replace wa_p_ageg65 = perc_ageg65 if oshpdid==121002 | oshpdid==334001
	
	save "$dir_root/d03.Intermediate.Output/Hosp_demographics2_20160523.dta", replace		
	

//Add in population density of the hospital's county from Census 2000
	use "$dir_root/d01.RawData/Census2000/popdensity1999_by_county.dta", clear
	rename gct_stubtargetgeoid2 hosp_id_countyfips
	drop if substr(var7,1,6)=="Census"
	rename hc08 pop_per_sqmile
	rename hc09 hous_per_sqmile
	label variable pop_per_sqmile "popln per sq mile of the county, Census 2000"
	label variable hous_per_sqmile "housing units per sq mile of the county, Census 2000"
	keep hosp_id_countyfips pop hous
	sum
	save "$dir_root/d03.Intermediate.Output/popdensity_county_cleaned.dta", replace



use "$dir_root/d03.Intermediate.Output/Hosp_demographics2_20160523.dta"		
sort oshpdid
merge 1:1 oshpdid using "$dir_root/d03.Intermediate.Output/WTPcalc/hospital_charas5_20160523.dta", keepusing(hosp_id_county)
keep if _merge==3
drop _merge
rename hosp_id_county county
merge m:1 county using "$dir_root/d03.Intermediate.Output/CountyNameCrosswalk_Link_countyfips.dta"  
drop if _merge==2
drop _merge
rename county hosp_id_county
rename countyfips hosp_id_countyfips
merge m:1 hosp_id_countyfips using "$dir_root/d03.Intermediate.Output/popdensity_county_cleaned.dta"
drop if _merge==2
drop _merge
drop zipcode hosp_id_county description hosp_id_countyfips
la data "Hospital Demographics (create_2_demog_HospVbles.do) created `c(current_date)'"

save "$dir_root/d03.Intermediate.Output/Hosp_demographics2_20160523.dta", replace



log close
