//Calculation of WTP variable using method from Ho (2006)

*=====================================
global dir_root     /home/HC
global dir_raw 		$dir_root/d01.RawData
global dir_log 		$dir_root/d02.Scripts.and.Logs
global dir_intout 	$dir_root/d03.Intermediate.Output
global dir_out 		$dir_root/d04.Cleaned.Output
global dir_temp 	$dir_root/d99.Temp

clear
set more off
cap log close
*=====================================

log using "$dir_log/Logs/WTPcalcn_Part1_20160523.log", text replace

//Begin with ZipHsaHrr03.dta, pulled from Dartmouth Atlas website, lists the zipcodes in each HRR 
	use "$dir_raw/DartmouthAtlas/ZipHsaHrr03.dta"
	des
	count
	keep if hrrstate=="CA"
	keep zipcode03 hrrnum hrrcity
	egen numhrr = group(hrrnum)
	sum numhrr      
	drop numhrr
	tab hrrcity
	sort zipcode03
	save "$dir_intout/WTPcalc/WTP_data120612.dta", replace

//Now add in lat/long and ave income for each zipcode from zip-codes.com (October 2004 data)
	use "$dir_raw/zipcodes/zip-codes-databases-DELUXE_100104_CA.dta"          
	des
	tab state
	tab msa
	keep if primaryrecord=="P"    
	count              
	rename zipcode zipcode03
	sort zipcode03
	merge 1:m zipcode03 using "$dir_intout/WTPcalc/WTP_data120612.dta"
	sum population householdsper* if _merge==1   
	sum population householdsper* if _merge==3
	drop if  _merge==2           
	drop _merge
	keep zipcode03 latitude longitude incomeperhousehold population msa msaname hrrnum hrrcity countyfips
	label variable latitude "lat of zipcode03 from zip-codes.com, 2004 data"
	label variable longitude "long of zipcode03 from zip-codes.com, 2004 data"
	rename incomeperhousehold hhinc
	replace hhinc = hhinc/1000
	
	sum hhinc, detail
	replace hhinc = 22.151 if hhinc<22.151
	replace hhinc = 87.486 if hhinc>87.486
	
	label variable hhinc "mean household income, $000, from zip-codes.com, 2004 data"
	label variable msa "msacode of zipcode03 from zip-codes.com, 2004 data"
	label variable population "popln of zipcode03 from zip-codes.com, 2004 data"
	sort zipcode03
	sum
	save "$dir_intout/WTPcalc/WTP_data120612.dta", replace   

//Now merge with hsa variable from OSHPD03
	rename zipcode03 patzip
	merge m:1 patzip using "$dir_raw/OSHPD03/oshpd03_patzip_hsa.dta"
	drop if _merge==2 	
	drop _merge
	bys countyfips: egen maxhsa = max(hsap)
	bys countyfips: egen minhsa = min(hsap)
	replace hsap = maxhsa if maxhsa==minhsa & hsap==.   		
	drop maxhsa minhsa
	rename hsap hsa
	rename patzip zipcode03
	tab hsa
	save "$dir_intout/WTPcalc/WTP_data120612.dta", replace   
		
*Generate Zipcode-HSA crosswalk
	u "$dir_intout/WTPcalc/WTP_data120612.dta", replace
	keep zipcode03 hsa
	so zipcode03 
	la data "Zip-HSA Crosswalk (create_4_WTPcalcn_Part1_20130214.do) created `c(current_date)'"
	sa "$dir_intout/crosswalk_zip-hsa.dta", replace
	

//Create an observation for each age/gender within each zipcode, and add number of admissions to hospital from each age/gender/zip (OSHPD data) to the dataset
	use "$dir_raw/OSHPD03/oshpd03_zipagesexdiag.dta", clear
	collapse (sum) patzip, by(agecat_Ho sex)
	drop patzip
	gen zipcode03 = 90001   
	save "$dir_intout/WTPcalc/work.dta", replace
	
	use "$dir_intout/WTPcalc/WTP_data120612.dta"
	sort zipcode03
	merge zipcode03 using "$dir_intout/WTPcalc/work.dta", sort uniqmaster
	tab _merge
	rename _merge _merge1     
	replace sex=1 if sex==.
	replace agecat_Ho=1 if agecat_Ho==.         
	fillin zipcode03 sex agecat_Ho  
	count                  
	drop hhinc latitude longitude msa msaname hrrnum hrrcity population hsa
	sort zipcode03
	merge zipcode03 using "$dir_intout/WTPcalc/WTP_data120612.dta", sort uniqusing
	tab _merge
	drop _merge _merge1 _fillin
	sort zipcode03 sex agecat_Ho
	save "$dir_intout/WTPcalc/WTP_data120612_2hsa.dta", replace
	
	
	sort sex agecat_Ho
	drop if agecat_Ho==6    
	
	merge sex agecat_Ho using "$dir_intout/WTPcalc/agesex_data.dta", sort uniqusing
	tab _merge
	drop _merge  
	
	gen priv_pop = 0.57*population      
	replace priv_pop = floor(priv_pop)
	label variable priv_pop "priv insured under-65 pop of zip: pop*0.57 (% of CA pop priv insured in CA 2003 (kff.org); assume none are >65)"
	gen mkt_pop = priv_pop * p_CApop
	replace mkt_pop = floor(mkt_pop)
	label variable mkt_pop "priv insured pop of zip-age-sex: priv_pop*p_CApop"


	bys sex agecat_Ho: egen pop_agesex = total(mkt_pop)
	gen p_adm = numadm / pop_agesex
	drop pop_agesex
	label variable p_adm "P(adm|priv insured, age, sex) = OSHPD03 num priv adm in age/sex, excl newborns, / sum(mkt_pop) across zips"
	save "$dir_intout/WTPcalc/WTP_data120612_2hsa.dta", replace


	sort zipcode03 sex agecat_Ho
	merge zipcode03 sex agecat_Ho using "$dir_intout/WTPcalc/prob_adms_agesexzipinf.dta", sort uniqmaster
	tab _merge           
	drop if _merge==2   
	corr(mkt_pop pop_inf) if _merge==3    
	sum mkt_pop pop_inf if _merge==3, detail   
	sum pop_inf if mkt_pop==0 & _merge==3, detail     
	sum pop_inf if mkt_pop>0 & _merge==3, detail      
	tab zipcode03 if mkt_pop==0 & _merge==3
	sum mkt_pop if _merge==1               
	sum mkt_pop if _merge==1 & mkt_pop==0	
	drop _merge pop_inf numpats_zip_oshpd p_adm_calpers
	save "$dir_intout/WTPcalc/WTP_data120612_2hsa.dta", replace
	
	
	count
	drop if population < 100  
	count
	save "$dir_intout/WTPcalc/WTP_data120612_3hsa.dta", replace    
	
    

******************************
*Calculate p(admit w/ given diagnosis l | zip)
******************************
	u "$dir_intout/WTPcalc/WTP_data120612_3hsa.dta", replace 
	keep zipcode agecat_Ho sex hsa mkt_pop p_*
	
	bysort zipcode: egen totzip_pop = total(mkt_pop)

	local diags "cancer cardiac digestive labor neuro othercode"
	foreach x of local diags  {
		gen n_adm_`x' = mkt_pop * p_adm * p_`x'
		bysort zipcode: egen totzip_adm_`x' = total(n_adm_`x')
		bysort zipcode: gen double p_adm`x' = totzip_adm_`x' / totzip_pop
		la var p_adm`x' "p(admit w/ `x' | zip)"
	}
	keep zipcode hsa p_adm* totzip_pop
	drop p_adm
	duplicates drop zipcode, force
	label data "p(admit w/ given diagnosis l | zip) created in create_4_WTPcalcn_Part1"
	sa "$dir_intout/WTPcalc/WTP_pradmdiag_zip.dta", replace 	
		
******************************
*Determine share of patients w/in zip for given diagnosis that go to a hospital 
	use "$dir_raw/OSHPD03/oshpd03_hospzipdiag.dta", clear
	collapse (sum) numpats, by(oshpdid patzip diagnosis)    
	drop if diagnosis=="newborn"
	rename patzip zipcode03	
	merge m:1 zipcode03 using "$dir_intout/crosswalk_zip-hsa.dta"	
	keep if _merge==3
	bysort zipcode03 diagnosis: egen totalpats_zipdiag = total(numpats)
	bysort zipcode03 diagnosis oshpdid: egen totalpats_hospzipdiag = total(numpats)
	bysort zipcode03 diagnosis oshpdid: gen sobs_hjl = totalpats_hospzipdiag / totalpats_zipdiag
	label var sobs_hjl "hosp share (discharge) of admits with diag l in zip (discharge)"
	drop totalpats_*
	duplicates drop oshpdid zipcode03 diagnosis, force 
	keep oshpdid hsa zipcode03 diagnosis sobs_hjl
	reshape wide sobs_hjl, i(oshpdid hsa zipcode03) j(diagnosis) string
	
	*Bring in probabilities of admitted w/ diag in HSA to determine \gamma_l x \sigma_{hjl}
	merge m:1 zipcode03 using "$dir_intout/WTPcalc/WTP_pradmdiag_zip.dta"
	drop if _merge==2
	drop _merge
	local diags "cancer cardiac digestive labor neuro othercode"
	foreach x of local diags  {
		egen temp =  mean(p_adm`x') 
		replace p_adm`x' = temp if p_adm`x'==.
		drop temp
	}
	
	

	
	label data "gamma_l, share_hjl() created in create_4_WTPcalcn_Part1"
	sa "$dir_intout/WTPcalc/WTP_sharehjl_pradmdiag_zip.dta", replace 	

	
******************************
	u "$dir_intout/WTPcalc/WTP_data120612_3hsa.dta", replace
	
	drop if hsa==.
	joinby hsa using "$dir_intout/WTPcalc/hospital_charas5_20160523.dta"		
	count
	globdist hospdist, lat0(latitude) lon0(longitude) latvar(hosplat) lonvar(hosplong) miles
	label variable hospdist "Dist (mi) from patient zip"
	generate hospdistsq = hospdist*hospdist
	sum hospdist
	drop if hospdist>100    
	
	*Merge in probabilities
	merge m:1 oshpdid zipcode03 using "$dir_intout/WTPcalc/WTP_sharehjl_pradmdiag_zip.dta"
	drop if _merge==2
	drop _merge
	foreach x of local diags  {
		egen temp = mean(p_adm`x')
		replace p_adm`x' = temp if p_adm`x'==.
		drop temp
		replace sobs_hjl`x' = 0 if sobs_hjl`x'==.
	}
		
	merge m:1 hsa oshpdid using "$dir_intout/WTPcalc/hospital_deltas_20160523.dta"	/* <== 2016.05.23 PUT NEW FILE NAME HERE */
	
	drop _merge
	generate teach2_inc = teach2*hhinc
	generate FP_inc = FP*hhinc
	generate nurseperbed_inc = nurseperbed*hhinc
	generate qualcard_inc = qualcardiac*hhinc
	generate qualimag_inc = qualimaging*hhinc
	generate qualcanc_inc = qualcancer2*hhinc
	generate qualbirth_inc = qualbirths2*hhinc
	
	forvalues y = 1(1)14 {
			gen dum_hsa_`y' = 0
			replace dum_hsa_`y' = 1 if hsa==`y'
		}
	forvalues y=1(1)14  {
		gen hsa_`y'_hospdist = dum_hsa_`y'*hospdist
		}
	
	
	
	gen u_ihl_othercodeBS = delta - 0.107*hsa_1_hospdist - 0.155*hsa_2_hospdist - 0.235*hsa_3_hospdist - 0.274*hsa_4_hospdist - 0.240*hsa_5_hospdist - 0.186*hsa_6_hospdist - 0.246*hsa_7_hospdist - 0.149*hsa_8_hospdist - 0.106*hsa_9_hospdist - 0.165*hsa_10_hospdist - 0.276*hsa_11_hospdist - 0.132*hsa_12_hospdist - 0.312*hsa_13_hospdist - 0.114*hsa_14_hospdist + .0077*teach2_inc + 0.000119*nurseperbed_inc - 0.000484*FP_inc + 0.00770*qualcard_inc - 0.00340*qualimag_inc - 0.0131*qualcanc_inc + 0.00561*qualbirth_inc
	
	gen u_ihl_cancerBS = u_ihl_othercodeBS + .098*teach2 + 0.121*nurseperbed + 0.0116*FP + 0.1394*qualimaging + 0.4437*qualcancer2
	gen u_ihl_cardiacBS = u_ihl_othercodeBS - .521*teach2 + 0.0734*nurseperbed + 0.107*FP + .2511*qualcardiac + 0.0491*qualimaging 
	gen u_ihl_digestiveBS = u_ihl_othercodeBS - 0.237*teach2 - 0.0866*nurseperbed - .122*FP + .0372*qualimaging
	gen u_ihl_laborBS = u_ihl_othercodeBS - .0695*teach2 - 0.1789*nurseperbed + 0.324*FP - 0.475*qualimaging + 1.164*qualbirths2
	gen u_ihl_neuroBS = u_ihl_othercodeBS + 1.281*teach2 - 1.009*nurseperbed + 0.609*FP - 0.775*qualimaging
	foreach x of local diags {
			gen u_ihl_`x'BC = u_ihl_`x'BS + .123*teach2 + .0540*nurseperbed + 0.0334*FP + .254*qualcardiac + .142*qualimaging - .133*qualcancer2 - .168*qualbirths2
	}
	
		
	save "$dir_intout/WTPcalc/WTP_data20160523_5hsa.dta", replace	
	
log close
