//Calculation of WTP variable using method from Ho (2006)

*=====================================
global dir_root     /home/HC

global dir_raw 		$dir_root/d01.RawData
global dir_log 		$dir_root/d02.Scripts.and.Logs
global dir_intout 	$dir_root/d03.Intermediate.Output
global dir_out 		$dir_root/d04.Cleaned.Output
global dir_temp 	$dir_root/d99.Temp

clear
set more off
cap log close
*=====================================

log using "$dir_log/Logs/WTPcalcn_Part2_system_20160523.log", text replace

set type double

	*Only set this to 1 if this has been run already at least once (to get DeltaWTP measures to interact with instruments)
	local ImportDeltaWTP 1

	use "$dir_intout/WTPcalc/WTP_data20160523_5hsa.dta", replace	
	
	if "`ImportDeltaWTP'"=="1" {
		merge m:1 oshpdid using	"$dir_intout/WTPcalc/DeltaWTP_only_sys_20160523.dta"	
		drop _merge
	}

	rensfix logical
	sa "$dir_intout/WTPcalc/WTP_data20160523_6hsa_sys.dta", replace		


	*************************
	* PART 2 
	*************************			
	*=========================
	* Create WTP variable for each insurer (the HMO)
	*=========================
	foreach insurer in BS BC {
		clear
		use "$dir_intout/WTPcalc/WTP_data20160523_6hsa_sys.dta", replace
		drop if is`insurer'==0    
				

		if "`ImportDeltaWTP'"=="0" {
			gen deltaWTP = 0
			gen deltaWTP_sys = 0
		}

		egen numhosp = group(oshpdid)
		sum numhosp               
		drop numhosp
		gen price = avg_amt_drgadj_`insurer'

		*fill in missing prices
		replace price =. if price==0
		bys hsa: egen ave_price = mean(price)
		gen err = price - ave_price
		sum err if price~=.
		gen price_imp = price
		replace price_imp = ave_price if price_imp==. | price_imp==0

		rensfix `insurer' 		
			
		keep hrrnum hsa oshpdid zipcode03 sex agecat_Ho p_adm* mkt_pop p_* u_ihl* avg_amt* price_imp pay_peradm exp_peradm deltaWTP deltaWTP_sys sysid
		drop p_CApop     

		
		local diags "cancer cardiac digestive labor neuro othercode"
	
		foreach x of local diags  {
			gen expu_ihl_`x' = exp(u_ihl_`x')
			bys zipcode03 sex agecat_Ho: egen sumexpu_ihl_`x' = total(expu_ihl_`x')
			gen s_ihl_`x' = expu_ihl_`x' / sumexpu_ihl_`x'
			la var s_ihl_`x' "Hosp Share of ins admits of `x' in zipcode, computed from demand system"
			gen double EU_ijl_`x' = ln(sumexpu_ihl_`x')
		}
		drop sumexpu*
		egen numhosp = group(oshpdid)    
		save  "$dir_intout/WTPcalc/WTP_data20160523_6hsa_`insurer'_sys.dta", replace	
		
		
        *Create a system/hospital identifier: sysid if there is one, or oshpdid if not. Then make sure it differs by market. This syshos-hsa pair will be the bargaining unit.
		destring sysid, replace
		sum sysid
		gen syshos = sysid
		replace syshos = oshpdid if syshos==.
		replace syshos = syshos*100+hsa
		egen numsyshos = group(syshos)
		save  "$dir_intout/WTPcalc/WTP_data20160523_6hsa_`insurer'_sys.dta", replace	
			
		****		
		*Collapse to a market, and within each one, remove a hospital and find EU_ihl_diag_no_h
		****
		bys zipcode03 sex agecat_Ho: gen numchoice = [_n]
		bys zipcode03 sex agecat_Ho: egen numchoice2 = max(numchoice)
		drop numchoice
		save, replace
		keep if numchoice2==1
		rename syshos syshos_drop
		rename oshpdid oshpdid_drop
		foreach x of local diags   {
			gen deltaEU_ihjl_`x' = EU_ijl_`x' - 1000
			gen deltaEU_ihjl_`x'_sys = EU_ijl_`x' - 1000
			gen s_price_ihjl_`x' = 0
			gen s_price_ihjl_`x'_drop = 0
			gen s_price_ihjl_`x'_drop_sys = 0				
			gen ds_price_ihjl_`x' = 0
			gen ds_price_ihjl_`x'_sys = 0
		}
		keep zipcode03 sex agecat_Ho deltaEU* ds_price* s_price* deltaWTP hrrnum hsa p_* mkt_pop syshos_drop oshpdid_drop
		order zipcode03 sex agecat_Ho deltaEU* ds_price* s_price* deltaWTP hrrnum hsa p_* mkt_pop syshos_drop oshpdid_drop
		save "$dir_intout/WTPcalc/deltaEU_1hsa_sys_20160523.dta", replace		
		
		
		*===============================================
		keep zipcode03 sex agecat_Ho hsa hrrnum oshpdid_drop
		gen oshpdid = oshpdid_drop   
		gen sigmaH_kijm_drop = 0
		gen sigmaH_kijm_drop_sys = 0
		order zipcode03 sex agecat_Ho hsa hrrnum oshpdid oshpdid_drop sigmaH_kijm_drop sigmaH_kijm_drop_sys 
		save "$dir_intout/sigmaH_drop_1_20160523.dta", replace		
		
		u "$dir_intout/WTPcalc/deltaEU_1hsa_sys_20160523.dta"
		keep zipcode03 sex agecat_Ho hsa hrrnum p_* oshpdid_drop s_price_*_drop s_price_*_drop_sys
		rename s_price_ihjl_*_drop EU_ijl_*_drop 
		rename s_price_ihjl_*_drop_sys EU_ijl_*_drop_sys 
		save "$dir_intout/EU_drop_1_20160523.dta", replace
		*==================================================
		
		
			
		*Look at the markets with >1 hospital (may still be just one system)
		use "$dir_intout/WTPcalc/WTP_data20160523_6hsa_`insurer'_sys.dta", replace
		drop if numchoice2==1
		bys zipcode03 sex agecat_Ho: egen maxnumsys = max(numsyshos)
		bys zipcode03 sex agecat_Ho: egen minnumsys = min(numsyshos)		
		drop numchoice2 numhosp numsyshos maxnumsys minnumsys
		egen numsyshos = group(syshos)
		egen numhosp = group(oshpdid)   
		sum numhosp
		save "$dir_intout/WTPcalc/WTP_data20160523_7hsa_sys.dta", replace
		
		local numHospRemaining = r(max)
		
		*Go through all hospitals in market.  Remove one.  Calculate diversions to all other hospitals in HSA, by zip-age-sex.
		forvalues i=1(1)`numHospRemaining'   {   								
			disp "`insurer': `i' out of `numHospRemaining'"
			use "$dir_intout/WTPcalc/WTP_data20160523_7hsa_sys.dta"
			replace numhosp = 999 if numhosp==`i'   
			gsort -numhosp
			keep if hsa == hsa[1]    
			gen oshpdid_drop = oshpdid[1]    
			gen syshos_drop = syshos[1] 
			
		
			drop if numhosp==999          
			
			
			foreach x of local diags  {
				bys zipcode03 sex agecat_Ho: egen sumexpu_ihl_`x'_drop = total(expu_ihl_`x')
				gen double s_ihl_`x'_drop = expu_ihl_`x' / sumexpu_ihl_`x'_drop					
				gen double delta_s_ihl_`x' = s_ihl_`x' - s_ihl_`x'_drop
			
				gen double s_price_ihjl_`x' = s_ihl_`x' * price_imp
				gen double s_price_ihjl_`x'_drop = s_ihl_`x'_drop * price_imp
				gen double ds_price_ihjl_`x' = delta_s_ihl_`x' * price_imp

				gen double s_exppa_ihjl_`x' = s_ihl_`x' * exp_peradm
				gen double s_exppa_ihjl_`x'_drop = s_ihl_`x'_drop * exp_peradm
				gen double ds_exppa_ihjl_`x' = delta_s_ihl_`x' * exp_peradm
				
				gen double s_paypa_ihjl_`x' = s_ihl_`x' * pay_peradm
				gen double s_paypa_ihjl_`x'_drop = s_ihl_`x'_drop * pay_peradm
				gen double ds_paypa_ihjl_`x' = delta_s_ihl_`x' * pay_peradm

				gen double s_dWTP_ihjl_`x' = s_ihl_`x' * deltaWTP
				gen double s_dWTP_ihjl_`x'_drop = s_ihl_`x'_drop * deltaWTP
				gen double ds_dWTP_ihjl_`x' = delta_s_ihl_`x' * deltaWTP
				
				gen double EU_ijl_`x'_drop = ln(sumexpu_ihl_`x'_drop)
				gen double deltaEU_ihjl_`x' = EU_ijl_`x' - EU_ijl_`x'_drop
			}				
			
			preserve
				collapse (sum) ds_price_ihjl* s_price_ihjl*  ds_paypa* s_paypa* ds_exppa* s_exppa* ds_dWTP* s_dWTP* (mean)deltaEU* hrrnum hsa p_* mkt_pop oshpdid_drop, by(zipcode03 sex agecat_Ho)
				tempfile droponlyhosp
				sa `droponlyhosp'	
				
				*======================================
			restore
			
			preserve
				collapse (mean) EU_ijl_*_drop hrrnum hsa p_* oshpdid_drop, by(zipcode03 sex agecat_Ho)
				tempfile EUdroponlyhosp
				sa `EUdroponlyhosp'
				*==========================================
				
			restore
			
			preserve
			
				*==========================			
				*Keep just the sH variables you'll need at micro (kijh) level
				keep s_ihl_*_drop hrrnum hsa p_* oshpdid oshpdid_drop zipcode03 sex agecat_Ho
				gen s_kij_drop = 0		
				local diags "cancer cardiac digestive labor neuro othercode"
				foreach x of local diags  {
					replace s_kij_drop = s_kij_drop + s_ihl_`x'_drop*p_`x'
				} 	
				gen sigmaH_kijm_drop = p_adm * s_kij_drop
				keep hrrnum hsa oshpdid oshpdid_drop zipcode03 sex agecat_Ho sigmaH_kijm_drop 				
				
				tempfile sharedroponlyhosp
				sa `sharedroponlyhosp'
			restore
			
				*============================
			
			*Drop whole system aligned with oshpdid_drop
			bys zipcode03 sex agecat_Ho: egen maxnumsys = max(numsyshos)
			bys zipcode03 sex agecat_Ho: egen minnumsys = min(numsyshos)
			
			preserve
				*look first at zip-age-sex's where dropping this system leaves no hospitals. Only want to do this if there are any such zips.
				gen onesys = 0
				replace onesys=1 if maxnumsys==minnumsys & syshos==syshos_drop
				egen existonesys = max(onesys)
				if existonesys[1]>0            {				
				
					keep if maxnumsys==minnumsys & syshos==syshos_drop    
					foreach x of local diags {
						gen double s_ihl_`x'_drop_sys = 0
						gen double delta_s_ihl_`x'_sys = 0
						gen double s_price_ihjl_`x'_drop_sys = 0
						gen double ds_price_ihjl_`x'_sys = 0
						gen double s_exppa_ihjl_`x'_drop_sys = 0
						gen double ds_exppa_ihjl_`x'_sys = 0
						gen double s_paypa_ihjl_`x'_drop_sys = 0
						gen double ds_paypa_ihjl_`x'_sys = 0
						gen double s_dWTP_ihjl_`x'_drop_sys = 0
						gen double ds_dWTP_ihjl_`x'_sys = 0
					
						gen deltaEU_ihjl_`x'_sys = EU_ijl_`x' - 1000
					}
					*Sum over all other hospitals in a market (excluding all system hospitals)
					collapse (sum) s_*_sys ds_*_sys (mean) deltaEU*_sys oshpdid_drop, by(zipcode03 sex agecat_Ho)
		
					so oshpdid_drop
					merge 1:1 zipcode03 sex agecat_Ho using `droponlyhosp', keep(match)
					drop _merge
					append using "$dir_intout/WTPcalc/deltaEU_1hsa_sys_20160523.dta"
					save "$dir_intout/WTPcalc/deltaEU_1hsa_sys_20160523.dta", replace	
				
				}
			
			*for other zip-age-sex, where we can drop this system and still have others, go ahead and drop the system and fill in numbers for the others
			restore 
				drop if maxnumsys==minnumsys & syshos==syshos_drop 
				drop if syshos==syshos_drop          
				foreach x of local diags  {
					bys zipcode03 sex agecat_Ho: egen sumexpu_ihl_`x'_drop_sys = total(expu_ihl_`x')
					gen double s_ihl_`x'_drop_sys = expu_ihl_`x' / sumexpu_ihl_`x'_drop_sys
					gen double delta_s_ihl_`x'_sys = s_ihl_`x' - s_ihl_`x'_drop_sys
					gen double s_price_ihjl_`x'_drop_sys = s_ihl_`x'_drop_sys * price_imp
					gen double ds_price_ihjl_`x'_sys = delta_s_ihl_`x'_sys * price_imp

					gen double s_exppa_ihjl_`x'_drop_sys = s_ihl_`x'_drop_sys * exp_peradm
					gen double ds_exppa_ihjl_`x'_sys = delta_s_ihl_`x'_sys * exp_peradm
				
					gen double s_paypa_ihjl_`x'_drop_sys = s_ihl_`x'_drop_sys * pay_peradm
					gen double ds_paypa_ihjl_`x'_sys = delta_s_ihl_`x'_sys * pay_peradm

					gen double s_dWTP_ihjl_`x'_drop_sys = s_ihl_`x'_drop_sys * deltaWTP_sys
					gen double ds_dWTP_ihjl_`x'_sys = delta_s_ihl_`x'_sys * deltaWTP_sys
				
					gen double EU_ijl_`x'_drop_sys = ln(sumexpu_ihl_`x'_drop_sys)
					gen double deltaEU_ihjl_`x'_sys = EU_ijl_`x' - EU_ijl_`x'_drop_sys
				}		
			
			preserve
				collapse (sum) s_*_sys ds_*_sys (mean) deltaEU*_sys oshpdid_drop, by(zipcode03 sex agecat_Ho)
		
				so oshpdid_drop
				merge 1:1 zipcode03 sex agecat_Ho using `droponlyhosp', keep(match)
				drop _merge
				append using "$dir_intout/WTPcalc/deltaEU_1hsa_sys_20160523.dta"
				save "$dir_intout/WTPcalc/deltaEU_1hsa_sys_20160523.dta", replace	
				
			restore
			preserve
				*=========================================================================
				collapse (mean) EU_ijl_*_drop_sys oshpdid_drop, by(zipcode03 sex agecat_Ho)
				so oshpdid_drop
				
							
				merge 1:1 zipcode03 sex agecat_Ho using `EUdroponlyhosp'
				drop _merge
				append using "$dir_intout/EU_drop_1_20160523.dta"
				save "$dir_intout/EU_drop_1_20160523.dta", replace
				
			restore
				*===========================================================================================
				keep s_ihl_*_drop_sys oshpdid oshpdid_drop zipcode03 sex agecat_Ho p_*
				
				gen s_kij_drop_sys = 0
				local diags "cancer cardiac digestive labor neuro othercode"
				foreach x of local diags  {
					replace s_kij_drop_sys = s_kij_drop_sys + s_ihl_`x'_drop_sys * p_`x'
				} 
				gen sigmaH_kijm_drop_sys = p_adm * s_kij_drop_sys

				keep oshpdid oshpdid_drop zipcode03 sex agecat_Ho sigmaH_kijm_drop_sys
				so oshpdid_drop
				merge 1:1 zipcode03 sex agecat_Ho oshpdid oshpdid_drop using `sharedroponlyhosp'
				drop _merge
				append using "$dir_intout/sigmaH_drop_1_20160523.dta"
				save "$dir_intout/sigmaH_drop_1_20160523.dta", replace
				*================================================================================================
			
		} 

		use "$dir_intout/WTPcalc/deltaEU_1hsa_sys_20160523.dta"			
		sum deltaEU*, detail
				
		generate deltaWTP_ijh = 0
		generate deltaWTP_ijh_sys = 0
		
		local varsuse "price_ijh paypa_ijh exppa_ijh dWTP_ijh"
		foreach x of local varsuse {
			gen s_`x' = 0
			gen s_`x'_drop = 0
			gen ds_`x' = 0
			gen s_`x'_drop_sys = 0
			gen ds_`x'_sys = 0
		}				

		local diags "cancer cardiac digestive labor neuro othercode"
		foreach x of local diags  {
			replace deltaWTP_ijh = deltaWTP_ijh + deltaEU_ihjl_`x'*p_`x'
			replace deltaWTP_ijh_sys = deltaWTP_ijh_sys + deltaEU_ihjl_`x'_sys*p_`x'
								
			replace s_price_ijh = s_price_ijh +  s_price_ihjl_`x'*p_`x'			
			replace s_price_ijh_drop = s_price_ijh_drop + s_price_ihjl_`x'_drop*p_`x'			
			replace ds_price_ijh = ds_price_ijh +  ds_price_ihjl_`x'*p_`x'
			replace s_price_ijh_drop_sys = s_price_ijh_drop_sys + s_price_ihjl_`x'_drop_sys*p_`x'			
			replace ds_price_ijh_sys = ds_price_ijh_sys +  ds_price_ihjl_`x'_sys*p_`x'

			replace s_paypa_ijh = s_paypa_ijh +  s_paypa_ihjl_`x'*p_`x'			
			replace s_paypa_ijh_drop = s_paypa_ijh_drop + s_paypa_ihjl_`x'_drop*p_`x'			
			replace ds_paypa_ijh = ds_paypa_ijh +  ds_paypa_ihjl_`x'*p_`x'							
			replace s_paypa_ijh_drop_sys  = s_paypa_ijh_drop_sys  + s_paypa_ihjl_`x'_drop_sys *p_`x'			
			replace ds_paypa_ijh_sys  = ds_paypa_ijh_sys  +  ds_paypa_ihjl_`x'_sys *p_`x'	

			replace s_exppa_ijh = s_exppa_ijh +  s_exppa_ihjl_`x'*p_`x'			
			replace s_exppa_ijh_drop = s_exppa_ijh_drop + s_exppa_ihjl_`x'_drop*p_`x'			
			replace ds_exppa_ijh = ds_exppa_ijh +  ds_exppa_ihjl_`x'*p_`x'							
			replace s_exppa_ijh_drop_sys  = s_exppa_ijh_drop_sys  + s_exppa_ihjl_`x'_drop_sys *p_`x'			
			replace ds_exppa_ijh_sys  = ds_exppa_ijh_sys  +  ds_exppa_ihjl_`x'_sys *p_`x'							

			replace s_dWTP_ijh = s_dWTP_ijh +  s_dWTP_ihjl_`x'*p_`x'			
			replace s_dWTP_ijh_drop = s_dWTP_ijh_drop + s_dWTP_ihjl_`x'_drop*p_`x'			
			replace ds_dWTP_ijh = ds_dWTP_ijh +  ds_dWTP_ihjl_`x'*p_`x'							
			replace s_dWTP_ijh_drop_sys  = s_dWTP_ijh_drop_sys  + s_dWTP_ihjl_`x'_drop_sys *p_`x'			
			replace ds_dWTP_ijh_sys  = ds_dWTP_ijh_sys  +  ds_dWTP_ihjl_`x'_sys *p_`x'							
		
		} 
						
		gen gamma_deltaWTP_ijh = p_adm * deltaWTP_ijh
		gen gamma_deltaWTP_ijh_sys = p_adm * deltaWTP_ijh_sys

		local varsuse "price_ijh paypa_ijh exppa_ijh dWTP_ijh"
		foreach x of local varsuse {
			gen gamma_s_`x' = p_adm*s_`x'
			gen gamma_s_`x'_drop = p_adm*s_`x'_drop
			gen gamma_ds_`x' = p_adm*ds_`x'
			gen gamma_s_`x'_drop_sys = p_adm*s_`x'_drop_sys
			gen gamma_ds_`x'_sys = p_adm*ds_`x'_sys
		}				
		
		sum deltaWTP_ijh, detail
		sum ds_price_ijh, detail

		sum deltaWTP_ijh_sys, detail
		sum ds_price_ijh_sys, detail

		collapse (mean) deltaWTP_jhm = deltaWTP_ijh  deltaWTP_jhm_sys = deltaWTP_ijh_sys  gamma_deltaWTP_jhm = gamma_deltaWTP_ijh gamma_deltaWTP_jhm_sys = gamma_deltaWTP_ijh_sys ds_price_jhm = ds_price_ijh s_price_jhm = s_price_ijh s_price_jhm_drop = s_price_ijh_drop gamma_ds_price_jhm = gamma_ds_price_ijh gamma_s_price_jhm = gamma_s_price_ijh gamma_s_price_jhm_drop = gamma_s_price_ijh_drop ds_price_jhm_sys = ds_price_ijh_sys s_price_jhm_drop_sys = s_price_ijh_drop_sys gamma_ds_price_jhm_sys = gamma_ds_price_ijh_sys gamma_s_price_jhm_drop_sys = gamma_s_price_ijh_drop_sys ds_paypa_jhm = ds_paypa_ijh s_paypa_jhm = s_paypa_ijh s_paypa_jhm_drop = s_paypa_ijh_drop gamma_ds_paypa_jhm = gamma_ds_paypa_ijh gamma_s_paypa_jhm = gamma_s_paypa_ijh gamma_s_paypa_jhm_drop = gamma_s_paypa_ijh_drop ds_paypa_jhm_sys = ds_paypa_ijh_sys s_paypa_jhm_drop_sys = s_paypa_ijh_drop_sys gamma_ds_paypa_jhm_sys = gamma_ds_paypa_ijh_sys gamma_s_paypa_jhm_drop_sys = gamma_s_paypa_ijh_drop_sys ds_exppa_jhm = ds_exppa_ijh s_exppa_jhm = s_exppa_ijh s_exppa_jhm_drop = s_exppa_ijh_drop gamma_ds_exppa_jhm = gamma_ds_exppa_ijh gamma_s_exppa_jhm = gamma_s_exppa_ijh gamma_s_exppa_jhm_drop = gamma_s_exppa_ijh_drop ds_exppa_jhm_sys = ds_exppa_ijh_sys s_exppa_jhm_drop_sys = s_exppa_ijh_drop_sys gamma_ds_exppa_jhm_sys = gamma_ds_exppa_ijh_sys gamma_s_exppa_jhm_drop_sys = gamma_s_exppa_ijh_drop_sys ds_dWTP_jhm = ds_dWTP_ijh s_dWTP_jhm = s_dWTP_ijh s_dWTP_jhm_drop = s_dWTP_ijh_drop gamma_ds_dWTP_jhm = gamma_ds_dWTP_ijh gamma_s_dWTP_jhm = gamma_s_dWTP_ijh gamma_s_dWTP_jhm_drop = gamma_s_dWTP_ijh_drop ds_dWTP_jhm_sys = ds_dWTP_ijh_sys  s_dWTP_jhm_drop_sys = s_dWTP_ijh_drop_sys gamma_ds_dWTP_jhm_sys = gamma_ds_dWTP_ijh_sys  gamma_s_dWTP_jhm_drop_sys = gamma_s_dWTP_ijh_drop_sys [w=mkt_pop], by(oshpdid_drop hsa)
		
		gen insurer="`insurer'"
		save "$dir_intout/WTPcalc/deltaEU_2hsa_`insurer'_sys_20160523.dta", replace
		
		*=========================================================
		use "$dir_intout/sigmaH_drop_1_20160523.dta", clear
		gen insurer = "`insurer'"
		save "$dir_intout/sigmaH_drop_`insurer'_20160523.dta", replace
		
		use "$dir_intout/EU_drop_1_20160523.dta", clear
		gen insurer = "`insurer'"
		save "$dir_intout/EU_drop_`insurer'_20160523.dta", replace
		*============================================================
	}
	*=========================
	
	
	foreach insurer in BS BC {			
			
		use "$dir_intout/WTPcalc/WTP_data20160523_6hsa_`insurer'_sys.dta", clear  
		
		keep zipcode03 sex agecat_Ho hsa mkt_pop
		duplicates drop zipcode03 sex agecat_Ho, force
		bysort hsa: egen mkt_pop_hsa = total(mkt_pop)
		keep hsa mkt_pop_hsa
		duplicates drop hsa, force
		tempfile hsa_mktpop
		sa `hsa_mktpop'
		use "$dir_intout/WTPcalc/WTP_data20160523_6hsa_`insurer'_sys.dta", clear  
		merge m:1 hsa using `hsa_mktpop'
		drop _merge
					
		generate double s_ijh = 0
		generate double gamma_s_ijh = 0			

		local diags "cancer cardiac digestive labor neuro othercode"
		foreach x of local diags  {
			replace s_ijh = s_ijh + s_ihl_`x'*p_`x'
			replace gamma_s_ijh = gamma_s_ijh + p_adm*s_ihl_`x'*p_`x'
		}			
	
		gen temp_admpop_s_ijh = gamma_s_ijh * mkt_pop
		bysort oshpdid hsa: egen temp_admpop_s_jh_hsa = total(temp_admpop_s_ijh)

		duplicates drop oshpdid hsa, force
		drop zipcode03 age sex

		bysort hsa: egen temp_admpop_s_hsa = total(temp_admpop_s_jh_hsa)
		gen s_jh = temp_admpop_s_jh_hsa / temp_admpop_s_hsa
		gen gamma_s_jh = temp_admpop_s_jh_hsa / mkt_pop_hsa
		drop temp_adm*

		la var gamma_s_jh "oshpdid share (logit demand) of `insurer' enrollees in zip (gammaXshare)"

		keep hsa oshpdid p_adm s_jh gamma_s_jh
		
		rename oshpdid oshpdid_drop
		merge 1:m oshpdid_drop using "$dir_intout/WTPcalc/deltaEU_2hsa_`insurer'_sys_20160523.dta"
		drop _merge	

		save "$dir_intout/WTPcalc/deltaEU_3hsa_`insurer'_sys_20160523.dta", replace
	}  
	
	
	u "$dir_intout/WTPcalc/deltaEU_3hsa_BS_sys_20160523.dta", clear
	append using "$dir_intout/WTPcalc/deltaEU_3hsa_BC_sys_20160523.dta"

	la data "Hospital WTP EU with Systems (create_4_WTPcalcn_Part2_sys.do) created `c(current_date)'"
	save "$dir_intout/WTPcalc/deltaEU_3hsa_20160523_sys.dta", replace	
	des
	bys insurer: sum deltaWTP*, detail
	
	*============================================================
	u "$dir_intout/sigmaH_drop_BS_20160523.dta", clear
	append using "$dir_intout/sigmaH_drop_BC_20160523.dta"
	
	la data "Share of insurer j's enrollment going to h when i dropped, for all h in i's HSA, by zip-age-sex-diag, created create_4_WTPcalcn_Part2_sys_2015.do created `c(current_date)'"
	save "$dir_intout/sigmaH_drop1_20160523.dta", replace
	
	u "$dir_intout/EU_drop_BS_20160523.dta", clear
	append using "$dir_intout/EU_drop_BC_20160523.dta"
	
	la data "EU for insurer j when i dropped, by zip-age-sex-diag, created create_4_WTPcalcn_Part2_sys_2015.do created `c(current_date)'"
	save "$dir_intout/EU_dropdiag_20160523.dta", replace
	*==============================================================
				
				
	*=========================				
	*After running once, re-run this to construct deltaWTP instruments	
	*=========================
	
		u "$dir_intout/WTPcalc/deltaEU_3hsa_20160523_sys.dta", replace
		keep oshpdid_drop deltaWTP_jhm deltaWTP_jhm_sys insurer
		rename oshpdid_drop oshpdid

		gen temp_deltaWTPBS_temp = deltaWTP_jhm if insurer=="BS"
		gen temp_deltaWTPBC_temp = deltaWTP_jhm if insurer=="BC"
		bysort oshpdid: egen deltaWTPBS = max(temp_deltaWTPBS)
		bysort oshpdid: egen deltaWTPBC = max(temp_deltaWTPBC)
		drop temp_*
		
		gen temp_deltaWTPBS_temp = deltaWTP_jhm_sys if insurer=="BS"
		gen temp_deltaWTPBC_temp = deltaWTP_jhm_sys if insurer=="BC"
		bysort oshpdid: egen deltaWTP_sysBS = max(temp_deltaWTPBS)
		bysort oshpdid: egen deltaWTP_sysBC = max(temp_deltaWTPBC)
		
		duplicates drop oshpdid, force
		keep oshpdid deltaWTPB* deltaWTP_sysB*			
		la data "Ohspdid DeltaWTP from dropping a system(create_4_WTPcalcn_Part2_sys.do) created `c(current_date)'"
		sa "$dir_intout/WTPcalc/DeltaWTP_only_sys_20160523.dta", replace		
			
	log close
			
		
