//Take the estimated WTP variable and merge with hospital prices and costs

*=====================================
global dir_root     /home/HC
global dir_raw 		$dir_root/d01.RawData
global dir_log 		$dir_root/d02.Scripts.and.Logs
global dir_intout 	$dir_root/d03.Intermediate.Output
global dir_out 		$dir_root/d04.Cleaned.Output
global dir_temp 	$dir_root/d99.Temp

clear
set more off
cap log close
*=====================================

log using "$dir_log/Logs/merge_WTP_hospcharas_20160523.log", text replace

//Merge with hospital characteristics including costs
use "$dir_intout/WTPcalc/deltaEU_3hsa_20160523_sys.dta", clear		
rename oshpdid_drop oshpdid
sort oshpdid
merge m:1 oshpdid using "$dir_intout/WTPcalc/hospital_charas5_20160523.dta"		
tab _merge
drop if _merge==2
drop _merge isBS isBC
save "$dir_intout/hospital_WTP_charas_hsa_20160523.dta", replace

//Add Kaiser availability variables, created in create_KaiserHospVbles.do
merge m:1 oshpdid using "$dir_intout/Kaiser_HospAvailability_20160523.dta"		

drop if _merge==2   
drop _merge
save "$dir_intout/hospital_WTP_charas_hsa_20160523.dta", replace

use "$dir_raw/Zipcodes/zip-codes-databases-DELUXE_100104_CA.dta"
keep if primaryrecord=="P"
keep zipcode householdsperzipcode population whitepopulation blackpopulation hispanicpopulation averagehousevalue incomeperhousehold personsperhousehold 
rename zipcode hosp_zipcode
merge 1:m hosp_zipcode using "$dir_intout/hospital_WTP_charas_hsa_20160523.dta"
keep if _merge==3
drop _merge
rename population pop_zip2010
rename whitepopulation white_zip2010
rename blackpopulation black_zip2010
rename hispanicpopulation hispanic_zip2010

save "$dir_intout/hospital_WTP_charas_hsa_20160523.dta", replace

//Add ZCTA and county characteristics from Census 2000
merge m:1 oshpdid using "$dir_intout/Hosp_demographics2_20160523.dta"
drop if _merge==2
drop _merge
save "$dir_intout/hospital_WTP_charas_hsa_20160523.dta", replace

gen percwhite_zip2010 = white_zip2010 / pop_zip2010

gen price = avg_amt_drgadj_BS
replace price = avg_amt_drgadj_BC if insurer=="BC"
sum price
gen BC = 0
replace BC = 1 if insurer=="BC"
gen BS = 0
replace BS = 1 if insurer=="BS"

gen nAdmits = nAdmits_BC
replace nAdmits = nAdmits_BS if insurer=="BS"

save, replace

gen deltaWTP_FP = deltaWTP_jhm*FP

*Construct Weighted Price Variables	
drop if price==. | price==0
sum price, detail
regress price deltaWTP_jhm BC exp_peradm 

bys hsa insurer: egen totprice = total(price)   
bys hsa insurer: egen numobs_inhsains = count(price)
gen avg_oth_price = (totprice - price)/(numobs_inhsains-1)   
drop totprice
save "$dir_intout/hospital_WTP_charas_hsa_posprice_20160523.dta", replace


**
*CONSTRUCT SHAREWEIGHTED PRICES FOR OTHER HOSPITALS ON SAME SYSTEM
**
u "$dir_intout/hospital_WTP_charas_hsa_posprice_20160523.dta", replace
	bysort sysid hsa: gen temp = gamma_s_jh * price
	bysort sysid hsa: egen sum_gs_price_othhospinsys = total(temp)
	drop temp
	bysort sysid hsa: gen temp = gamma_s_jh * (price - exp_peradm)
	bysort sysid hsa: egen sum_gs_exppa_othhospinsys = total(temp)
	drop temp
	bysort sysid hsa: gen temp = gamma_s_jh * (price - pay_peradm)
	bysort sysid hsa: egen sum_gs_paypa_othhospinsys = total(temp)
	drop temp
	bysort sysid hsa: gen temp = gamma_s_jh * deltaWTP_jhm
	bysort sysid hsa: egen sum_gs_dWTP_othhospinsys = total(temp)
	drop temp
	bysort sysid hsa: replace sum_gs_price_othhospinsys = sum_gs_price_othhospinsys - (gamma_s_jh*price)
	bysort sysid hsa: replace sum_gs_exppa_othhospinsys = sum_gs_exppa_othhospinsys - (gamma_s_jh*(exp_peradm))
	bysort sysid hsa: replace sum_gs_paypa_othhospinsys = sum_gs_paypa_othhospinsys - (gamma_s_jh*(pay_peradm))
	bysort sysid hsa: replace sum_gs_dWTP_othhospinsys = sum_gs_dWTP_othhospinsys - (gamma_s_jh*(deltaWTP_jhm))
	la var sum_gs_price_othhospinsys "\$ \sum_{h\in s_i, h\neq i} \sigma_{hj} p_{jh} \$"
	la var sum_gs_paypa_othhospinsys "\$ \sum_{h\in s_i, h\neq i} \sigma_{hj} c_{h} \$"
	la var sum_gs_exppa_othhospinsys "\$ \sum_{other.hosps.in.sys} \sigma_{hj} exppadm \$"
	la var sum_gs_dWTP_othhospinsys "\$ \sum_{other.hosps.in.sys} \sigma_{hj} \Delta WTP \$"
	
	
	destring sysid, replace
	gen syshos = sysid
	replace syshos = oshpdid if syshos==.
	*hsa is from 1/14, so multiply syshos by 100 and add hsa: now a system has different syshos ID's in different markets.
	replace syshos = syshos*100+hsa
	egen numsyshos = group(syshos)
	sum numsyshos
	local numSysRemaining = r(max)

	*weight Kaiservar for system by either s_jh or deltaWTP_jhm
	local weightUSE deltaWTP_jhm
	drop if deltaWTP_jhm < 0
	
	local distance_list 1 2 3 4 5 6 7 10 15 20
	local time_list 5 10 15 20 25 30 35
	foreach distance of numlist `distance_list' {
		gen waKaiserHospin`distance'mi_04_sys = 0
		gen waKaiserHospin`distance'mi_95_sys = 0
		gen KaiserHospin`distance'mi_04_sys = 0
		gen KaiserHospin`distance'mi_95_sys = 0
		forvalues i=1(1)`numSysRemaining'   {									
			quietly sum waKaiserHospin`distance'mi_04 [w=`weightUSE'] if numsyshos==`i'
			quietly replace waKaiserHospin`distance'mi_04_sys = r(mean) if numsyshos==`i'
			quietly sum waKaiserHospin`distance'mi_95 [w=`weightUSE'] if numsyshos==`i' 
			quietly replace waKaiserHospin`distance'mi_95_sys = r(mean) if numsyshos==`i'			
			quietly sum KaiserHospin`distance'mi_04 [w=`weightUSE'] if numsyshos==`i'
			quietly replace KaiserHospin`distance'mi_04_sys = r(mean) if numsyshos==`i'
			quietly sum KaiserHospin`distance'mi_95 [w=`weightUSE'] if numsyshos==`i' 
			quietly replace KaiserHospin`distance'mi_95_sys = r(mean) if numsyshos==`i'			
		}
	}
	foreach time of numlist `time_list' {
		gen waKaiserHospin`time'mins_04_sys = 0
		gen KaiserHospin`time'mins_04_sys = 0
		gen waKaiserHospin`time'mins_95_sys = 0
		gen KaiserHospin`time'mins_95_sys = 0
		forvalues i=1(1)`numSysRemaining'   {									
			quietly sum waKaiserHospin`time'mins_04 [w=`weightUSE'] if numsyshos==`i'
			quietly replace waKaiserHospin`time'mins_04_sys = r(mean) if numsyshos==`i'
			quietly sum KaiserHospin`time'mins_04 [w=`weightUSE'] if numsyshos==`i'
			quietly replace KaiserHospin`time'mins_04_sys = r(mean) if numsyshos==`i'

			quietly sum waKaiserHospin`time'mins_95 [w=`weightUSE'] if numsyshos==`i'
			quietly replace waKaiserHospin`time'mins_95_sys = r(mean) if numsyshos==`i'
			quietly sum KaiserHospin`time'mins_95 [w=`weightUSE'] if numsyshos==`i'
			quietly replace KaiserHospin`time'mins_95_sys = r(mean) if numsyshos==`i'
		}
	}

	
save "$dir_intout/hospital_WTP_charas_hsa_posprice_20160523.dta", replace

log close
