//Compare Kaiser hospital characteristics to the charas of other hospitals
//Start with hospital_charas5.dta and use similar code to create_1_hospcharas.do to generate similar characteristics for Kaiser hospitals.

*=====================================
global dir_root     /home/HC
global dir_raw 		$dir_root/d01.RawData
global dir_log 		$dir_root/d02.Scripts.and.Logs
global dir_intout 	$dir_root/d03.Intermediate.Output
global dir_out 		$dir_root/d04.Cleaned.Output
global dir_temp 	$dir_root/d99.Temp

clear
set more off
cap log close
*=====================================

log using "$dir_log/Logs/compare_Kaiser_hosp_20160523.log", text replace

//Put together AHA data for Kaiser hospitals
	use "$dir_raw/AHA/aha_extract03.dta"
	keep if substr(mname,1,6)=="Kaiser" | substr(mname,1,12)=="St Dominic's"
	keep if stcd=="93"
	keep mname id reg stcd hrrcode hsacode cntrl serv sysid bdtot cclabhos radthhos angiohos ftern ftemd fteres mapp1 mapp2 mapp3 mapp5 mapp8 nichos oncolhos obhos emdephos mammshos brnhos ultsnhos mrihos cichos exptot paytot admtot ipdtot 
	gen exp_peradm = exptot/(admtot)
	gen pay_peradm = paytot/ (admtot)
	save "$dir_intout/WTPcalc/work_kaiser.dta", replace

	use "$dir_raw/AHA/aha_addnaldata_03.dta"
	keep if substr(mname,1,6)=="Kaiser" | substr(mname,1,12)=="St Dominic's"
	keep if stcd=="93"
	keep id reg stcd subs ipahos foundhos ipfeehos osteo ctscnhos pethos specthos alcophos ohsrghos mloczip
	merge id reg stcd using "$dir_intout/WTPcalc/work_kaiser.dta", sort uniqusing
	tab _merge
	drop _merge
	save "$dir_intout/WTPcalc/work_kaiser.dta", replace
	
	
	use "$dir_raw/AHA/aha_addnaldata_04.dta"
	keep if substr(mname,1,6)=="Kaiser" | substr(mname,1,12)=="St Dominic's"
	keep if stcd=="93"
	keep id reg stcd broomhos 
	merge id reg stcd using "$dir_intout/WTPcalc/work_kaiser.dta", sort uniqusing
	tab _merge
	drop _merge
	save "$dir_intout/WTPcalc/work_kaiser.dta", replace


	rename id ahaidno
	destring ahaidno, replace

	save "$dir_intout/WTPcalc/hospital_charas_kaiser.dta", replace

	keep if cichos==.
	sum                    
	keep ahaidno reg stcd *hos
	drop broomhos          
	sort ahaidno
	rename *hos *hostemp
	save "$dir_intout/WTPcalc/temp_kaiser.dta", replace
	
	use "$dir_raw/AHA/aha_extract2004.dta", clear
	keep id reg stcd *hos
	keep if stcd=="93" 
	rename id ahaidno
	replace ahaidno="693139" if ahaidno=="693139A"
	destring ahaidno, replace
	merge ahaidno reg stcd using "$dir_intout/WTPcalc/temp_kaiser.dta", sort uniqusing
	tab _merge
	keep if _merge==3
	drop _merge
	local tempvars "alcop ctscn pet spect ipa found ipfee ob cic nic brn mamms emdep oncol mri ultsn"
	foreach x of local tempvars  {
		replace `x'hostemp = `x'hos  
	}  
	
	keep ahaidno reg stcd *temp
	save "$dir_intout/WTPcalc/temp_kaiser.dta", replace  
	
	use "$dir_intout/WTPcalc/hospital_charas_kaiser.dta"
	sort ahaidno reg stcd
	merge ahaidno reg stcd using "$dir_intout/WTPcalc/temp_kaiser.dta", sort uniqusing
	tab _merge      
	local tempvars "alcop ctscn pet spect ipa found ipfee ob cic nic brn mamms emdep oncol mri ultsn"
	foreach x of local tempvars  {
		replace `x'hos = `x'hostemp if _merge==3  
	} 
	
	drop _merge *temp
	
	local vars "broomhos osteo subs alcophos ohsrghos ctscnhos pethos specthos ipahos foundhos ipfeehos obhos cichos nichos brnhos angiohos mammshos cclabhos emdephos oncolhos radthhos mrihos ultsnhos"
	foreach x of local vars  {
		replace `x'=0 if `x'==.
	}

save "$dir_intout/WTPcalc/hospital_charas_kaiser2.dta", replace


//Create the variables we use to create WTP (code for "service" variables, from create_extravbles_fill.do)
	generate qualcardiac = 0
	replace qualcardiac=1 if ohsrghos==1
	replace qualcardiac=0.90 if ohsrghos==0 & angiohos==1
	replace qualcardiac=0.76 if ohsrghos==0 & angiohos==0 & cichos==1
	replace qualcardiac=0.57 if ohsrghos==0 & angiohos==0 & cichos==0 & cclabhos==1
	generate qualimaging=0
	replace qualimaging=1 if pethos==1
	replace qualimaging=0.49 if pethos==0 & specthos==1
	replace qualimaging=0.45 if pethos==0 & specthos==0 & mrihos==1
	replace qualimaging=0.03 if pethos==0 & specthos==0 & mrihos==0 & ctscnhos==1
	replace qualimaging=0.03 if pethos==0 & specthos==0 & mrihos==0 & ultsnhos==1
	generate qualcancer2 = 0
	replace qualcancer2 = 1 if radthhos==1
	replace qualcancer2 = 0.22 if radthhos==1 & oncolhos==1
	generate qualbirths2 = 0
	replace qualbirths2 = 1 if nichos==1
	replace qualbirths2 = 1 if nichos==0 & broomhos==1
	replace qualbirths2 = 0.89 if nichos==0 & broomhos==0 & obhos==1
	
	
	generate JCAHO = 2 - mapp1
	generate CancerProg = 2 - mapp2
	generate Residency = 2 - mapp3
	generate MedSchool = 2 - mapp5
	generate teach2 = 2 - mapp8
	generate FP = 0
	replace FP = 1 if cntrl>30
	generate cntrl_county = 0
	replace cntrl_county = 1 if cntrl==13
	generate cntrl_city = 0
	replace cntrl_city = 1 if cntrl==14
	generate cntrl_hospauth = 0 
	replace cntrl_hospauth = 1 if cntrl==16
	generate cntrl_church = 0
	replace cntrl_church = 1 if cntrl==21
	generate cntrl_othnfp = 0 
	replace cntrl_othnfp = 1 if cntrl==23
	generate cntrl_indfp = 0
	replace cntrl_indfp = 1 if cntrl==31
	generate cntrl_ptnerfp = 0 
	replace cntrl_ptnerfp = 1 if cntrl==32
	generate cntrl_corpfp = 0
	replace cntrl_corpfp = 1 if cntrl==33
	
	generate nurseperbed = ftern / bdtot
	generate nurseperbedsq = nurseperbed * nurseperbed
	generate docsperbed = ftemd/bdtot
	
	generate kaiser=1
		
	//Add in HSA of the hospital, using mloczip
	rename mloczip patzip
	destring patzip, replace
	merge m:1 patzip using "$dir_raw/OSHPD03/oshpd03_patzip_hsa.dta"
	drop if _merge==2
	drop _merge
	tab hsap
	rename hsap hsa
	rename patzip mloczip
	
	keep ahaidno kaiser mloczip hsa broomhos osteo subs alcophos ctscnhos pethos specthos ipahos foundhos ipfeehos sysid obhos nichos brnhos angiohos mammshos cclabhos emdephos oncolhos bdtot mname qual* JCAHO CancerProg Residency MedSchool teach2 FP cntrl_county cntrl_church nurseperbed nurseperbedsq docsperbed exptot paytot exp_peradm pay_peradm

save "$dir_intout/WTPcalc/hospital_charas_kaiser3.dta", replace

//Append to hospital_charas5.dta
append using "$dir_intout/WTPcalc/hospital_charas5_20160523.dta"	
replace kaiser=0 if kaiser==.
save "$dir_intout/WTPcalc/hospital_charas5_and_kaiser_20160523.dta", replace	



u "$dir_intout/hospital_WTP_charas_hsa_posprice_20160523.dta", clear
	egen totnAdmits = total(nAdmits)
	gen exclude = 0
	count if (BS & nAdmits_BS > 10) | (BC & nAdmits_BC > 10)
	count
	
	replace exclude = 1 if numobs_inhsains<=1
	replace exclude = 1 if BS & nAdmits_BS < 10
	replace exclude = 1 if BC & nAdmits_BC < 10
	replace exclude = 1 if deltaWTP_jhm < 0
	
	bys exclude: egen exclnumAdmits = total(nAdmits)
	
	
	keep if exclude==0
	tab insurer FP
	
	
	bysort oshpdid: gen unique = _n==1
	count if unique==1
	drop unique

	drop if s_jh < 10^-5
	
	drop if missing(pwhite)
	drop if hsa==4 | hsa==5 | hsa==11     //drop LA / SF
	
	count
	tab insurer
	sort oshpdid
	keep if oshpdid~=oshpdid[_n-1]
	count
	
	keep ahaid oshpdid
	sort oshpdid
	merge oshpdid using "$dir_intout/WTPcalc/hospital_charas5_and_kaiser_20160523.dta", sort uniqmaster
	tab _merge
	keep if _merge==3 | kaiser==1
	drop _merge
	tab kaiser
	tab hsa if kaiser==1
	drop if hsa==4 | hsa==5 | hsa==11    
	save "$dir_intout/WTPcalc/hospital_charas5_and_kaiser_20160523.dta", replace
	
	
	
	//Merge in the kaiser_i variable needed to identify which hospitals most treated by Kaiser
	u "$dir_intout/hospital_WTP_charas_hsa_posprice_20160523.dta", clear
	collapse (mean) waKaiserHospin3mi_04, by(oshpdid)
	sort oshpdid
	merge oshpdid using "$dir_intout/WTPcalc/hospital_charas5_and_kaiser_20160523.dta", sort uniqmaster
	tab _merge
	keep if _merge==3 | _merge==2
	sum bdtot nurseperbed docsperbed ctscnhos pethos nichos angiohos oncolhos pay_peradm if kaiser==0
	sum bdtot nurseperbed docsperbed ctscnhos pethos nichos angiohos oncolhos pay_peradm if kaiser==1
	sum waKaiserHospin3mi_04 if kaiser==0, detail
	sum bdtot nurseperbed docsperbed ctscnhos pethos nichos angiohos oncolhos pay_peradm if kaiser==0 & waKaiserHospin3mi_04 <= 0.002467
	sum bdtot nurseperbed docsperbed ctscnhos pethos nichos angiohos oncolhos pay_peradm if kaiser==0 & waKaiserHospin3mi_04 >= 0.002467 & waKaiserHospin3mi_04 <= 0.008493
	sum bdtot nurseperbed docsperbed ctscnhos pethos nichos angiohos oncolhos pay_peradm if kaiser==0 & waKaiserHospin3mi_04 >= 0.008493 & waKaiserHospin3mi_04 <= 0.06637
	sum bdtot nurseperbed docsperbed ctscnhos pethos nichos angiohos oncolhos pay_peradm if kaiser==0 & waKaiserHospin3mi_04 >= 0.06637

		
log close
