*Use output from previous files to create variables needed to estimate bargaining equation. 

clear 

*=====================================
global dir_root     /home/HC
global dir_raw 		$dir_root/d01.RawData
global dir_log 		$dir_root/d02.Scripts.and.Logs
global dir_intout 	$dir_root/d03.Intermediate.Output
global dir_out 		$dir_root/d04.Cleaned.Output
global dir_temp 	$dir_root/d99.Temp

clear
set more off
cap log close
*=====================================

log using "$dir_log/create_5_matlabvbles_20160523", text replace
set type double

*=========================
* Create sigmaH for each insurer-hospital pair
*=========================
foreach insurer in BS BC {
	use  "$dir_intout/WTPcalc/WTP_data20160523_6hsa_`insurer'_sys.dta", clear
			
		keep s_ihl_* p_* zipcode03 hsa hrrnum agecat_Ho sex oshpdid
								
		gen s_kij = 0		
		local diags "cancer cardiac digestive labor neuro othercode"
		foreach x of local diags  {
			replace s_kij = s_kij + s_ihl_`x'*p_`x'
			
		} 
		***end(foreach x of local diags)***
						
		gen sigmaH_kijm = p_adm * s_kij


	gen insurer="`insurer'"
		save "$dir_intout/sigmaH_`insurer'_20160523.dta", replace
	}
	*** end(for insurer in BS BC)
	*=========================
	
u "$dir_intout/sigmaH_BS_20160523.dta", clear
append using "$dir_intout/sigmaH_BC_20160523.dta"

	
la data "sigmaH_kijm: share of insurer j's enrollees by zip-age-sex going to hospital i from obs network(variable_outsheet_20150113.do) created `c(current_date)'"
save "$dir_intout/sigmaH_20160523.dta", replace	
des



*=========================
* Create sigmaH_kijm_drophosp and sigmaH_kijm_drop_sys for each insurer-hospital pair x every hospital that could be dropped.	
*=========================

u "$dir_intout/sigmaH_drop1_20160523.dta", clear

keep hrrnum hsa zipcode03 agecat_Ho sex  oshpdid insurer oshpdid_drop sigmaH_kijm_drop sigmaH_kijm_drop_sys
order hrrnum hsa zipcode03 agecat_Ho sex  oshpdid insurer oshpdid_drop sigmaH_kijm_drop sigmaH_kijm_drop_sys

drop if oshpdid==oshpdid_drop
replace sigmaH_kijm_drop_sys = 0 if sigmaH_kijm_drop_sys==.
								
save "$dir_intout/sigmaH_drop_20160523.dta", replace	

u "$dir_intout/sigmaH_20160523.dta", clear
keep hrrnum hsa zipcode03 agecat_Ho sex  oshpdid insurer sigmaH_kijm
order hrrnum hsa zipcode03 agecat_Ho sex  oshpdid insurer sigmaH_kijm

generate oshpdid_drop = oshpdid
drop sigmaH_kijm
generate sigmaH_kijm_drop = 0
generate sigmaH_kijm_drop_sys = 0
save "$dir_intout/sigmaH_drop2_20160523.dta", replace 

append using "$dir_intout/sigmaH_drop_20160523.dta"
order hrrnum hsa zipcode03 agecat_Ho sex oshpdid insurer oshpdid_drop sigmaH_kijm_drop sigmaH_kijm_drop_sys
sort hrrnum hsa zipcode03 agecat_Ho sex insurer oshpdid
save "$dir_intout/sigmaH_drop2_20160523.dta", replace 

*===========================================
*Note WTP_j already created by zip-age-sex in create_4_WTPcalcn_Part3_noD_2014
*==============================================

*==============================================
* Create EU_kjm_drophosp and EU_kjm_drop_sys for each insurer x every hospital that could be dropped.
*=========================

u "$dir_intout/EU_dropdiag_20160523.dta", clear

keep zipcode03 agecat_Ho sex hsa hrrnum insurer oshpdid_drop EU_ijl_* p_* 

						
gen WTP_kjm_drop = 0		
gen WTP_kjm_drop_sys = 0
local diags "cancer cardiac digestive labor neuro othercode"
foreach x of local diags  {
	replace WTP_kjm_drop = WTP_kjm_drop + EU_ijl_`x'_drop * p_`x'
	replace WTP_kjm_drop_sys = WTP_kjm_drop_sys + EU_ijl_`x'_drop_sys * p_`x'
		
} 
***end(foreach x of local diags)***
				
replace WTP_kjm_drop = -1000 if WTP_kjm_drop==0
replace WTP_kjm_drop_sys = -1000 if WTP_kjm_drop_sys==0
replace WTP_kjm_drop_sys = -1000 if WTP_kjm_drop_sys==.						
				
gen gamma_WTP_kjm_drop = p_adm * WTP_kjm_drop
gen gamma_WTP_kjm_drop_sys = p_adm * WTP_kjm_drop_sys

save "$dir_intout/WTP_drop_20160523.dta", replace	



log close


