*Estimation of multinomial logit model of hospital choice
* Inputs: 2004_admissions.dta from create_0_countadmissions.do
* 		  hospital_charas.dta from create_1_hospcharas.do (and other supporting zip/hsa crosswalks)
*


*=====================================
global dir_root 	/home/HC
global dir_raw 		$dir_root/d01.RawData
global dir_log 		$dir_root/d02.Scripts.and.Logs
global dir_intout 	$dir_root/d03.Intermediate.Output
global dir_out 		$dir_root/d04.Cleaned.Output
global dir_temp 	$dir_root/d99.Temp
global dir_tables 	$dir_root/d05.Excel.Tables.and.Graphs

clear
set more off
set matsize 600
cap log close
*=====================================

log using "$dir_log/estimate_1_hospitaldemand_20160523.log", text replace
*u "$dir_intout/2004_admissions.dta", replace


********************
*merge patient zipcode info
	use "$dir_raw/zipcodes/zip-codes-databases-DELUXE_100104_CA.dta", clear
	des
	tab state
	tab msa
	keep if primaryrecord=="P"    	
    count
	rename zipcode zipcode_patient
	sort zipcode_patient
	merge 1:m zipcode_patient using "$dir_intout/2004_admissions_20160523.dta"   
	keep if _merge==3 
	drop _merge
	keep age_bin sex admit_* name_facility id_* is* oshpdid* zipcode_patient latitude longitude incomeperhousehold population wt drg
	label variable latitude "lat of zipcode03 from zip-codes.com, 2004 data"
	label variable longitude "long of zipcode03 from zip-codes.com, 2004 data"
	rename incomeperhousehold hhinc
	replace hhinc = hhinc/1000
	
	sum hhinc, detail
	replace hhinc = 22.151 if hhinc<22.151
	replace hhinc = 87.486 if hhinc>87.486

	
	label variable hhinc "mean household income, $000, from zip-codes.com, 2004 data"
	label variable population "popln of zipcode03 from zip-codes.com, 2004 data"

********************
*merge HSA variables
********************
	rename zipcode_patient patzip
	merge m:1 patzip using "$dir_raw/OSHPD03/oshpd03_patzip_hsa.dta"
	drop if _merge==2 
	drop _merge
	
	rename patzip zipcode
	merge m:1 zipcode using "$dir_intout/crosswalk_zipcounty_eligibility.dta"	
	drop if _merge==2
	drop _merge
	bys county: egen maxhsa = max(hsap)
	bys county: egen minhsa = min(hsap)
	replace hsap = maxhsa if maxhsa==minhsa & hsap==.
	drop maxhsa minhsa
	rename hsap hsa
	rename zipcode zipcode03
	drop if missing(hsa)
	tab hsa

	rename oshpdid oshpdid_admit
	rename isBS is_admit_BS
	rename isBC is_admit_BC
	
	so hsa zipcode03 
	gen id_admit = _n

	sa "$dir_intout/WTPCalc/estimate_1_a_20160523.dta", replace		

********************
*Hospital fixed effect construction
********************
	u "$dir_intout/WTPcalc/hospital_charas5_20160523.dta", clear	
	so hsa mname
	bysort hsa: gen id_hsa_hosp = _n
	
	gen nAdmits = nAdmits_BS + nAdmits_BC
	bysort hsa: egen maxAdmits = max(nAdmits)
	gen biggesthosp=0
	replace biggesthosp=1 if maxAdmits==nAdmits
	tab hsa if biggesthosp==1
	drop nAdmits

	forvalues x=1(1)14 {
		quietly sum num_hosp_in_hsa if hsa==`x'
		local numHosp = r(max)
		forvalues y = 1(1)`numHosp' {
			gen dum_hosp_`x'_`y' = 0
			replace dum_hosp_`x'_`y' = 1 if hsa==`x' & id_hsa_hosp==`y'  & biggesthosp~=1
		}
	}
	sa "$dir_intout/WTPcalc/hospital_charas6_20160523.dta", replace		

	
********************
*merge Hospital characteristics
********************
	u "$dir_intout/WTPCalc/estimate_1_a_20160523.dta", clear		
	rename id_hosp id_hosp_admit
	drop if hsa==.
	joinby hsa using "$dir_intout/WTPcalc/hospital_charas6_20160523.dta"		

	generate is_admit = 1 if id_hosp_admit == id_hosp
	replace is_admit = 0 if missing(is_admit)	

	drop if is_admit_BS==1 & isBS ==0
	drop if is_admit_BC==1 & isBC ==0

	bysort id_admit: egen num_admit = total(is_admit)
	tab name_facility hsa if num_admit==0
	
	drop if num_admit==0
	sum num_admit
		
	*ssc install unique
	unique(id_admit)
	
	preserve
		duplicates drop id_admit, force
		bysort sex age: sum wt
	restore
	
	globdist hospdist, lat0(latitude) lon0(longitude) latvar(hosplat) lonvar(hosplong) miles
	label variable hospdist "Dist (mi) from patient zip"
	generate hospdistsq = hospdist*hospdist
	sum hospdist
	
	foreach x in teach2 nurseperbed FP qualcard qualimag qualcanc qualbirth {
		gen x_`x'_inc = `x'*hhinc
	}

	*PPO interaction
	foreach x in teach2 nurseperbed FP qualcard qualimag qualcanc qualbirth {
		gen x_`x'_PPO = `x'*is_admit_BC
	}
		
	*diagnosis interaction
	local diags "cancer cardiac digestive labor neurological"
	foreach xdiag of local diags  {
		foreach x in teach2 nurseperbed FP qualcard qualimag qualcanc qualbirth {
			gen x_`x'_`xdiag' = `x'*admit_`xdiag'
		}
 	}

	drop x_qualcard_cancer x_qualcard_digestive x_qualcard_labor x_qualcard_neurological
	drop x_qualcanc_cardiac x_qualcanc_digestive x_qualcanc_labor x_qualcanc_neurological
	drop x_qualbirth_cancer x_qualbirth_cardiac x_qualbirth_digestive x_qualbirth_neurological
	
	
	*hsa fixed effects interacted with distance
	forvalues y = 1(1)14 {
			gen dum_hsa_`y' = 0
			replace dum_hsa_`y' = 1 if hsa==`y'
		}
	forvalues y=1(1)14  {
		gen hsa_`y'_hospdist = dum_hsa_`y'*hospdist
		}
	
	
	sa "$dir_temp/temp.dta", replace

	
	
	clogit is_admit hsa_*_hospdist dum_hosp_* x_*, gr(id_admit)

	preserve

	eststo clear
	eststo
	esttab, label ar2 drop (dum_hosp_*)
	esttab using "$dir_tables/logitdemand_20160523.csv", label ar2 sca(cdf) drop (dum_hosp_*) replace	

	matrix coeffs = get(_b)
	gen delta = 0
	forvalues x=1(1)14 {
		quietly sum num_hosp_in_hsa if hsa==`x'
		local numHosp = r(max)
		forvalues y = 1(1)`numHosp' {
			scalar temp = _b[dum_hosp_`x'_`y']
			replace delta = temp if hsa==`x' & id_hsa_hosp==`y'
		}
	}
	keep ahaidno oshpdid hsa delta mname id_hsa_hosp
	bysort hsa id_hsa_hosp: gen dup = cond(_N==1,0,_n)
	keep if dup==1
	drop dup
	sa "$dir_intout/WTPcalc/hospital_deltas_20160523.dta", replace		
log close
