*Estimation of multinomial logit model of insurer demand
* Inputs: 2004_enrollment.dta from CalPERS Data
* 		  $dir_intout/WTPcalc/WTP_20141022.dta from (create_4_WTPcalcn_Part3_noD.do)
*
*=====================================
global dir_root     /home/HC
global dir_raw 		$dir_root/d01.RawData
global dir_log 		$dir_root/d02.Scripts.and.Logs
global dir_intout 	$dir_root/d03.Intermediate.Output
global dir_out 		$dir_root/d04.Cleaned.Output
global dir_temp 	$dir_root/d99.Temp
global dir_raw 		$dir_root/d01.RawData
global dir_log 		$dir_root/d02.Scripts.and.Logs
global dir_intout 	$dir_root/d03.Intermediate.Output
global dir_out 		$dir_root/d04.Cleaned.Output
global dir_temp 	$dir_root/d99.Temp
global dir_papertables $dir_root/d00.InsurerCompetition/tables

clear
set more off
cap log close
*=====================================

log using "$dir_log/estimate_2_insurerdemand_20160523.log", text replace		

*Clean and Ready Kaiser Distance Measures
	u "$dir_intout/Kaiser_ZipAvailability_traveltimes.dta", replace      
	keep zipcode Kaiser_isAvailable Kaiser_Distance_04 Kaiser_drivedist_04 Kaiser_time_04 Kaiser_Distance_95 Kaiser_drivedist_95 Kaiser_time_95
	rename zipcode zipcode03
	sa "$dir_temp/insdemand_KaiserDistance.dta", replace	


*CLEAN UP ENROLLMENT DATA
	u "$dir_intout/2004_enrollment_all.dta", replace
	
	gen sex = 1
	replace sex = 2 if gender=="F"
	
	gen agecat_Ho = 1
	replace agecat_Ho = 2 if age >= 20 
	replace agecat_Ho = 3 if age >= 35 
	replace agecat_Ho = 4 if age >= 45 
	replace agecat_Ho = 5 if age >= 55
	drop if age >= 65
	
	drop if zipcode=="~    "
	destring(zipcode), generate(zipcode03)
	
	*78 obs are categorized as "split", and not single, 2-party, family.  Drop these.
	drop if party_rollup > 3
	
	*MERGE IN WTP OF INSURER NETWORKS
	joinby zipcode03 agecat_Ho sex using "$dir_intout/WTPcalc/WTP_20160523.dta"		
	sa "$dir_temp/insdemand_temp.dta", replace	

	*CLEANING/CONSTRUCTION OF VARS FOR REGRESSIONS
	u "$dir_temp/insdemand_temp.dta", replace	
	bys pid: gen temp = _N
	count if temp < 2
	drop if temp < 2
	drop temp
	bysort fid: egen totalprimary = max(relationship_type=="P")
	drop if totalprimary==0
	unique fid
	bys fid insurer: gen fsize = _N

	*ADD KAISER OUTSIDE OPTION
	expand 2 if insurer=="BC"
	bys pid insurer: replace insurer="K" if _n==2	
	replace WTP_ij = 0 if insurer=="K"
    replace gamma_WTP_ij = 0 if insurer=="K"

	gen is_insurerchoice = 0
	replace is_insurerchoice = 1 if insurer=="BS" & plan_rollup=="Blue Shield Access+"
	replace is_insurerchoice = 1 if insurer=="BC" & plan_rollup=="PERS Choice"
	replace is_insurerchoice = 1 if insurer=="K" & plan_rollup=="Kaiser"
	gen id_insurer = 1
	replace id_insurer = 2 if insurer=="BC"
	replace id_insurer = 3 if insurer=="K"

	*WTP VARIABLES============================
	*BY HOUSEHOLDS-INSURER TYPE, ADD WITHIN FAMILY TO GET TOTAL WTP
	bys fid insurer: egen totWTPfam = total(gamma_WTP_ij)
	bys fid insurer: egen avgWTPfam = mean(gamma_WTP_ij)

	*Generate a WTP variable for each "family type" (Single, 2-Party, Family)
	forvalues familytype = 1(1)3 {	
		gen useWTPhead_`familytype' = gamma_WTP_ij
		replace useWTPhead_`familytype' = 0 if party_rollup != `familytype'

		gen useWTPfam_`familytype' = totWTPfam
		replace useWTPfam_`familytype' = 0 if party_rollup != `familytype'		
		
		gen useavgWTPfam_`familytype' = avgWTPfam
		replace useavgWTPfam_`familytype' = 0 if party_rollup != `familytype'	
	}
	
	*Generate a WTP variable for each age/sex type within a family
	forvalues idxagecat = 1(1)5 {
		forvalues idxsex = 1(1)2 {
			gen WTP_`idxsex'_`idxagecat' = 0
			replace WTP_`idxsex'_`idxagecat' = gamma_WTP_ij if agecat_Ho==`idxagecat' & sex==`idxsex'			
			bys fid insurer: egen totWTPfam_`idxsex'_`idxagecat' = total(WTP_`idxsex'_`idxagecat')
		}	
	}
	
	sa "$dir_temp/insdemand_temp.dta", replace	

	u "$dir_temp/insdemand_temp.dta", replace	
	*KAISER DISTANCE MEASURES===================
	merge m:1 zipcode03 using "$dir_temp/insdemand_KaiserDistance.dta"
	drop if _merge==2
	drop _merge
	so fid pid insurer 
	
	*CLEANING: ELIMINATE KAISER AS AN OPTION IF NOT CHOSEN AND SUPPOSEDLY NOT AVAILABLE IN ZIPCODE
	bys hsa insurer: egen total_hsa_ins = total(is_insurerchoice)
	drop if insurer=="K" & (Kaiser_isAvailable ==0 & is_insurerchoice==0)
		
	bys pid: gen temp_drop = (insurer=="K") * (Kaiser_isAvailable==0) * (is_insurerchoice==1)
	bys pid: egen temp_drop2 = max(temp_drop)
	drop if temp_drop2==1
	drop temp_*
	drop if fid=="itNht1oT5" || fid=="i5AwFstqW"
	drop if hsa==1 & insurer=="K"	
	drop if hsa==8 & insurer=="K"	
	sa "$dir_temp/insdemand_temp2.dta", replace	


	*EXPORT HOUSEHOLD/FAMILY MEMBERS FOR MATLAB HERE
	preserve
	duplicates drop pid, force
	gen planchoice=1
	replace planchoice=2 if plan_rollup=="PERS Choice"
	replace planchoice=3 if plan_rollup=="Kaiser"	
	sa "$dir_intout/insdemand_enrollment_20160523.dta", replace		
	restore	

		
	
	u "$dir_temp/insdemand_temp2.dta", replace	
	**********************
	* NARROW DOWN TO PRIMARY MEMBERS ONLY
	**********************
	keep if relationship==1

	bys fid: gen temp = _N
	sum temp
	count if temp < 2
	drop if temp < 2
	drop temp
	bys fid: egen temp = total(is_insurerchoice)
	sum temp
	drop temp

	*Dummy variables: insurer market family type; don't create one for Kaiser
	*dum_hsainsftype_x_y_z is for hsa x, insurer y, family type z
	forvalues x=1(1)14 {
		forvalues y = 1(1)2 {
			forvalues z = 1(1)3 {
				gen dum_hsainsftype_`x'_`y'_`z' = 0
				replace dum_hsainsftype_`x'_`y'_`z' = 1 if hsa==`x' & id_insurer==`y'  & party_rollup==`z'
			}
		}
	}	

	*Dummy Variables: insurer market only	
	*dum_hsains_x_y is for hsa x, insurer y
	forvalues x=1(1)14 {
		forvalues y = 1(1)2 {
				gen dum_hsains_`x'_`y' = 0
				replace dum_hsains_`x'_`y' = 1 if hsa==`x' & id_insurer==`y'
		}
	}		
	
	
	gen temp_prem = premium * is_insurerchoice
	bys agecat_Ho hsa party_rollup insurer: egen imputed_premium = max(temp_prem) 
	replace imputed_premium = premium if is_insurerchoice==1
	drop temp_prem
	bys hsa party_rollup insurer: replace imputed_premium =imputed_premium[_N] if imputed_premium==0
	bys hsa party_rollup insurer: sum imputed_premium
	
	drop dum_hsainsftype_1_2_* dum_hsains_1_2 dum_hsainsftype_8_2_* dum_hsains_8_2

	*Only have non-zero values for Kaiser Hospital values for insurer=="K" option
	replace Kaiser_isAvailable = 0 if insurer~="K"
	replace Kaiser_Distance_04 = 0 if insurer~="K" || hsa==9
	replace Kaiser_drivedist_04 = 0 if insurer~="K" || hsa==9 
	replace Kaiser_time_04 = 0 if insurer~="K" || hsa==9
	local time_list 5 10 15 20 25 30 35
	foreach time of numlist `time_list' {
		gen KaiserHospin`time'mins_04 = 0
		replace KaiserHospin`time'mins_04 = 1 if (Kaiser_time_04 < `time' & insurer=="K") & hsa ~= 9
		label variable KaiserHospin`time'mins_04 "Kaiser hosp in `time' minutes of pat zip 04"  
	}
	gen KaiserHospWithin_0_4_mi = 0
	gen KaiserHospWithin_5_9_mi = 0
	gen KaiserHospWithin_10_19_mi = 0
	gen KaiserHospWithin_20_29_mi = 0
	gen KaiserHospWithin_30_50_mi = 0
	replace KaiserHospWithin_0_4_mi = 1 if Kaiser_Distance_04 < 5 & insurer=="K" & hsa~=9
	replace KaiserHospWithin_5_9_mi = 1 if (Kaiser_Distance_04 < 10 & Kaiser_Distance_04 >= 5) & insurer=="K" & hsa~=9
	replace KaiserHospWithin_10_19_mi = 1 if (Kaiser_Distance_04 < 20 & Kaiser_Distance_04 >= 10) & insurer=="K" & hsa~=9
	replace KaiserHospWithin_20_29_mi = 1 if (Kaiser_Distance_04 < 30 & Kaiser_Distance_04 >= 20) & insurer=="K" & hsa~=9
	replace KaiserHospWithin_30_50_mi = 1 if (Kaiser_Distance_04 < 50 & Kaiser_Distance_04 >= 30) & insurer=="K" & hsa~=9

	*Kaiser ftype specific distances and time
	forvalues familytype = 1(1)3 {	
		gen KaiserDistUse_`familytype' = Kaiser_Distance_04
		replace KaiserDistUse_`familytype' = 0 if party_rollup != `familytype' | insurer~="K"
		gen KaiserDistUse_Sq_`familytype' = KaiserDistUse_`familytype'^2

		gen KaiserTimeUse_`familytype' = Kaiser_time_04
		replace KaiserTimeUse_`familytype' = 0 if party_rollup != `familytype' | insurer~="K"
		gen KaiserTimeUse2_`familytype' = KaiserTimeUse_`familytype'^2		
	}
	
	gen annualprem = imputed_premium * 12 * .2
	*Premium interacted with income range
	forvalues incomerange = 1(1)10 {
		gen incXprem_`incomerange' = 0 
		replace incXprem_`incomerange' = annualprem if pay_amount == `incomerange'
		replace incXprem_`incomerange' = annualprem if `incomerange' == 10 & pay_amount > 10
		replace incXprem_`incomerange' = . if missing(pay_amount)
	}	
	gen logincminusprem = log(pay_amount * 10000 - annualprem)	
	gen logincXprem = annualprem * log(pay_amount * 10000)
	
	*HSA-specific WTP Coeffs
	forvalues idxhsa = 1(1)14 {
		gen KaiserTimeUseHSA_`idxhsa' = Kaiser_time_04
		replace KaiserTimeUseHSA_`idxhsa' = 0  if hsa != `idxhsa'		
		gen KaiserTimeUse2HSA_`idxhsa' = Kaiser_time_04^2
		replace KaiserTimeUse2HSA_`idxhsa' = 0  if hsa != `idxhsa'		
			
		forvalues familytype = 1(1)3 {	
			gen useWTPfamHSA_`idxhsa'_`familytype' = useWTPfam_`familytype'
			replace useWTPfamHSA_`idxhsa'_`familytype' = 0 if hsa != `idxhsa'		
			gen useavgWTPfamHSA_`idxhsa'_`familytype' = useavgWTPfam_`familytype'
			replace useavgWTPfamHSA_`idxhsa'_`familytype' = 0 if hsa != `idxhsa'		

			gen KaiserTimeUseHSAfam_`idxhsa'_`familytype' = KaiserTimeUse_`familytype'
			replace KaiserTimeUseHSAfam_`idxhsa'_`familytype' = 0  if hsa != `idxhsa'		
			
			gen KaiserTimeUse2HSAfam_`idxhsa'_`familytype' = KaiserTimeUse2_`familytype'
			replace KaiserTimeUse2HSAfam_`idxhsa'_`familytype' = 0  if hsa != `idxhsa'		
		}
	}
	local insurerlist "BS BC"
	foreach idxins of local insurerlist {
		forvalues familytype = 1(1)3 {	
			gen useWTPfamIns_`idxins'_`familytype' = useWTPfam_`familytype'
			replace useWTPfamIns_`idxins'_`familytype' = 0 if insurer != "`idxins'"
			gen useavgWTPfamIns_`idxins'_`familytype' = useavgWTPfam_`familytype'
			replace useavgWTPfamIns_`idxins'_`familytype' = 0 if insurer != "`idxins'"
		}
	}
	
	sa "$dir_temp/insdemand_temp3.dta", replace	
	
************************************************************
*REGRESSIONS	
************************************************************
	u "$dir_temp/insdemand_temp3.dta", replace		
	
	unique(fid)
	
	unique(fid) if logincXprem~=.
	
	la var annualprem "Premium ($\alpha^\phi_0$)"
	la var logincXprem "Log(Income) $\times$ Premium ($\alpha^\phi_1$)"
	la var totWTPfam_1_1 "WTP ($\alpha^W$ Male, Age 0-19)"
	la var totWTPfam_1_2 "WTP ($\alpha^W$ Male, Age 20-34)"
	la var totWTPfam_1_3 "WTP ($\alpha^W$ Male, Age 35-44)"	
	la var totWTPfam_1_4 "WTP ($\alpha^W$ Male, Age 45-54)"	
	la var totWTPfam_1_5 "WTP ($\alpha^W$ Male, Age 55-64)"	
	la var totWTPfam_2_1 "WTP ($\alpha^W$ Female, Age 0-19)"
	la var totWTPfam_2_2 "WTP ($\alpha^W$ Female, Age 20-34)"
	la var totWTPfam_2_3 "WTP ($\alpha^W$ Female, Age 35-44)"	
	la var totWTPfam_2_4 "WTP ($\alpha^W$ Female, Age 45-54)"	
	la var totWTPfam_2_5 "WTP ($\alpha^W$ Female, Age 55-64)"	
	forvalues idxhsa=1(1)14 {
		la var KaiserTimeUseHSA_`idxhsa' "Drive Time to Kaiser ($\alpha^K$ HSA `idxhsa')"	
	}

	*Combine coefficients on M/W ages 0-19
	gen totWTPfam_0_1 = totWTPfam_1_1
	replace totWTPfam_0_1 = totWTPfam_2_1 if sex==2
	la var totWTPfam_0_1 "WTP ($\alpha^W$ Age 0-19)"
	drop totWTPfam_1_1 totWTPfam_2_1

	eststo clear
	clogit is_insurerchoice totWTPfam_* annualprem logincXprem KaiserTimeUseHSA_* dum_hsains_*, gr(fid)   			
	eststo
	esttab using "$dir_papertables/table_insurerdemand_raw_20160523.tex",  label se noobs nodepvars compress nogaps replace star(* 0.10 ** 0.05 *** 0.01) drop(dum_hsains_* KaiserTimeUseHSA_1 KaiserTimeUseHSA_8 KaiserTimeUseHSA_9) order(annualprem logincXprem totWTPfam_0_1 totWTPfam_* KaiserTimeUseHSA_*) substitute(\_ _)

	
*********************************************
*SAVE FIXED EFFECT COEFFICIENTS
***********************************************
	matrix coeffs = get(_b)
	
	preserve
	gen Kcoeff = 0
	gen K2coeff = 0
	gen WTPcoeff = 0
	gen Pricecoeff = 0
	gen LogIncPricecoeff = 0

	scalar temp = _b[annualprem]
	replace Pricecoeff = temp
	scalar temp = _b[logincXprem]
	replace LogIncPricecoeff = temp
	scalar temp=_b[totWTPfam_0_1]
	replace WTPcoeff = temp if agecat_Ho==1
	forvalues idxagecat = 2(1)5 {
		forvalues idxsex = 1(1)2 {
			scalar temp = _b[totWTPfam_`idxsex'_`idxagecat']
			replace WTPcoeff = temp if agecat_Ho==`idxagecat' & sex==`idxsex'
		}
	}
		forvalues idxhsa=1(1)14 {
			if `idxhsa' != 1 & `idxhsa' != 8 & `idxhsa' != 9 {
				scalar temp = _b[KaiserTimeUseHSA_`idxhsa']
				replace Kcoeff = temp if hsa == `idxhsa'
			}
		}
	duplicates drop hsa party_rollup agecat_Ho sex, force
	keep hsa party_rollup sex agecat_Ho WTPcoeff Pricecoeff LogIncPricecoeff Kcoeff K2coeff 
	order hsa party_rollup sex agecat_Ho WTPcoeff Pricecoeff LogIncPricecoeff Kcoeff K2coeff 
	so hsa party_rollup sex agecat_Ho

	la data "Insurer Demand Coeffs (estimate_2_insurerdemand.do) created `c(current_date)'"		
	sa "$dir_intout/insurer_demand_coeffs_20160523.dta", replace
	restore
	
	preserve	
	gen delta = 0
	forvalues x=1(1)14 {
		egen num_ins_in_hsa = group(insurer) if hsa==`x'
		replace num_ins_in_hsa = num_ins_in_hsa - 1
		egen numIns1 = max(num_ins_in_hsa)
		local numIns = numIns1[1] 
		
		forvalues y = 1(1)`numIns' {
			scalar temp = _b[dum_hsains_`x'_`y']
			replace delta = temp if hsa==`x' & id_insurer==`y'  
		}
		drop num_ins_in_hsa numIns1
	}
	keep hsa insurer delta id_insurer
	bysort hsa id_insurer: gen dup = cond(_N==1,0,_n)
	keep if dup==1
	drop dup
	la data "Insurer Demand Ins FEs (estimate_2_insurerdemand.do) created `c(current_date)'"	
	sa "$dir_intout/insurer_demand_deltas_20160523.dta", replace
	restore	
	

